/*! For license information please see chunk.14613ef780b1623041e2.js.LICENSE.txt */
(self.webpackJsonp=self.webpackJsonp||[]).push([[166],{108:function(e,t,n){"use strict";n.d(t,"a",(function(){return r})),n.d(t,"c",(function(){return a})),n.d(t,"d",(function(){return c})),n.d(t,"b",(function(){return s}));class r{constructor(e="keyval-store",t="keyval"){this.storeName=t,this._dbp=new Promise((n,r)=>{const o=indexedDB.open(e,1);o.onerror=()=>r(o.error),o.onsuccess=()=>n(o.result),o.onupgradeneeded=()=>{o.result.createObjectStore(t)}})}_withIDBStore(e,t){return this._dbp.then(n=>new Promise((r,o)=>{const i=n.transaction(this.storeName,e);i.oncomplete=()=>r(),i.onabort=i.onerror=()=>o(i.error),t(i.objectStore(this.storeName))}))}}let o;function i(){return o||(o=new r),o}function a(e,t=i()){let n;return t._withIDBStore("readonly",t=>{n=t.get(e)}).then(()=>n.result)}function c(e,t,n=i()){return n._withIDBStore("readwrite",n=>{n.put(t,e)})}function s(e=i()){return e._withIDBStore("readwrite",e=>{e.clear()})}},150:function(e,t,n){"use strict";n(52),n(83);var r=n(6),o=n(3),i=n(4),a=n(5);Object(r.a)({_template:i.a`
    <style>
      :host {
        @apply --layout-inline;
        @apply --layout-center-center;
        position: relative;

        vertical-align: middle;

        fill: var(--iron-icon-fill-color, currentcolor);
        stroke: var(--iron-icon-stroke-color, none);

        width: var(--iron-icon-width, 24px);
        height: var(--iron-icon-height, 24px);
        @apply --iron-icon;
      }

      :host([hidden]) {
        display: none;
      }
    </style>
`,is:"iron-icon",properties:{icon:{type:String},theme:{type:String},src:{type:String},_meta:{value:a.a.create("iron-meta",{type:"iconset"})}},observers:["_updateIcon(_meta, isAttached)","_updateIcon(theme, isAttached)","_srcChanged(src, isAttached)","_iconChanged(icon, isAttached)"],_DEFAULT_ICONSET:"icons",_iconChanged:function(e){var t=(e||"").split(":");this._iconName=t.pop(),this._iconsetName=t.pop()||this._DEFAULT_ICONSET,this._updateIcon()},_srcChanged:function(e){this._updateIcon()},_usesIconset:function(){return this.icon||!this.src},_updateIcon:function(){this._usesIconset()?(this._img&&this._img.parentNode&&Object(o.a)(this.root).removeChild(this._img),""===this._iconName?this._iconset&&this._iconset.removeIcon(this):this._iconsetName&&this._meta&&(this._iconset=this._meta.byKey(this._iconsetName),this._iconset?(this._iconset.applyIcon(this,this._iconName,this.theme),this.unlisten(window,"iron-iconset-added","_updateIcon")):this.listen(window,"iron-iconset-added","_updateIcon"))):(this._iconset&&this._iconset.removeIcon(this),this._img||(this._img=document.createElement("img"),this._img.style.width="100%",this._img.style.height="100%",this._img.draggable=!1),this._img.src=this.src,Object(o.a)(this.root).appendChild(this._img))}})},204:function(e,t,n){"use strict";n.d(t,"a",(function(){return i}));var r=n(10);const o=new WeakMap,i=Object(r.f)(e=>t=>{const n=o.get(t);if(void 0===e&&t instanceof r.a){if(void 0!==n||!o.has(t)){const e=t.committer.name;t.committer.element.removeAttribute(e)}}else e!==n&&t.setValue(e);o.set(t,e)})},210:function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));const r=e=>(t,n)=>{if(t.constructor._observers){if(!t.constructor.hasOwnProperty("_observers")){const e=t.constructor._observers;t.constructor._observers=new Map,e.forEach((e,n)=>t.constructor._observers.set(n,e))}}else{t.constructor._observers=new Map;const e=t.updated;t.updated=function(t){e.call(this,t),t.forEach((e,t)=>{const n=this.constructor._observers.get(t);void 0!==n&&n.call(this,this[t],e)})}}t.constructor._observers.set(n,e)}},218:function(e,t,n){"use strict";n.d(t,"a",(function(){return o}));var r=n(85);n.d(t,"b",(function(){return r.b}));class o extends r.a{createRenderRoot(){return this.attachShadow({mode:"open",delegatesFocus:!0})}click(){this.formElement&&(this.formElement.focus(),this.formElement.click())}setAriaLabel(e){this.formElement&&this.formElement.setAttribute("aria-label",e)}firstUpdated(){super.firstUpdated(),this.mdcRoot.addEventListener("change",e=>{this.dispatchEvent(new Event("change",e))})}}},224:function(e,t,n){"use strict";n.d(t,"a",(function(){return r}));const r=n(0).c`.mdc-form-field{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto, sans-serif;font-family:var(--mdc-typography-body2-font-family, var(--mdc-typography-font-family, Roboto, sans-serif));font-size:.875rem;font-size:var(--mdc-typography-body2-font-size, 0.875rem);line-height:1.25rem;line-height:var(--mdc-typography-body2-line-height, 1.25rem);font-weight:400;font-weight:var(--mdc-typography-body2-font-weight, 400);letter-spacing:.0178571429em;letter-spacing:var(--mdc-typography-body2-letter-spacing, 0.0178571429em);text-decoration:inherit;text-decoration:var(--mdc-typography-body2-text-decoration, inherit);text-transform:inherit;text-transform:var(--mdc-typography-body2-text-transform, inherit);color:rgba(0,0,0,.87);color:var(--mdc-theme-text-primary-on-background, rgba(0, 0, 0, 0.87));display:inline-flex;align-items:center;vertical-align:middle}.mdc-form-field>label{margin-left:0;margin-right:auto;padding-left:4px;padding-right:0;order:0}[dir=rtl] .mdc-form-field>label,.mdc-form-field>label[dir=rtl]{margin-left:auto;margin-right:0}[dir=rtl] .mdc-form-field>label,.mdc-form-field>label[dir=rtl]{padding-left:0;padding-right:4px}.mdc-form-field--nowrap>label{text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.mdc-form-field--align-end>label{margin-left:auto;margin-right:0;padding-left:0;padding-right:4px;order:-1}[dir=rtl] .mdc-form-field--align-end>label,.mdc-form-field--align-end>label[dir=rtl]{margin-left:0;margin-right:auto}[dir=rtl] .mdc-form-field--align-end>label,.mdc-form-field--align-end>label[dir=rtl]{padding-left:4px;padding-right:0}.mdc-form-field--space-between{justify-content:space-between}.mdc-form-field--space-between>label{margin:0}[dir=rtl] .mdc-form-field--space-between>label,.mdc-form-field--space-between>label[dir=rtl]{margin:0}:host{display:inline-flex}.mdc-form-field{width:100%}::slotted(*){-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:Roboto, sans-serif;font-family:var(--mdc-typography-body2-font-family, var(--mdc-typography-font-family, Roboto, sans-serif));font-size:.875rem;font-size:var(--mdc-typography-body2-font-size, 0.875rem);line-height:1.25rem;line-height:var(--mdc-typography-body2-line-height, 1.25rem);font-weight:400;font-weight:var(--mdc-typography-body2-font-weight, 400);letter-spacing:.0178571429em;letter-spacing:var(--mdc-typography-body2-letter-spacing, 0.0178571429em);text-decoration:inherit;text-decoration:var(--mdc-typography-body2-text-decoration, inherit);text-transform:inherit;text-transform:var(--mdc-typography-body2-text-transform, inherit);color:rgba(0,0,0,.87);color:var(--mdc-theme-text-primary-on-background, rgba(0, 0, 0, 0.87))}::slotted(mwc-switch){margin-right:10px}[dir=rtl] ::slotted(mwc-switch),::slotted(mwc-switch)[dir=rtl]{margin-left:10px}`},252:function(e,t,n){"use strict";var r=n(1),o=n(0),i=n(87),a={ROOT:"mdc-form-field"},c={LABEL_SELECTOR:".mdc-form-field > label"},s=function(e){function t(n){var o=e.call(this,Object(r.a)(Object(r.a)({},t.defaultAdapter),n))||this;return o.clickHandler_=function(){return o.handleClick_()},o}return Object(r.c)(t,e),Object.defineProperty(t,"cssClasses",{get:function(){return a},enumerable:!0,configurable:!0}),Object.defineProperty(t,"strings",{get:function(){return c},enumerable:!0,configurable:!0}),Object.defineProperty(t,"defaultAdapter",{get:function(){return{activateInputRipple:function(){},deactivateInputRipple:function(){},deregisterInteractionHandler:function(){},registerInteractionHandler:function(){}}},enumerable:!0,configurable:!0}),t.prototype.init=function(){this.adapter_.registerInteractionHandler("click",this.clickHandler_)},t.prototype.destroy=function(){this.adapter_.deregisterInteractionHandler("click",this.clickHandler_)},t.prototype.handleClick_=function(){var e=this;this.adapter_.activateInputRipple(),requestAnimationFrame((function(){return e.adapter_.deactivateInputRipple()}))},t}(i.a),l=n(85),d=n(218),u=n(210),f=n(89),h=n(47);class p extends l.a{constructor(){super(...arguments),this.alignEnd=!1,this.spaceBetween=!1,this.nowrap=!1,this.label="",this.mdcFoundationClass=s}createAdapter(){return{registerInteractionHandler:(e,t)=>{this.labelEl.addEventListener(e,t)},deregisterInteractionHandler:(e,t)=>{this.labelEl.removeEventListener(e,t)},activateInputRipple:async()=>{const e=this.input;if(e instanceof d.a){const t=await e.ripple;t&&t.startPress()}},deactivateInputRipple:async()=>{const e=this.input;if(e instanceof d.a){const t=await e.ripple;t&&t.endPress()}}}}get input(){return Object(f.d)(this.slotEl,"*")}render(){const e={"mdc-form-field--align-end":this.alignEnd,"mdc-form-field--space-between":this.spaceBetween,"mdc-form-field--nowrap":this.nowrap};return o.f`
      <div class="mdc-form-field ${Object(h.a)(e)}">
        <slot></slot>
        <label class="mdc-label"
               @click="${this._labelClick}">${this.label}</label>
      </div>`}_labelClick(){const e=this.input;e&&(e.focus(),e.click())}}Object(r.b)([Object(o.h)({type:Boolean})],p.prototype,"alignEnd",void 0),Object(r.b)([Object(o.h)({type:Boolean})],p.prototype,"spaceBetween",void 0),Object(r.b)([Object(o.h)({type:Boolean})],p.prototype,"nowrap",void 0),Object(r.b)([Object(o.h)({type:String}),Object(u.a)((async function(e){const t=this.input;t&&("input"===t.localName?t.setAttribute("aria-label",e):t instanceof d.a&&(await t.updateComplete,t.setAriaLabel(e)))}))],p.prototype,"label",void 0),Object(r.b)([Object(o.i)(".mdc-form-field")],p.prototype,"mdcRoot",void 0),Object(r.b)([Object(o.i)("slot")],p.prototype,"slotEl",void 0),Object(r.b)([Object(o.i)("label")],p.prototype,"labelEl",void 0);var m=n(224);let v=class extends p{};v.styles=m.a,v=Object(r.b)([Object(o.d)("mwc-formfield")],v)},272:function(e,t,n){"use strict";n(5),n(52);var r=n(6),o=n(3),i=n(4),a=n(166);Object(r.a)({_template:i.a`
    <style>
      :host {
        display: block;
        /**
         * Force app-header-layout to have its own stacking context so that its parent can
         * control the stacking of it relative to other elements (e.g. app-drawer-layout).
         * This could be done using \`isolation: isolate\`, but that's not well supported
         * across browsers.
         */
        position: relative;
        z-index: 0;
      }

      #wrapper ::slotted([slot=header]) {
        @apply --layout-fixed-top;
        z-index: 1;
      }

      #wrapper.initializing ::slotted([slot=header]) {
        position: relative;
      }

      :host([has-scrolling-region]) {
        height: 100%;
      }

      :host([has-scrolling-region]) #wrapper ::slotted([slot=header]) {
        position: absolute;
      }

      :host([has-scrolling-region]) #wrapper.initializing ::slotted([slot=header]) {
        position: relative;
      }

      :host([has-scrolling-region]) #wrapper #contentContainer {
        @apply --layout-fit;
        overflow-y: auto;
        -webkit-overflow-scrolling: touch;
      }

      :host([has-scrolling-region]) #wrapper.initializing #contentContainer {
        position: relative;
      }

      :host([fullbleed]) {
        @apply --layout-vertical;
        @apply --layout-fit;
      }

      :host([fullbleed]) #wrapper,
      :host([fullbleed]) #wrapper #contentContainer {
        @apply --layout-vertical;
        @apply --layout-flex;
      }

      #contentContainer {
        /* Create a stacking context here so that all children appear below the header. */
        position: relative;
        z-index: 0;
      }

      @media print {
        :host([has-scrolling-region]) #wrapper #contentContainer {
          overflow-y: visible;
        }
      }

    </style>

    <div id="wrapper" class="initializing">
      <slot id="headerSlot" name="header"></slot>

      <div id="contentContainer">
        <slot></slot>
      </div>
    </div>
`,is:"app-header-layout",behaviors:[a.a],properties:{hasScrollingRegion:{type:Boolean,value:!1,reflectToAttribute:!0}},observers:["resetLayout(isAttached, hasScrollingRegion)"],get header(){return Object(o.a)(this.$.headerSlot).getDistributedNodes()[0]},_updateLayoutStates:function(){var e=this.header;if(this.isAttached&&e){this.$.wrapper.classList.remove("initializing"),e.scrollTarget=this.hasScrollingRegion?this.$.contentContainer:this.ownerDocument.documentElement;var t=e.offsetHeight;this.hasScrollingRegion?(e.style.left="",e.style.right=""):requestAnimationFrame(function(){var t=this.getBoundingClientRect(),n=document.documentElement.clientWidth-t.right;e.style.left=t.left+"px",e.style.right=n+"px"}.bind(this));var n=this.$.contentContainer.style;e.fixed&&!e.condenses&&this.hasScrollingRegion?(n.marginTop=t+"px",n.paddingTop=""):(n.paddingTop=t+"px",n.marginTop="")}}})},282:function(e,t,n){"use strict";var r=n(1),o=n(0),i=(n(119),n(218)),a=n(90),c=n(47),s=n(204);class l extends i.a{constructor(){super(...arguments),this.checked=!1,this.indeterminate=!1,this.disabled=!1,this.value="",this.animationClass="",this.shouldRenderRipple=!1,this.mdcFoundationClass=void 0,this.mdcFoundation=void 0,this.rippleElement=null,this.rippleHandlers=new a.a(()=>(this.shouldRenderRipple=!0,this.ripple.then(e=>this.rippleElement=e),this.ripple))}createAdapter(){return{}}update(e){const t=e.get("indeterminate"),n=e.get("checked");if(void 0!==t||void 0!==n){const e=this.calculateAnimationStateName(!!n,!!t),r=this.calculateAnimationStateName(this.checked,this.indeterminate);this.animationClass=`${e}-${r}`}super.update(e)}calculateAnimationStateName(e,t){return t?"indeterminate":e?"checked":"unchecked"}renderRipple(){const e=this.indeterminate||this.checked;return o.f`${this.shouldRenderRipple?o.f`<mwc-ripple .accent="${e}" .disabled="${this.disabled}" .unbounded="${!0}"></mwc-ripple>`:""}`}render(){const e=this.indeterminate||this.checked,t={"mdc-checkbox--disabled":this.disabled,"mdc-checkbox--selected":e,"mdc-checkbox--anim-checked-indeterminate":"checked-indeterminate"==this.animationClass,"mdc-checkbox--anim-checked-unchecked":"checked-unchecked"==this.animationClass,"mdc-checkbox--anim-indeterminate-checked":"indeterminate-checked"==this.animationClass,"mdc-checkbox--anim-indeterminate-unchecked":"indeterminate-unchecked"==this.animationClass,"mdc-checkbox--anim-unchecked-checked":"unchecked-checked"==this.animationClass,"mdc-checkbox--anim-unchecked-indeterminate":"unchecked-indeterminate"==this.animationClass},n=this.indeterminate?"mixed":void 0;return o.f`
      <div class="mdc-checkbox mdc-checkbox--upgraded ${Object(c.a)(t)}">
        <input type="checkbox"
              class="mdc-checkbox__native-control"
              aria-checked="${Object(s.a)(n)}"
              data-indeterminate="${this.indeterminate?"true":"false"}"
              ?disabled="${this.disabled}"
              .indeterminate="${this.indeterminate}"
              .checked="${this.checked}"
              .value="${this.value}"
              @change="${this._changeHandler}"
              @focus="${this._handleFocus}"
              @blur="${this._handleBlur}"
              @mousedown="${this._activateRipple}"
              @mouseup="${this._deactivateRipple}"
              @mouseenter="${this._handleMouseEnter}"
              @mouseleave="${this._handleMouseLeave}"
              @touchstart="${this._activateRipple}"
              @touchend="${this._deactivateRipple}"
              @touchcancel="${this._deactivateRipple}">
        <div class="mdc-checkbox__background">
          <svg class="mdc-checkbox__checkmark"
              viewBox="0 0 24 24">
            <path class="mdc-checkbox__checkmark-path"
                  fill="none"
                  d="M1.73,12.91 8.1,19.28 22.79,4.59"></path>
          </svg>
          <div class="mdc-checkbox__mixedmark"></div>
        </div>
        ${this.renderRipple()}
      </div>`}_handleFocus(){this.rippleHandlers.startFocus()}_handleBlur(){this.rippleHandlers.endFocus()}_activateRipple(){this.rippleHandlers.startPress()}_deactivateRipple(){this.rippleHandlers.endPress()}_handleMouseEnter(){this.rippleHandlers.startHover()}_handleMouseLeave(){this.rippleHandlers.endHover()}_changeHandler(){this.checked=this.formElement.checked,this.indeterminate=this.formElement.indeterminate}get isRippleActive(){var e;return(null===(e=this.rippleElement)||void 0===e?void 0:e.isActive)||!1}}Object(r.b)([Object(o.i)(".mdc-checkbox")],l.prototype,"mdcRoot",void 0),Object(r.b)([Object(o.i)("input")],l.prototype,"formElement",void 0),Object(r.b)([Object(o.h)({type:Boolean,reflect:!0})],l.prototype,"checked",void 0),Object(r.b)([Object(o.h)({type:Boolean})],l.prototype,"indeterminate",void 0),Object(r.b)([Object(o.h)({type:Boolean,reflect:!0})],l.prototype,"disabled",void 0),Object(r.b)([Object(o.h)({type:String})],l.prototype,"value",void 0),Object(r.b)([Object(o.g)()],l.prototype,"animationClass",void 0),Object(r.b)([Object(o.g)()],l.prototype,"shouldRenderRipple",void 0),Object(r.b)([Object(o.l)("mwc-ripple")],l.prototype,"ripple",void 0);const d=o.c`.mdc-touch-target-wrapper{display:inline}@keyframes mdc-checkbox-unchecked-checked-checkmark-path{0%,50%{stroke-dashoffset:29.7833385}50%{animation-timing-function:cubic-bezier(0, 0, 0.2, 1)}100%{stroke-dashoffset:0}}@keyframes mdc-checkbox-unchecked-indeterminate-mixedmark{0%,68.2%{transform:scaleX(0)}68.2%{animation-timing-function:cubic-bezier(0, 0, 0, 1)}100%{transform:scaleX(1)}}@keyframes mdc-checkbox-checked-unchecked-checkmark-path{from{animation-timing-function:cubic-bezier(0.4, 0, 1, 1);opacity:1;stroke-dashoffset:0}to{opacity:0;stroke-dashoffset:-29.7833385}}@keyframes mdc-checkbox-checked-indeterminate-checkmark{from{animation-timing-function:cubic-bezier(0, 0, 0.2, 1);transform:rotate(0deg);opacity:1}to{transform:rotate(45deg);opacity:0}}@keyframes mdc-checkbox-indeterminate-checked-checkmark{from{animation-timing-function:cubic-bezier(0.14, 0, 0, 1);transform:rotate(45deg);opacity:0}to{transform:rotate(360deg);opacity:1}}@keyframes mdc-checkbox-checked-indeterminate-mixedmark{from{animation-timing-function:mdc-animation-deceleration-curve-timing-function;transform:rotate(-45deg);opacity:0}to{transform:rotate(0deg);opacity:1}}@keyframes mdc-checkbox-indeterminate-checked-mixedmark{from{animation-timing-function:cubic-bezier(0.14, 0, 0, 1);transform:rotate(0deg);opacity:1}to{transform:rotate(315deg);opacity:0}}@keyframes mdc-checkbox-indeterminate-unchecked-mixedmark{0%{animation-timing-function:linear;transform:scaleX(1);opacity:1}32.8%,100%{transform:scaleX(0);opacity:0}}.mdc-checkbox{display:inline-block;position:relative;flex:0 0 18px;box-sizing:content-box;width:18px;height:18px;line-height:0;white-space:nowrap;cursor:pointer;vertical-align:bottom;padding:11px}.mdc-checkbox .mdc-checkbox__native-control:checked~.mdc-checkbox__background::before,.mdc-checkbox .mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background::before,.mdc-checkbox .mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background::before{background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}.mdc-checkbox.mdc-checkbox--selected .mdc-checkbox__ripple::before,.mdc-checkbox.mdc-checkbox--selected .mdc-checkbox__ripple::after{background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}.mdc-checkbox.mdc-checkbox--selected:hover .mdc-checkbox__ripple::before{opacity:.04}.mdc-checkbox.mdc-checkbox--selected.mdc-ripple-upgraded--background-focused .mdc-checkbox__ripple::before,.mdc-checkbox.mdc-checkbox--selected:not(.mdc-ripple-upgraded):focus .mdc-checkbox__ripple::before{transition-duration:75ms;opacity:.12}.mdc-checkbox.mdc-checkbox--selected:not(.mdc-ripple-upgraded) .mdc-checkbox__ripple::after{transition:opacity 150ms linear}.mdc-checkbox.mdc-checkbox--selected:not(.mdc-ripple-upgraded):active .mdc-checkbox__ripple::after{transition-duration:75ms;opacity:.12}.mdc-checkbox.mdc-checkbox--selected.mdc-ripple-upgraded{--mdc-ripple-fg-opacity: 0.12}.mdc-checkbox.mdc-ripple-upgraded--background-focused.mdc-checkbox--selected .mdc-checkbox__ripple::before,.mdc-checkbox.mdc-ripple-upgraded--background-focused.mdc-checkbox--selected .mdc-checkbox__ripple::after{background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}.mdc-checkbox .mdc-checkbox__background{top:11px;left:11px}.mdc-checkbox .mdc-checkbox__background::before{top:-13px;left:-13px;width:40px;height:40px}.mdc-checkbox .mdc-checkbox__native-control{top:0px;right:0px;left:0px;width:40px;height:40px}.mdc-checkbox__native-control:enabled:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:rgba(0,0,0,.54);background-color:transparent}.mdc-checkbox__native-control:enabled:checked~.mdc-checkbox__background,.mdc-checkbox__native-control:enabled:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true]:enabled~.mdc-checkbox__background{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}@keyframes mdc-checkbox-fade-in-background-8A000000secondary00000000secondary{0%{border-color:rgba(0,0,0,.54);background-color:transparent}50%{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}}@keyframes mdc-checkbox-fade-out-background-8A000000secondary00000000secondary{0%,80%{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}100%{border-color:rgba(0,0,0,.54);background-color:transparent}}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-in-background-8A000000secondary00000000secondary}.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-out-background-8A000000secondary00000000secondary}.mdc-checkbox__native-control[disabled]:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:rgba(0,0,0,.38);background-color:transparent}.mdc-checkbox__native-control[disabled]:checked~.mdc-checkbox__background,.mdc-checkbox__native-control[disabled]:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true][disabled]~.mdc-checkbox__background{border-color:transparent;background-color:rgba(0,0,0,.38)}.mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:#fff}.mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:#fff}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:#fff}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:#fff}@media screen and (-ms-high-contrast: active){.mdc-checkbox__native-control[disabled]:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:GrayText;background-color:transparent}.mdc-checkbox__native-control[disabled]:checked~.mdc-checkbox__background,.mdc-checkbox__native-control[disabled]:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true][disabled]~.mdc-checkbox__background{border-color:GrayText;background-color:transparent}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:GrayText}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:GrayText}.mdc-checkbox__mixedmark{margin:0 1px}}.mdc-checkbox--disabled{cursor:default;pointer-events:none}.mdc-checkbox__background{display:inline-flex;position:absolute;align-items:center;justify-content:center;box-sizing:border-box;width:18px;height:18px;border:2px solid currentColor;border-radius:2px;background-color:transparent;pointer-events:none;will-change:background-color,border-color;transition:background-color 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),border-color 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox__background .mdc-checkbox__background::before{background-color:#000;background-color:var(--mdc-theme-on-surface, #000)}.mdc-checkbox__checkmark{position:absolute;top:0;right:0;bottom:0;left:0;width:100%;opacity:0;transition:opacity 180ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox--upgraded .mdc-checkbox__checkmark{opacity:1}.mdc-checkbox__checkmark-path{transition:stroke-dashoffset 180ms 0ms cubic-bezier(0.4, 0, 0.6, 1);stroke:currentColor;stroke-width:3.12px;stroke-dashoffset:29.7833385;stroke-dasharray:29.7833385}.mdc-checkbox__mixedmark{width:100%;height:0;transform:scaleX(0) rotate(0deg);border-width:1px;border-style:solid;opacity:0;transition:opacity 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),transform 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox--upgraded .mdc-checkbox__background,.mdc-checkbox--upgraded .mdc-checkbox__checkmark,.mdc-checkbox--upgraded .mdc-checkbox__checkmark-path,.mdc-checkbox--upgraded .mdc-checkbox__mixedmark{transition:none !important}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__background,.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__background,.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__background,.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__background{animation-duration:180ms;animation-timing-function:linear}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__checkmark-path{animation:mdc-checkbox-unchecked-checked-checkmark-path 180ms linear 0s;transition:none}.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__mixedmark{animation:mdc-checkbox-unchecked-indeterminate-mixedmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__checkmark-path{animation:mdc-checkbox-checked-unchecked-checkmark-path 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-indeterminate .mdc-checkbox__checkmark{animation:mdc-checkbox-checked-indeterminate-checkmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-indeterminate .mdc-checkbox__mixedmark{animation:mdc-checkbox-checked-indeterminate-mixedmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-checked .mdc-checkbox__checkmark{animation:mdc-checkbox-indeterminate-checked-checkmark 500ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-checked .mdc-checkbox__mixedmark{animation:mdc-checkbox-indeterminate-checked-mixedmark 500ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__mixedmark{animation:mdc-checkbox-indeterminate-unchecked-mixedmark 300ms linear 0s;transition:none}.mdc-checkbox__native-control:checked~.mdc-checkbox__background,.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background{transition:border-color 90ms 0ms cubic-bezier(0, 0, 0.2, 1),background-color 90ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__checkmark-path,.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__checkmark-path,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__checkmark-path{stroke-dashoffset:0}.mdc-checkbox__background::before{position:absolute;transform:scale(0, 0);border-radius:50%;opacity:0;pointer-events:none;content:"";will-change:opacity,transform;transition:opacity 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),transform 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox__native-control:focus~.mdc-checkbox__background::before{transform:scale(1);opacity:.12;transition:opacity 80ms 0ms cubic-bezier(0, 0, 0.2, 1),transform 80ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-checkbox__native-control{position:absolute;margin:0;padding:0;opacity:0;cursor:inherit}.mdc-checkbox__native-control:disabled{cursor:default;pointer-events:none}.mdc-checkbox--touch{margin-top:4px;margin-bottom:4px;margin-right:4px;margin-left:4px}.mdc-checkbox--touch .mdc-checkbox__native-control{top:-4px;right:-4px;left:-4px;width:48px;height:48px}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__checkmark{transition:opacity 180ms 0ms cubic-bezier(0, 0, 0.2, 1),transform 180ms 0ms cubic-bezier(0, 0, 0.2, 1);opacity:1}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__mixedmark{transform:scaleX(1) rotate(-45deg)}.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__checkmark,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__checkmark{transform:rotate(45deg);opacity:0;transition:opacity 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),transform 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__mixedmark,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__mixedmark{transform:scaleX(1) rotate(0deg);opacity:1}:host{outline:none;display:inline-block}.mdc-checkbox .mdc-checkbox__native-control:focus~.mdc-checkbox__background::before{background-color:rgba(0,0,0,.54);background-color:var(--mdc-checkbox-unchecked-color, rgba(0, 0, 0, 0.54))}.mdc-checkbox .mdc-checkbox__background::before{content:none}.mdc-checkbox__native-control[disabled]:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-disabled-color, rgba(0, 0, 0, 0.38));background-color:transparent}.mdc-checkbox__native-control[disabled]:checked~.mdc-checkbox__background,.mdc-checkbox__native-control[disabled]:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true][disabled]~.mdc-checkbox__background{border-color:transparent;background-color:var(--mdc-checkbox-disabled-color, rgba(0, 0, 0, 0.38))}.mdc-checkbox__native-control:enabled:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-unchecked-color, rgba(0, 0, 0, 0.54));background-color:transparent}.mdc-checkbox__native-control:enabled:checked~.mdc-checkbox__background,.mdc-checkbox__native-control:enabled:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true]:enabled~.mdc-checkbox__background{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}@keyframes mdc-checkbox-fade-in-background---mdc-checkbox-unchecked-colorsecondary00000000secondary{0%{border-color:var(--mdc-checkbox-unchecked-color, rgba(0, 0, 0, 0.54));background-color:transparent}50%{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}}@keyframes mdc-checkbox-fade-out-background---mdc-checkbox-unchecked-colorsecondary00000000secondary{0%,80%{border-color:#018786;border-color:var(--mdc-theme-secondary, #018786);background-color:#018786;background-color:var(--mdc-theme-secondary, #018786)}100%{border-color:var(--mdc-checkbox-unchecked-color, rgba(0, 0, 0, 0.54));background-color:transparent}}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-in-background---mdc-checkbox-unchecked-colorsecondary00000000secondary}.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-out-background---mdc-checkbox-unchecked-colorsecondary00000000secondary}.mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:var(--mdc-checkbox-mark-color, #fff)}.mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:var(--mdc-checkbox-mark-color, #fff)}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:var(--mdc-checkbox-mark-color, #fff)}.mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:var(--mdc-checkbox-mark-color, #fff)}`;let u=class extends l{};u.styles=d,u=Object(r.b)([Object(o.d)("mwc-checkbox")],u)},517:function(e,t,n){"use strict";t.a='@charset "UTF-8";\n.fc-not-allowed,\n.fc-not-allowed .fc-event {\n  cursor: not-allowed;\n}\n\n.fc-unselectable {\n  -webkit-user-select: none;\n  -khtml-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n  -webkit-touch-callout: none;\n  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);\n}\n\n.fc {\n  font-size: 1em;\n  display: flex;\n  flex-direction: column;\n}\n.fc,\n.fc *,\n.fc *:before,\n.fc *:after {\n  -webkit-box-sizing: border-box;\n  -moz-box-sizing: border-box;\n  box-sizing: border-box;\n}\n.fc table {\n  border-spacing: 0;\n  font-size: 1em;\n  /* normalize cross-browser */\n}\n.fc th {\n  text-align: center;\n}\n.fc th, .fc td {\n  vertical-align: top;\n}\n.fc a[data-navlink] {\n  cursor: pointer;\n}\n.fc a[data-navlink]:hover {\n  text-decoration: underline;\n}\n\n.fc-direction-ltr {\n  direction: ltr;\n  text-align: left;\n}\n\n.fc-direction-rtl {\n  direction: rtl;\n  text-align: right;\n}\n\n.fc-theme-standard td, .fc-theme-standard th {\n  border: 1px solid #ddd;\n  border: 1px solid var(--fc-theme-standard-border-color, #ddd);\n}\n\n.fc-media-print {\n  max-width: 100%;\n}\n\n.fc-liquid-hack td, .fc-liquid-hack th {\n  position: relative;\n}\n\n@font-face {\n  font-family: "fcicons";\n  src: url("data:application/x-font-ttf;charset=utf-8;base64,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") format("truetype");\n  font-weight: normal;\n  font-style: normal;\n}\n.fc-icon {\n  /* added for fc */\n  display: inline-block;\n  width: 1em;\n  height: 1em;\n  text-align: center;\n  /* use !important to prevent issues with browser extensions that change fonts */\n  font-family: "fcicons" !important;\n  speak: none;\n  font-style: normal;\n  font-weight: normal;\n  font-variant: normal;\n  text-transform: none;\n  line-height: 1;\n  /* Better Font Rendering =========== */\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n\n.fc-icon-chevron-left:before {\n  content: "";\n}\n\n.fc-icon-chevron-right:before {\n  content: "";\n}\n\n.fc-icon-chevrons-left:before {\n  content: "";\n}\n\n.fc-icon-chevrons-right:before {\n  content: "";\n}\n\n.fc-icon-minus-square:before {\n  content: "";\n}\n\n.fc-icon-plus-square:before {\n  content: "";\n}\n\n.fc-icon-x:before {\n  content: "";\n}\n\n/*\nLots taken from Flatly (MIT): https://bootswatch.com/4/flatly/bootstrap.css\n\nThese styles only apply when the standard-theme is activated.\nWhen it\'s NOT activated, the fc-button classes won\'t even be in the DOM.\n*/\n.fc-button {\n  border-radius: 0;\n  overflow: visible;\n  text-transform: none;\n  margin: 0;\n  font-family: inherit;\n  font-size: inherit;\n  line-height: inherit;\n}\n\n.fc-button:focus {\n  outline: 1px dotted;\n  outline: 5px auto -webkit-focus-ring-color;\n}\n\n.fc-button {\n  -webkit-appearance: button;\n}\n\n.fc-button:not(:disabled) {\n  cursor: pointer;\n}\n\n.fc-button::-moz-focus-inner {\n  padding: 0;\n  border-style: none;\n}\n\n.fc-button {\n  display: inline-block;\n  font-weight: 400;\n  color: #212529;\n  text-align: center;\n  vertical-align: middle;\n  -webkit-user-select: none;\n  -moz-user-select: none;\n  -ms-user-select: none;\n  user-select: none;\n  background-color: transparent;\n  border: 1px solid transparent;\n  padding: 0.4em 0.65em;\n  font-size: 1em;\n  line-height: 1.5;\n  border-radius: 0.25em;\n}\n\n.fc-button:hover {\n  color: #212529;\n  text-decoration: none;\n}\n\n.fc-button:focus {\n  outline: 0;\n  -webkit-box-shadow: 0 0 0 0.2rem rgba(44, 62, 80, 0.25);\n  box-shadow: 0 0 0 0.2rem rgba(44, 62, 80, 0.25);\n}\n\n.fc-button:disabled {\n  opacity: 0.65;\n}\n\n.fc-button-primary {\n  color: #fff;\n  background-color: #2C3E50;\n  border-color: #2C3E50;\n}\n\n.fc-button-primary:hover {\n  color: #fff;\n  background-color: #1e2b37;\n  border-color: #1a252f;\n}\n\n.fc-button-primary:focus {\n  -webkit-box-shadow: 0 0 0 0.2rem rgba(76, 91, 106, 0.5);\n  box-shadow: 0 0 0 0.2rem rgba(76, 91, 106, 0.5);\n}\n\n.fc-button-primary:disabled {\n  color: #fff;\n  background-color: #2C3E50;\n  border-color: #2C3E50;\n}\n\n.fc-button-primary:not(:disabled):active,\n.fc-button-primary:not(:disabled).fc-button-active {\n  color: #fff;\n  background-color: #1a252f;\n  border-color: #151e27;\n}\n\n.fc-button-primary:not(:disabled):active:focus,\n.fc-button-primary:not(:disabled).fc-button-active:focus {\n  -webkit-box-shadow: 0 0 0 0.2rem rgba(76, 91, 106, 0.5);\n  box-shadow: 0 0 0 0.2rem rgba(76, 91, 106, 0.5);\n}\n\n.fc-button .fc-icon {\n  vertical-align: middle;\n  font-size: 1.5em;\n}\n\n.fc-button-group {\n  position: relative;\n  display: -webkit-inline-box;\n  display: -ms-inline-flexbox;\n  display: inline-flex;\n  vertical-align: middle;\n}\n\n.fc-button-group > .fc-button {\n  position: relative;\n  -webkit-box-flex: 1;\n  -ms-flex: 1 1 auto;\n  flex: 1 1 auto;\n}\n\n.fc-button-group > .fc-button:hover {\n  z-index: 1;\n}\n\n.fc-button-group > .fc-button:focus,\n.fc-button-group > .fc-button:active,\n.fc-button-group > .fc-button.fc-button-active {\n  z-index: 1;\n}\n\n.fc-direction-ltr .fc-button-group > .fc-button:not(:first-child) {\n  margin-left: -1px;\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n.fc-direction-ltr .fc-button-group > .fc-button:not(:last-child) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.fc-direction-rtl .fc-button-group > .fc-button:not(:first-child) {\n  margin-right: -1px;\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n.fc-direction-rtl .fc-button-group > .fc-button:not(:last-child) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.fc-toolbar {\n  display: flex;\n  justify-content: space-between;\n  align-items: center;\n}\n\n.fc-direction-rtl .fc-toolbar-ltr {\n  flex-direction: row-reverse;\n}\n\n.fc-toolbar.fc-header-toolbar {\n  margin-bottom: 1.5em;\n}\n\n.fc-toolbar.fc-footer-toolbar {\n  margin-top: 1.5em;\n}\n\n.fc-toolbar-title {\n  font-size: 1.75em;\n  margin: 0;\n}\n\n.fc-direction-ltr .fc-toolbar > * > :not(:first-child) {\n  margin-left: 0.75em;\n}\n\n.fc-direction-rtl .fc-toolbar > * > :not(:first-child) {\n  margin-right: 0.75em;\n}\n\n.fc-scroller {\n  -webkit-overflow-scrolling: touch;\n  position: relative;\n}\n\n.fc-scroller-liquid {\n  height: 100%;\n}\n\n.fc-scroller-liquid-absolute {\n  position: absolute;\n  top: 0;\n  right: 0;\n  left: 0;\n  bottom: 0;\n}\n\n.fc-scroller-harness {\n  position: relative;\n  overflow: hidden;\n  direction: ltr;\n}\n\n.fc-scroller-harness-liquid {\n  height: 100%;\n}\n\n.fc-direction-rtl .fc-scroller-harness > .fc-scroller {\n  direction: rtl;\n}\n\n.fc-scrollgrid, .fc-scrollgrid table {\n  width: 100%;\n  table-layout: fixed;\n  border-collapse: separate !important;\n}\n.fc-scrollgrid table {\n  border-style: hidden !important;\n}\n.fc-scrollgrid tr > * {\n  padding: 0;\n}\n\n.fc-scrollgrid-liquid {\n  height: 100%;\n}\n\n.fc-theme-standard .fc-scrollgrid {\n  border: 1px solid #ddd;\n}\n\n.fc-media-print .fc-scrollgrid {\n  table-layout: auto;\n}\n\n.fc-scrollgrid tr:not(.fc-scrollgrid-section-header) > * {\n  border-bottom: 0;\n}\n\n.fc-scrollgrid tr:first-child > *,\n.fc-scrollgrid-section-header + .fc-scrollgrid-section > *,\n.fc .fc-scrollgrid-section-footer > * {\n  border-top: 0;\n}\n\n.fc-direction-ltr .fc-scrollgrid tr > *:first-child {\n  border-left: 0;\n}\n.fc-direction-ltr .fc-scrollgrid tr > * {\n  border-right: 0;\n}\n\n.fc-direction-rtl .fc-scrollgrid tr > *:first-child {\n  border-right: 0;\n}\n.fc-direction-rtl .fc-scrollgrid tr > * {\n  border-left: 0;\n}\n\n.fc-scrollgrid-section {\n  height: 0;\n}\n.fc-scrollgrid-section > td {\n  height: 0;\n}\n.fc-scrollgrid-section table {\n  height: 1px;\n}\n\n.fc-scrollgrid-section-liquid {\n  height: auto;\n}\n.fc-scrollgrid-section-liquid > td {\n  height: 100%;\n}\n\n.fc-scrollgrid-section-header > td {\n  top: 0;\n}\n\n.fc-scrollgrid-section-footer > td {\n  bottom: 0;\n}\n\n.fc-scrollgrid-section-sticky > td {\n  background: #fff;\n  position: sticky;\n  z-index: 2;\n}\n\n.fc-scrollgrid-sticky-shim {\n  height: 1px;\n  margin-bottom: -1px;\n}\n\n.fc-media-screen .fc-sticky {\n  position: -webkit-sticky;\n  position: sticky;\n}\n\n.fc-view-harness {\n  flex-grow: 1;\n  position: relative;\n}\n\n.fc-view-harness-active > .fc-view {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n}\n\n.fc-col-header-cell-cushion {\n  display: inline-block;\n  padding: 2px 4px;\n}\n\n.fc-theme-standard .fc-divider {\n  background: #eee;\n  background: var(--fc-theme-standard-muted-bg-color, #eee);\n}\n\n.fc-bg-event,\n.fc-non-business,\n.fc-highlight {\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n  bottom: 0;\n  opacity: 0.3;\n}\n\n.fc-non-business {\n  background: #d7d7d7;\n}\n\n.fc-bg-event {\n  background: #8fdf82;\n}\n\n.fc-highlight {\n  background: #bce8f1;\n}\n\n.fc-bg-event .fc-event-title {\n  margin: 0.5em;\n  font-size: 0.85em;\n  font-style: italic;\n}\n\n.fc-day-today {\n  background: rgba(255, 220, 40, 0.15);\n}\n\n.fc-day-disabled {\n  background: #f2f2f2;\n}\n\na.fc-event {\n  display: block;\n  text-decoration: none;\n}\n\n.fc-event[href],\n.fc-event.fc-event-draggable {\n  cursor: pointer;\n}\n\n.fc-media-print .fc-event {\n  page-break-inside: avoid;\n}\n\n.fc-event-mirror {\n  z-index: 9999;\n}\n\n.fc-event-dragging:not(.fc-event-selected) {\n  opacity: 0.75;\n}\n\n.fc-event-dragging.fc-event-selected {\n  box-shadow: 0 2px 7px rgba(0, 0, 0, 0.3);\n}\n\n.fc-event .fc-event-resizer {\n  display: none;\n}\n\n.fc-event-resizable-mouse .fc-event-resizer,\n.fc-event-selected .fc-event-resizer {\n  display: block;\n}\n\n.fc-media-print .fc-event-resizer {\n  display: none;\n}\n\n.fc-event-selected:before {\n  content: "";\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  right: -1px;\n  bottom: -1px;\n}\n\n.fc-event-selected .fc-event-resizer:before {\n  content: "";\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  width: 40px;\n  height: 40px;\n  margin-left: -20px;\n  margin-top: -20px;\n}\n\n.fc-event-selected {\n  box-shadow: 0 2px 5px rgba(0, 0, 0, 0.2);\n}\n\n.fc-event-selected:after {\n  content: "";\n  position: absolute;\n  z-index: 1;\n  top: -1px;\n  left: -1px;\n  right: -1px;\n  bottom: -1px;\n  background: #000;\n  opacity: 0.25;\n}\n\n/*\nA HORIZONTAL event\n*/\n.fc-h-event .fc-event-main {\n  position: relative;\n  z-index: 2;\n}\n\n.fc-h-event .fc-event-resizer {\n  position: absolute;\n  z-index: 3;\n}\n\n.fc-direction-ltr .fc-h-event .fc-event-resizer-start,\n.fc-direction-rtl .fc-h-event .fc-event-resizer-end {\n  cursor: w-resize;\n}\n\n.fc-direction-ltr .fc-h-event .fc-event-resizer-end,\n.fc-direction-rtl .fc-h-event .fc-event-resizer-start {\n  cursor: e-resize;\n}\n\n.fc-h-event.fc-event-resizable-mouse .fc-event-resizer {\n  width: 8px;\n  top: -1px;\n  bottom: -1px;\n}\n\n.fc-direction-ltr .fc-h-event.fc-event-resizable-mouse .fc-event-resizer-start,\n.fc-direction-rtl .fc-h-event.fc-event-resizable-mouse .fc-event-resizer-end {\n  left: -4px;\n}\n\n.fc-direction-ltr .fc-h-event.fc-event-resizable-mouse .fc-event-resizer-end,\n.fc-direction-rtl .fc-h-event.fc-event-resizable-mouse .fc-event-resizer-start {\n  right: -4px;\n}\n\n.fc-h-event.fc-event-selected .fc-event-resizer {\n  border-radius: 4px;\n  border-width: 1px;\n  width: 8px;\n  height: 8px;\n  border-style: solid;\n  border-color: inherit;\n  background: #fff;\n  top: 50%;\n  margin-top: -4px;\n}\n\n.fc-direction-ltr .fc-h-event.fc-event-selected .fc-event-resizer-start,\n.fc-direction-rtl .fc-h-event.fc-event-selected .fc-event-resizer-end {\n  left: -4px;\n}\n\n.fc-direction-ltr .fc-h-event.fc-event-selected .fc-event-resizer-end,\n.fc-direction-rtl .fc-h-event.fc-event-selected .fc-event-resizer-start {\n  right: -4px;\n}\n\n.fc-h-event.fc-event-selected:before {\n  top: -10px;\n  bottom: -10px;\n}\n'},518:function(e,t,n){"use strict";t.a='.fc-popover {\n  position: fixed !important;\n  top: 0;\n  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.15);\n}\n\n.fc-popover-header {\n  display: flex;\n  flex-direction: row;\n  justify-content: space-between;\n  align-items: center;\n  padding: 3px 4px !important;\n}\n\n.fc-direction-rtl .fc-popover-header {\n  flex-direction: row-reverse;\n}\n\n.fc-popover-title {\n  margin: 0 2px;\n}\n\n.fc-popover-close {\n  cursor: pointer;\n  opacity: 0.65;\n  font-size: 1.1em;\n}\n\n.fc-theme-standard .fc-popover {\n  border: 1px solid #ddd;\n  border: 1px solid var(--fc-theme-standard-border-color, #ddd);\n  background: #fff;\n}\n.fc-theme-standard .fc-popover-header {\n  background: #eee;\n  background: var(--fc-theme-standard-muted-bg-color, #eee);\n}\n\n.fc-media-print .fc-popover {\n  display: none;\n}\n\n.fc-daygrid-body {\n  position: relative;\n  z-index: 1;\n}\n\n.fc-daygrid-day-frame {\n  position: relative;\n  min-height: 100%;\n}\n.fc-daygrid-day-frame:before {\n  content: "";\n  clear: both;\n  display: table;\n}\n\n.fc-liquid-hack .fc-daygrid-day-frame {\n  position: static;\n}\n\n.fc-daygrid-body-balanced .fc-daygrid-day-events {\n  position: absolute;\n  left: 0;\n  right: 0;\n}\n\n.fc-daygrid-body-unbalanced .fc-daygrid-day-events {\n  position: relative;\n  min-height: 3em;\n}\n.fc-daygrid-body-unbalanced .fc-daygrid-day-events:before {\n  content: "";\n  clear: both;\n  display: table;\n}\n\n.fc-daygrid-body-natural .fc-daygrid-day-events {\n  padding-bottom: 1em;\n}\n\n.fc-daygrid-day-top {\n  position: relative;\n  z-index: 4;\n}\n.fc-daygrid-day-top:after {\n  content: "";\n  clear: both;\n  display: table;\n}\n\n.fc-day-other .fc-daygrid-day-top {\n  opacity: 0.3;\n}\n\n.fc-daygrid-day-number {\n  padding: 4px;\n}\n\n.fc-direction-ltr .fc-daygrid-day-number {\n  float: right;\n}\n\n.fc-direction-rtl .fc-daygrid-day-number {\n  float: left;\n}\n\n.fc-daygrid-day-events {\n  margin-left: 2px;\n  margin-right: 2px;\n}\n.fc-daygrid-day-events:first-child {\n  margin-top: 2px;\n}\n\n.fc-daygrid-event-harness:before {\n  content: "";\n  clear: both;\n  display: table;\n}\n.fc-daygrid-event-harness:after {\n  content: "";\n  clear: both;\n  display: table;\n}\n\n.fc-daygrid-event-harness-abs {\n  position: absolute;\n  top: 0;\n  left: 0;\n  right: 0;\n}\n\n.fc-daygrid-event:not(.fc-event-mirror) {\n  z-index: 5;\n}\n\n.fc-daygrid-day-bottom {\n  position: relative;\n  z-index: 4;\n  font-size: 0.85em;\n  margin: 2px 3px 0;\n}\n\n.fc-daygrid-more-link {\n  cursor: pointer;\n}\n\n.fc-daygrid-day-bg .fc-non-business {\n  z-index: 1;\n}\n.fc-daygrid-day-bg .fc-bg-event {\n  z-index: 2;\n}\n.fc-daygrid-day-bg .fc-highlight {\n  z-index: 3;\n}\n\n.fc-daygrid-bg-harness {\n  position: absolute;\n  top: 0;\n  bottom: 0;\n}\n\n.fc-daygrid-week-number {\n  position: absolute;\n  z-index: 4;\n  top: 0;\n  padding: 2px;\n  min-width: 1.5em;\n  text-align: center;\n  background-color: #f2f2f2;\n  color: #808080;\n}\n\n.fc-direction-ltr .fc-daygrid-week-number {\n  left: 0;\n  border-radius: 0 0 3px 0;\n}\n\n.fc-direction-rtl .fc-daygrid-week-number {\n  right: 0;\n  border-radius: 0 0 0 3px;\n}\n\n.fc-daygrid .fc-popover {\n  z-index: 6;\n}\n\n.fc-more-popover .fc-popover-body {\n  padding: 10px !important;\n  min-width: 220px;\n}\n\n.fc-daygrid-event {\n  position: relative;\n  white-space: nowrap;\n  margin: 1px 0;\n  border-radius: 3px;\n  font-size: 0.85em;\n}\n.fc-daygrid-event .fc-event-time,\n.fc-daygrid-event .fc-event-title {\n  display: inline;\n}\n\n.fc-direction-ltr .fc-daygrid-event .fc-event-time {\n  margin-right: 3px;\n}\n\n.fc-direction-rtl .fc-daygrid-event .fc-event-time {\n  margin-left: 3px;\n}\n\n.fc-daygrid-block-event {\n  border: 1px solid #3788d8;\n  background-color: #3788d8;\n}\n.fc-daygrid-block-event .fc-event-main {\n  color: #fff;\n  padding: 1px;\n  overflow: hidden;\n}\n.fc-daygrid-block-event .fc-event-time {\n  font-weight: bold;\n}\n\n.fc-direction-ltr .fc-daygrid-block-event:not(.fc-event-start),\n.fc-direction-rtl .fc-daygrid-block-event:not(.fc-event-end) {\n  border-top-left-radius: 0;\n  border-bottom-left-radius: 0;\n}\n\n.fc-direction-ltr .fc-daygrid-block-event:not(.fc-event-end),\n.fc-direction-rtl .fc-daygrid-block-event:not(.fc-event-start) {\n  border-top-right-radius: 0;\n  border-bottom-right-radius: 0;\n}\n\n.fc-daygrid-dot-event {\n  overflow: hidden;\n  padding: 2px 0;\n}\n.fc-daygrid-dot-event .fc-event-title {\n  font-weight: bold;\n}\n.fc-daygrid-dot-event:hover, .fc-daygrid-dot-event.fc-event-mirror {\n  background: rgba(0, 0, 0, 0.1);\n}\n\n.fc-daygrid-event-dot {\n  display: inline-block;\n  margin: 0 4px;\n  width: 8px;\n  height: 8px;\n  border-radius: 50%;\n  background: #3788d8;\n}\n'},571:function(e,t,n){"use strict";n(517);var r,o,i,a,c,s,l,d=n(1),u={},f=[],h=/acit|ex(?:s|g|n|p|$)|rph|grid|ows|mnc|ntw|ine[ch]|zoo|^ord/i;function p(e,t){for(var n in t)e[n]=t[n];return e}function m(e){var t=e.parentNode;t&&t.removeChild(e)}function v(e,t,n){var r,o=arguments,i={};for(r in t)"key"!==r&&"ref"!==r&&(i[r]=t[r]);if(arguments.length>3)for(n=[n],r=3;r<arguments.length;r++)n.push(o[r]);if(null!=n&&(i.children=n),"function"==typeof e&&null!=e.defaultProps)for(r in e.defaultProps)void 0===i[r]&&(i[r]=e.defaultProps[r]);return g(e,i,t&&t.key,t&&t.ref,null)}function g(e,t,n,o,i){var a={type:e,props:t,key:n,ref:o,__k:null,__:null,__b:0,__e:null,__d:void 0,__c:null,constructor:void 0,__v:i};return null==i&&(a.__v=a),r.vnode&&r.vnode(a),a}function b(){return{}}function y(e){return e.children}function k(e,t){this.props=e,this.context=t}function A(e,t){if(null==t)return e.__?A(e.__,e.__.__k.indexOf(e)+1):null;for(var n;t<e.__k.length;t++)if(null!=(n=e.__k[t])&&null!=n.__e)return n.__e;return"function"==typeof e.type?A(e):null}function _(e){var t,n;if(null!=(e=e.__)&&null!=e.__c){for(e.__e=e.__c.base=null,t=0;t<e.__k.length;t++)if(null!=(n=e.__k[t])&&null!=n.__e){e.__e=e.__c.base=n.__e;break}return _(e)}}function E(e){(!e.__d&&(e.__d=!0)&&o.push(e)&&!i++||c!==r.debounceRendering)&&((c=r.debounceRendering)||a)(x)}function x(){for(var e;i=o.length;)e=o.sort((function(e,t){return e.__v.__b-t.__v.__b})),o=[],e.some((function(e){var t,n,r,o,i,a,c;e.__d&&(a=(i=(t=e).__v).__e,(c=t.__P)&&(n=[],(r=p({},i)).__v=r,o=O(c,i,r,t.__n,void 0!==c.ownerSVGElement,null,n,null==a?A(i):a),T(n,i),o!=a&&_(i)))}))}function w(e,t,n,r,o,i,a,c,s){var l,d,h,p,v,g,b,y=n&&n.__k||f,k=y.length;if(c==u&&(c=null!=i?i[0]:k?A(n,0):null),l=0,t.__k=S(t.__k,(function(n){if(null!=n){if(n.__=t,n.__b=t.__b+1,null===(h=y[l])||h&&n.key==h.key&&n.type===h.type)y[l]=void 0;else for(d=0;d<k;d++){if((h=y[d])&&n.key==h.key&&n.type===h.type){y[d]=void 0;break}h=null}if(p=O(e,n,h=h||u,r,o,i,a,c,s),(d=n.ref)&&h.ref!=d&&(b||(b=[]),h.ref&&b.push(h.ref,null,n),b.push(d,n.__c||p,n)),null!=p){var f;if(null==g&&(g=p),void 0!==n.__d)f=n.__d,n.__d=void 0;else if(i==h||p!=c||null==p.parentNode){e:if(null==c||c.parentNode!==e)e.appendChild(p),f=null;else{for(v=c,d=0;(v=v.nextSibling)&&d<k;d+=2)if(v==p)break e;e.insertBefore(p,c),f=c}"option"==t.type&&(e.value="")}c=void 0!==f?f:p.nextSibling,"function"==typeof t.type&&(t.__d=c)}else c&&h.__e==c&&c.parentNode!=e&&(c=A(h))}return l++,n})),t.__e=g,null!=i&&"function"!=typeof t.type)for(l=i.length;l--;)null!=i[l]&&m(i[l]);for(l=k;l--;)null!=y[l]&&j(y[l],y[l]);if(b)for(l=0;l<b.length;l++)M(b[l],b[++l],b[++l])}function S(e,t,n){if(null==n&&(n=[]),null==e||"boolean"==typeof e)t&&n.push(t(null));else if(Array.isArray(e))for(var r=0;r<e.length;r++)S(e[r],t,n);else n.push(t?t("string"==typeof e||"number"==typeof e?g(null,e,null,null,e):null!=e.__e||null!=e.__c?g(e.type,e.props,e.key,null,e.__v):e):e);return n}function D(e,t,n){"-"===t[0]?e.setProperty(t,n):e[t]="number"==typeof n&&!1===h.test(t)?n+"px":null==n?"":n}function C(e,t,n,r,o){var i,a,c,s,l;if(o?"className"===t&&(t="class"):"class"===t&&(t="className"),"style"===t)if(i=e.style,"string"==typeof n)i.cssText=n;else{if("string"==typeof r&&(i.cssText="",r=null),r)for(s in r)n&&s in n||D(i,s,"");if(n)for(l in n)r&&n[l]===r[l]||D(i,l,n[l])}else"o"===t[0]&&"n"===t[1]?(a=t!==(t=t.replace(/Capture$/,"")),c=t.toLowerCase(),t=(c in e?c:t).slice(2),n?(r||e.addEventListener(t,R,a),(e.l||(e.l={}))[t]=n):e.removeEventListener(t,R,a)):"list"!==t&&"tagName"!==t&&"form"!==t&&"type"!==t&&"size"!==t&&!o&&t in e?e[t]=null==n?"":n:"function"!=typeof n&&"dangerouslySetInnerHTML"!==t&&(t!==(t=t.replace(/^xlink:?/,""))?null==n||!1===n?e.removeAttributeNS("http://www.w3.org/1999/xlink",t.toLowerCase()):e.setAttributeNS("http://www.w3.org/1999/xlink",t.toLowerCase(),n):null==n||!1===n&&!/^ar/.test(t)?e.removeAttribute(t):e.setAttribute(t,n))}function R(e){this.l[e.type](r.event?r.event(e):e)}function O(e,t,n,o,i,a,c,s,l){var d,u,f,h,m,v,g,b,A,_,E=t.type;if(void 0!==t.constructor)return null;(d=r.__b)&&d(t);try{e:if("function"==typeof E){if(b=t.props,A=(d=E.contextType)&&o[d.__c],_=d?A?A.props.value:d.__:o,n.__c?g=(u=t.__c=n.__c).__=u.__E:("prototype"in E&&E.prototype.render?t.__c=u=new E(b,_):(t.__c=u=new k(b,_),u.constructor=E,u.render=N),A&&A.sub(u),u.props=b,u.state||(u.state={}),u.context=_,u.__n=o,f=u.__d=!0,u.__h=[]),null==u.__s&&(u.__s=u.state),null!=E.getDerivedStateFromProps&&(u.__s==u.state&&(u.__s=p({},u.__s)),p(u.__s,E.getDerivedStateFromProps(b,u.__s))),h=u.props,m=u.state,f)null==E.getDerivedStateFromProps&&null!=u.componentWillMount&&u.componentWillMount(),null!=u.componentDidMount&&u.__h.push(u.componentDidMount);else{if(null==E.getDerivedStateFromProps&&b!==h&&null!=u.componentWillReceiveProps&&u.componentWillReceiveProps(b,_),!u.__e&&null!=u.shouldComponentUpdate&&!1===u.shouldComponentUpdate(b,u.__s,_)||t.__v===n.__v&&!u.__){for(u.props=b,u.state=u.__s,t.__v!==n.__v&&(u.__d=!1),u.__v=t,t.__e=n.__e,t.__k=n.__k,u.__h.length&&c.push(u),d=0;d<t.__k.length;d++)t.__k[d]&&(t.__k[d].__=t);break e}null!=u.componentWillUpdate&&u.componentWillUpdate(b,u.__s,_),null!=u.componentDidUpdate&&u.__h.push((function(){u.componentDidUpdate(h,m,v)}))}u.context=_,u.props=b,u.state=u.__s,(d=r.__r)&&d(t),u.__d=!1,u.__v=t,u.__P=e,d=u.render(u.props,u.state,u.context),t.__k=null!=d&&d.type==y&&null==d.key?d.props.children:Array.isArray(d)?d:[d],null!=u.getChildContext&&(o=p(p({},o),u.getChildContext())),f||null==u.getSnapshotBeforeUpdate||(v=u.getSnapshotBeforeUpdate(h,m)),w(e,t,n,o,i,a,c,s,l),u.base=t.__e,u.__h.length&&c.push(u),g&&(u.__E=u.__=null),u.__e=!1}else null==a&&t.__v===n.__v?(t.__k=n.__k,t.__e=n.__e):t.__e=I(n.__e,t,n,o,i,a,c,l);(d=r.diffed)&&d(t)}catch(e){t.__v=null,r.__e(e,t,n)}return t.__e}function T(e,t){r.__c&&r.__c(t,e),e.some((function(t){try{e=t.__h,t.__h=[],e.some((function(e){e.call(t)}))}catch(e){r.__e(e,t.__v)}}))}function I(e,t,n,r,o,i,a,c){var s,l,d,h,p,m=n.props,v=t.props;if(o="svg"===t.type||o,null!=i)for(s=0;s<i.length;s++)if(null!=(l=i[s])&&((null===t.type?3===l.nodeType:l.localName===t.type)||e==l)){e=l,i[s]=null;break}if(null==e){if(null===t.type)return document.createTextNode(v);e=o?document.createElementNS("http://www.w3.org/2000/svg",t.type):document.createElement(t.type,v.is&&{is:v.is}),i=null,c=!1}if(null===t.type)m!==v&&e.data!=v&&(e.data=v);else{if(null!=i&&(i=f.slice.call(e.childNodes)),d=(m=n.props||u).dangerouslySetInnerHTML,h=v.dangerouslySetInnerHTML,!c){if(m===u)for(m={},p=0;p<e.attributes.length;p++)m[e.attributes[p].name]=e.attributes[p].value;(h||d)&&(h&&d&&h.__html==d.__html||(e.innerHTML=h&&h.__html||""))}(function(e,t,n,r,o){var i;for(i in n)"children"===i||"key"===i||i in t||C(e,i,null,n[i],r);for(i in t)o&&"function"!=typeof t[i]||"children"===i||"key"===i||"value"===i||"checked"===i||n[i]===t[i]||C(e,i,t[i],n[i],r)})(e,v,m,o,c),h?t.__k=[]:(t.__k=t.props.children,w(e,t,n,r,"foreignObject"!==t.type&&o,i,a,u,c)),c||("value"in v&&void 0!==(s=v.value)&&s!==e.value&&C(e,"value",s,m.value,!1),"checked"in v&&void 0!==(s=v.checked)&&s!==e.checked&&C(e,"checked",s,m.checked,!1))}return e}function M(e,t,n){try{"function"==typeof e?e(t):e.current=t}catch(e){r.__e(e,n)}}function j(e,t,n){var o,i,a;if(r.unmount&&r.unmount(e),(o=e.ref)&&(o.current&&o.current!==e.__e||M(o,null,t)),n||"function"==typeof e.type||(n=null!=(i=e.__e)),e.__e=e.__d=void 0,null!=(o=e.__c)){if(o.componentWillUnmount)try{o.componentWillUnmount()}catch(e){r.__e(e,t)}o.base=o.__P=null}if(o=e.__k)for(a=0;a<o.length;a++)o[a]&&j(o[a],t,n);null!=i&&m(i)}function N(e,t,n){return this.constructor(e,n)}function P(e,t,n){var o,i,a;r.__&&r.__(e,t),i=(o=n===s)?null:n&&n.__k||t.__k,e=v(y,null,[e]),a=[],O(t,(o?t:n||t).__k=e,i||u,u,void 0!==t.ownerSVGElement,n&&!o?[n]:i?null:f.slice.call(t.childNodes),a,n||u,o),T(a,e)}function B(e,t,n){if(e===t)return!0;var r,o=e.length;if(o!==t.length)return!1;for(r=0;r<o;r++)if(!(n?n(e[r],t[r]):e[r]===t[r]))return!1;return!0}function H(e){e.parentNode&&e.parentNode.removeChild(e)}function z(e,t){e.innerHTML=t}function U(e,t){var n=Array.prototype.slice.call(e.childNodes),r=Array.prototype.slice.call(t);if(!B(n,r)){for(var o=0,i=r;o<i.length;o++){var a=i[o];e.appendChild(a)}n.forEach(H)}}r={__e:function(e,t){for(var n,r;t=t.__;)if((n=t.__c)&&!n.__)try{if(n.constructor&&null!=n.constructor.getDerivedStateFromError&&(r=!0,n.setState(n.constructor.getDerivedStateFromError(e))),null!=n.componentDidCatch&&(r=!0,n.componentDidCatch(e)),r)return E(n.__E=n)}catch(t){e=t}throw e}},k.prototype.setState=function(e,t){var n;n=this.__s!==this.state?this.__s:this.__s=p({},this.state),"function"==typeof e&&(e=e(n,this.props)),e&&p(n,e),null!=e&&this.__v&&(t&&this.__h.push(t),E(this))},k.prototype.forceUpdate=function(e){this.__v&&(this.__e=!0,e&&this.__h.push(e),E(this))},k.prototype.render=y,o=[],i=0,a="function"==typeof Promise?Promise.prototype.then.bind(Promise.resolve()):setTimeout,s=u,l=0,n.d(t,"a",(function(){return Rn})),n.d(t,"b",(function(){return No})),n.d(t,"c",(function(){return Gr})),n.d(t,"d",(function(){return Mn})),n.d(t,"e",(function(){return er})),n.d(t,"f",(function(){return Io})),n.d(t,"g",(function(){return To})),n.d(t,"h",(function(){return co})),n.d(t,"i",(function(){return lo})),n.d(t,"j",(function(){return uo})),n.d(t,"k",(function(){return Fr})),n.d(t,"l",(function(){return xt})),n.d(t,"m",(function(){return Do})),n.d(t,"o",(function(){return io})),n.d(t,"p",(function(){return kn})),n.d(t,"q",(function(){return vo})),n.d(t,"r",(function(){return fr})),n.d(t,"s",(function(){return So})),n.d(t,"t",(function(){return fo})),n.d(t,"u",(function(){return Co})),n.d(t,"v",(function(){return br})),n.d(t,"w",(function(){return Bo})),n.d(t,"x",(function(){return X})),n.d(t,"y",(function(){return J})),n.d(t,"z",(function(){return Z})),n.d(t,"A",(function(){return hn})),n.d(t,"B",(function(){return Nt})),n.d(t,"C",(function(){return bt})),n.d(t,"D",(function(){return Er})),n.d(t,"F",(function(){return te})),n.d(t,"G",(function(){return ee})),n.d(t,"H",(function(){return Pt})),n.d(t,"I",(function(){return wo})),n.d(t,"J",(function(){return xo})),n.d(t,"L",(function(){return tt})),n.d(t,"M",(function(){return Fe})),n.d(t,"N",(function(){return He})),n.d(t,"O",(function(){return at})),n.d(t,"P",(function(){return jo})),n.d(t,"Q",(function(){return Eo})),n.d(t,"R",(function(){return In})),n.d(t,"S",(function(){return Ot})),n.d(t,"n",(function(){return y})),n.d(t,"E",(function(){return b})),n.d(t,"K",(function(){return v}));var F=Element.prototype.matches||Element.prototype.matchesSelector||Element.prototype.msMatchesSelector,L=Element.prototype.closest||function(e){var t=this;if(!document.documentElement.contains(t))return null;do{if(V(t,e))return t;t=t.parentElement||t.parentNode}while(null!==t&&1===t.nodeType);return null};function Q(e,t){return L.call(e,t)}function V(e,t){return F.call(e,t)}var W=/(top|left|right|bottom|width|height)$/i;function Z(e,t){for(var n in t)G(e,n,t[n])}function G(e,t,n){null==n?e.style[t]="":"number"==typeof n&&W.test(t)?e.style[t]=n+"px":e.style[t]=n}function Y(e,t){return function(n){var r=Q(n.target,e);r&&t.call(r,n,r)}}function q(e,t,n,r){var o=Y(n,r);return e.addEventListener(t,o),function(){e.removeEventListener(t,o)}}var K=["sun","mon","tue","wed","thu","fri","sat"];function J(e,t){var n=se(e);return n[2]+=7*t,le(n)}function X(e,t){var n=se(e);return n[2]+=t,le(n)}function $(e,t){var n=se(e);return n[6]+=t,le(n)}function ee(e,t){return te(e,t)/7}function te(e,t){return(t.valueOf()-e.valueOf())/864e5}function ne(e,t){return ue(e)===ue(t)?Math.round(te(e,t)):null}function re(e){return le([e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate()])}function oe(e,t,n,r){var o=le([t,0,1+ie(t,n,r)]),i=re(e),a=Math.round(te(o,i));return Math.floor(a/7)+1}function ie(e,t,n){var r=7+t-n;return-((7+le([e,0,r]).getUTCDay()-t)%7)+r-1}function ae(e){return[e.getFullYear(),e.getMonth(),e.getDate(),e.getHours(),e.getMinutes(),e.getSeconds(),e.getMilliseconds()]}function ce(e){return new Date(e[0],e[1]||0,null==e[2]?1:e[2],e[3]||0,e[4]||0,e[5]||0)}function se(e){return[e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate(),e.getUTCHours(),e.getUTCMinutes(),e.getUTCSeconds(),e.getUTCMilliseconds()]}function le(e){return 1===e.length&&(e=e.concat([0])),new Date(Date.UTC.apply(Date,e))}function de(e){return!isNaN(e.valueOf())}function ue(e){return 1e3*e.getUTCHours()*60*60+1e3*e.getUTCMinutes()*60+1e3*e.getUTCSeconds()+e.getUTCMilliseconds()}var fe=/^(-?)(?:(\d+)\.)?(\d+):(\d\d)(?::(\d\d)(?:\.(\d\d\d))?)?/;function he(e,t){var n;return"string"==typeof e?function(e){var t=fe.exec(e);if(t){var n=t[1]?-1:1;return{years:0,months:0,days:n*(t[2]?parseInt(t[2],10):0),milliseconds:n*(60*(t[3]?parseInt(t[3],10):0)*60*1e3+60*(t[4]?parseInt(t[4],10):0)*1e3+1e3*(t[5]?parseInt(t[5],10):0)+(t[6]?parseInt(t[6],10):0))}}return null}(e):"object"==typeof e&&e?pe(e):"number"==typeof e?pe(((n={})[t||"milliseconds"]=e,n)):null}function pe(e){return{years:e.years||e.year||0,months:e.months||e.month||0,days:(e.days||e.day||0)+7*me(e),milliseconds:60*(e.hours||e.hour||0)*60*1e3+60*(e.minutes||e.minute||0)*1e3+1e3*(e.seconds||e.second||0)+(e.milliseconds||e.millisecond||e.ms||0)}}function me(e){return e.weeks||e.week||0}function ve(e,t){return e.years===t.years&&e.months===t.months&&e.days===t.days&&e.milliseconds===t.milliseconds}function ge(e){return be(e)/864e5}function be(e){return 31536e6*e.years+2592e6*e.months+864e5*e.days+e.milliseconds}function ye(e,t){var n=e.milliseconds;if(n){if(n%1e3!=0)return{unit:"millisecond",value:n};if(n%6e4!=0)return{unit:"second",value:n/1e3};if(n%36e5!=0)return{unit:"minute",value:n/6e4};if(n)return{unit:"hour",value:n/36e5}}return e.days?t||e.days%7!=0?{unit:"day",value:e.days}:{unit:"week",value:e.days/7}:e.months?{unit:"month",value:e.months}:e.years?{unit:"year",value:e.years}:{unit:"millisecond",value:0}}var ke=0;function Ae(){return String(ke++)}function _e(e){var t,n,r=[],o=[];for("string"==typeof e?o=e.split(/\s*,\s*/):"function"==typeof e?o=[e]:Array.isArray(e)&&(o=e),t=0;t<o.length;t++)"string"==typeof(n=o[t])?r.push("-"===n.charAt(0)?{field:n.substring(1),order:-1}:{field:n,order:1}):"function"==typeof n&&r.push({func:n});return r}function Ee(e,t,n){return n.func?n.func(e,t):function(e,t){if(!e&&!t)return 0;if(null==t)return-1;if(null==e)return 1;if("string"==typeof e||"string"==typeof t)return String(e).localeCompare(String(t));return e-t}(e[n.field],t[n.field])*(n.order||1)}function xe(e){return e.charAt(0).toUpperCase()+e.slice(1)}function we(e,t){var n=String(e);return"000".substr(0,t-n.length)+n}function Se(e){return e%1==0}function De(e,t,n){if("function"==typeof e&&(e=[e]),e){var r=void 0,o=void 0;for(r=0;r<e.length;r++)o=e[r].apply(t,n)||o;return o}}function Ce(){for(var e=[],t=0;t<arguments.length;t++)e[t]=arguments[t];for(var n=0;n<e.length;n++)if(void 0!==e[n])return e[n]}function Re(e,t,n,r){void 0===n&&(n={});var o={};for(var i in t){var a=t[i];void 0!==e[i]?o[i]=a===Function?"function"==typeof e[i]?e[i]:null:a?a(e[i]):e[i]:void 0!==n[i]?o[i]=n[i]:a===String?o[i]="":a&&a!==Number&&a!==Boolean&&a!==Function?o[i]=a(null):o[i]=null}if(r)for(var i in e)void 0===t[i]&&(r[i]=e[i]);return o}function Oe(e){var t=Math.floor(te(e.start,e.end))||1,n=re(e.start);return{start:n,end:X(n,t)}}function Te(e,t){void 0===t&&(t=he(0));var n=null,r=null;if(e.end){r=re(e.end);var o=e.end.valueOf()-r.valueOf();o&&o>=be(t)&&(r=X(r,1))}return e.start&&(n=re(e.start),r&&r<=n&&(r=X(n,1))),{start:n,end:r}}function Ie(e,t,n,r){return"year"===r?he(n.diffWholeYears(e,t),"year"):"month"===r?he(n.diffWholeMonths(e,t),"month"):(i=t,a=re(o=e),c=re(i),{years:0,months:0,days:Math.round(te(a,c)),milliseconds:i.valueOf()-c.valueOf()-(o.valueOf()-a.valueOf())});var o,i,a,c}function Me(e){var t=e.querySelector(".fc-scrollgrid-shrink-frame"),n=e.querySelector(".fc-scrollgrid-shrink-cushion");if(!t)throw new Error("needs fc-scrollgrid-shrink-frame className");if(!n)throw new Error("needs fc-scrollgrid-shrink-cushion className");return e.getBoundingClientRect().width-t.getBoundingClientRect().width+n.getBoundingClientRect().width}function je(e,t,n,r,o){var i=o[e.recurringDef.typeId].expand(e.recurringDef.typeData,{start:r.subtract(n.start,t),end:n.end},r);return e.allDay&&(i=i.map(re)),i}var Ne=Object.prototype.hasOwnProperty;function Pe(e,t){var n,r,o,i,a,c,s={};if(t)for(n=0;n<t.length;n++){for(r=t[n],o=[],i=e.length-1;i>=0;i--)if("object"==typeof(a=e[i][r])&&a)o.unshift(a);else if(void 0!==a){s[r]=a;break}o.length&&(s[r]=Pe(o))}for(n=e.length-1;n>=0;n--)for(r in c=e[n])r in s||(s[r]=c[r]);return s}function Be(e,t){var n={};for(var r in e)t(e[r],r)&&(n[r]=e[r]);return n}function He(e,t){var n={};for(var r in e)n[r]=t(e[r],r);return n}function ze(e){for(var t={},n=0,r=e;n<r.length;n++){t[r[n]]=!0}return t}function Ue(e){var t=[];for(var n in e)t.push(e[n]);return t}function Fe(e,t){if(e===t)return!0;for(var n in e)if(Ne.call(e,n)&&!(n in t))return!1;for(var n in t)if(Ne.call(t,n)&&e[n]!==t[n])return!1;return!0}function Le(e,t){var n=[];for(var r in e)Ne.call(e,r)&&(r in t||n.push(r));for(var r in t)Ne.call(t,r)&&e[r]!==t[r]&&n.push(r);return n}function Qe(e,t,n){if(void 0===n&&(n={}),e===t)return!0;for(var r in t)if(!(r in e)||!Ve(e[r],t[r],n[r]))return!1;for(var r in e)if(!(r in t))return!1;return!0}function Ve(e,t,n){return e===t||!0===n||!!n&&n(e,t)}function We(e,t,n,r){for(var o={defs:{},instances:{}},i=0,a=e;i<a.length;i++){var c=rn(a[i],t,n,r);c&&Ze(c,o)}return o}function Ze(e,t){return void 0===t&&(t={defs:{},instances:{}}),t.defs[e.def.defId]=e.def,e.instance&&(t.instances[e.instance.instanceId]=e.instance),t}function Ge(e,t,n){var r=n.dateEnv,o=e.defs,i=e.instances;for(var a in i=Be(i,(function(e){return!o[e.defId].recurringDef})),o){var c=o[a];if(c.recurringDef){var s=c.recurringDef.duration;s||(s=c.allDay?n.defaultAllDayEventDuration:n.defaultTimedEventDuration);for(var l=0,d=je(c,s,t,n.dateEnv,n.pluginSystem.hooks.recurringTypes);l<d.length;l++){var u=d[l],f=an(a,{start:u,end:r.add(u,s)});i[f.instanceId]=f}}}return{defs:o,instances:i}}function Ye(e,t){var n=e.instances[t];if(n){var r=e.defs[n.defId],o=Je(e,(function(e){return t=r,n=e,Boolean(t.groupId&&t.groupId===n.groupId);var t,n}));return o.defs[r.defId]=r,o.instances[n.instanceId]=n,o}return{defs:{},instances:{}}}function qe(e,t){var n;if(t){n=[];for(var r=0,o=e;r<o.length;r++){var i=o[r],a=t(i);a?n.push(a):null==a&&n.push(i)}}else n=e;return n}function Ke(e,t){return{defs:Object(d.a)(Object(d.a)({},e.defs),t.defs),instances:Object(d.a)(Object(d.a)({},e.instances),t.instances)}}function Je(e,t){var n=Be(e.defs,t),r=Be(e.instances,(function(e){return n[e.defId]}));return{defs:n,instances:r}}function Xe(e,t){var n=null,r=null;return e.start&&(n=t.createMarker(e.start)),e.end&&(r=t.createMarker(e.end)),n||r?n&&r&&r<n?null:{start:n,end:r}:null}function $e(e,t){var n,r,o=[],i=t.start;for(e.sort(et),n=0;n<e.length;n++)(r=e[n]).start>i&&o.push({start:i,end:r.start}),r.end>i&&(i=r.end);return i<t.end&&o.push({start:i,end:t.end}),o}function et(e,t){return e.start.valueOf()-t.start.valueOf()}function tt(e,t){var n=e.start,r=e.end,o=null;return null!==t.start&&(n=null===n?t.start:new Date(Math.max(n.valueOf(),t.start.valueOf()))),null!=t.end&&(r=null===r?t.end:new Date(Math.min(r.valueOf(),t.end.valueOf()))),(null===n||null===r||n<r)&&(o={start:n,end:r}),o}function nt(e,t){return(null===e.start?null:e.start.valueOf())===(null===t.start?null:t.start.valueOf())&&(null===e.end?null:e.end.valueOf())===(null===t.end?null:t.end.valueOf())}function rt(e,t){return(null===e.end||null===t.start||e.end>t.start)&&(null===e.start||null===t.end||e.start<t.end)}function ot(e,t){return(null===e.start||null!==t.start&&t.start>=e.start)&&(null===e.end||null!==t.end&&t.end<=e.end)}function it(e,t){return(null===e.start||t>=e.start)&&(null===e.end||t<e.end)}function at(e,t,n){var r,o;return function(){for(var i=[],a=0;a<arguments.length;a++)i[a]=arguments[a];if(r){if(!B(r,i)){n&&n(o);var c=e.apply(this,i);t&&t(c,o)||(o=c)}}else o=e.apply(this,i);return r=i,o}}var ct={week:3,separator:0,omitZeroMinute:0,meridiem:0,omitCommas:0},st={timeZoneName:7,era:6,year:5,month:4,day:2,weekday:2,hour:1,minute:1,second:1},lt=/\s*([ap])\.?m\.?/i,dt=/,/g,ut=/\s+/g,ft=/\u200e/g,ht=/UTC|GMT/,pt=function(){function e(e){var t={},n={},r=0;for(var o in e)o in ct?(n[o]=e[o],r=Math.max(ct[o],r)):(t[o]=e[o],o in st&&(r=Math.max(st[o],r)));this.standardDateProps=t,this.extendedSettings=n,this.severity=r,this.buildFormattingFunc=at(mt)}return e.prototype.format=function(e,t){return this.buildFormattingFunc(this.standardDateProps,this.extendedSettings,t)(e)},e.prototype.formatRange=function(e,t,n){var r=this.standardDateProps,o=this.extendedSettings,i=function(e,t,n){if(n.getMarkerYear(e)!==n.getMarkerYear(t))return 5;if(n.getMarkerMonth(e)!==n.getMarkerMonth(t))return 4;if(n.getMarkerDay(e)!==n.getMarkerDay(t))return 2;if(ue(e)!==ue(t))return 1;return 0}(e.marker,t.marker,n.calendarSystem);if(!i)return this.format(e,n);var a=i;!(a>1)||"numeric"!==r.year&&"2-digit"!==r.year||"numeric"!==r.month&&"2-digit"!==r.month||"numeric"!==r.day&&"2-digit"!==r.day||(a=1);var c=this.format(e,n),s=this.format(t,n);if(c===s)return c;var l=mt(function(e,t){var n={};for(var r in e)(!(r in st)||st[r]<=t)&&(n[r]=e[r]);return n}(r,a),o,n),d=l(e),u=l(t),f=function(e,t,n,r){var o=0;for(;o<e.length;){var i=e.indexOf(t,o);if(-1===i)break;var a=e.substr(0,i);o=i+t.length;for(var c=e.substr(o),s=0;s<n.length;){var l=n.indexOf(r,s);if(-1===l)break;var d=n.substr(0,l);s=l+r.length;var u=n.substr(s);if(a===d&&c===u)return{before:a,after:c}}}return null}(c,d,s,u),h=o.separator||"";return f?f.before+d+h+u+f.after:c+h+s},e.prototype.getLargestUnit=function(){switch(this.severity){case 7:case 6:case 5:return"year";case 4:return"month";case 3:return"week";case 2:return"day";default:return"time"}},e}();function mt(e,t,n){var r=Object.keys(e).length;return 1===r&&"short"===e.timeZoneName?function(e){return kt(e.timeZoneOffset)}:0===r&&t.week?function(e){return function(e,t,n,r){var o=[];"narrow"===r?o.push(t):"short"===r&&o.push(t," ");o.push(n.simpleNumberFormat.format(e)),n.options.isRtl&&o.reverse();return o.join("")}(n.computeWeekNumber(e.marker),n.weekText,n.locale,t.week)}:function(e,t,n){e=Object(d.a)({},e),t=Object(d.a)({},t),function(e,t){e.timeZoneName&&(e.hour||(e.hour="2-digit"),e.minute||(e.minute="2-digit"));"long"===e.timeZoneName&&(e.timeZoneName="short");t.omitZeroMinute&&(e.second||e.millisecond)&&delete t.omitZeroMinute}(e,t),e.timeZone="UTC";var r,o=new Intl.DateTimeFormat(n.locale.codes,e);if(t.omitZeroMinute){var i=Object(d.a)({},e);delete i.minute,r=new Intl.DateTimeFormat(n.locale.codes,i)}return function(i){var a=i.marker;return function(e,t,n,r,o){e=e.replace(ft,""),"short"===n.timeZoneName&&(e=function(e,t){var n=!1;e=e.replace(ht,(function(){return n=!0,t})),n||(e+=" "+t);return e}(e,"UTC"===o.timeZone||null==t.timeZoneOffset?"UTC":kt(t.timeZoneOffset)));r.omitCommas&&(e=e.replace(dt,"").trim());r.omitZeroMinute&&(e=e.replace(":00",""));!1===r.meridiem?e=e.replace(lt,"").trim():"narrow"===r.meridiem?e=e.replace(lt,(function(e,t){return t.toLocaleLowerCase()})):"short"===r.meridiem?e=e.replace(lt,(function(e,t){return t.toLocaleLowerCase()+"m"})):"lowercase"===r.meridiem&&(e=e.replace(lt,(function(e){return e.toLocaleLowerCase()})));return e=(e=e.replace(ut," ")).trim()}((r&&!a.getUTCMinutes()?r:o).format(a),i,e,t,n)}}(e,t,n)}var vt=function(){function e(e,t){this.cmdStr=e,this.separator=t}return e.prototype.format=function(e,t){return t.cmdFormatter(this.cmdStr,At(e,null,t,this.separator))},e.prototype.formatRange=function(e,t,n){return n.cmdFormatter(this.cmdStr,At(e,t,n,this.separator))},e}(),gt=function(){function e(e){this.func=e}return e.prototype.format=function(e,t){return this.func(At(e,null,t))},e.prototype.formatRange=function(e,t,n){return this.func(At(e,t,n))},e}();function bt(e,t){return"object"==typeof e&&e?("string"==typeof t&&(e=Object(d.a)({separator:t},e)),new pt(e)):"string"==typeof e?new vt(e,t):"function"==typeof e?new gt(e):void 0}function yt(e){return e.toISOString().replace(/T.*$/,"")}function kt(e,t){void 0===t&&(t=!1);var n=e<0?"-":"+",r=Math.abs(e),o=Math.floor(r/60),i=Math.round(r%60);return t?n+we(o,2)+":"+we(i,2):"GMT"+n+o+(i?":"+we(i,2):"")}function At(e,t,n,r){var o=_t(e,n.calendarSystem);return{date:o,start:o,end:t?_t(t,n.calendarSystem):null,timeZone:n.timeZone,localeCodes:n.locale.codes,separator:r}}function _t(e,t){var n=t.markerToArray(e.marker);return{marker:e.marker,timeZoneOffset:e.timeZoneOffset,array:n,year:n[0],month:n[1],day:n[2],hour:n[3],minute:n[4],second:n[5],millisecond:n[6]}}var Et=function(){function e(e,t){this.calendar=e,this.internalEventSource=t}return e.prototype.remove=function(){this.calendar.dispatch({type:"REMOVE_EVENT_SOURCE",sourceId:this.internalEventSource.sourceId})},e.prototype.refetch=function(){this.calendar.dispatch({type:"FETCH_EVENT_SOURCES",sourceIds:[this.internalEventSource.sourceId]})},Object.defineProperty(e.prototype,"id",{get:function(){return this.internalEventSource.publicId},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"url",{get:function(){return this.internalEventSource.meta.url},enumerable:!0,configurable:!0}),e}(),xt=function(){function e(e,t,n){this._calendar=e,this._def=t,this._instance=n||null}return e.prototype.setProp=function(e,t){var n,r;if(e in nn);else if(e in tn)"function"==typeof tn[e]&&(t=tn[e](t)),this.mutate({standardProps:(n={},n[e]=t,n)});else if(e in qt){var o=void 0;"function"==typeof qt[e]&&(t=qt[e](t)),"color"===e?o={backgroundColor:t,borderColor:t}:"editable"===e?o={startEditable:t,durationEditable:t}:((r={})[e]=t,o=r),this.mutate({standardProps:{ui:o}})}},e.prototype.setExtendedProp=function(e,t){var n;this.mutate({extendedProps:(n={},n[e]=t,n)})},e.prototype.setStart=function(e,t){void 0===t&&(t={});var n=this._calendar.dateEnv,r=n.createMarker(e);if(r&&this._instance){var o=Ie(this._instance.range.start,r,n,t.granularity);t.maintainDuration?this.mutate({datesDelta:o}):this.mutate({startDelta:o})}},e.prototype.setEnd=function(e,t){void 0===t&&(t={});var n,r=this._calendar.dateEnv;if((null==e||(n=r.createMarker(e)))&&this._instance)if(n){var o=Ie(this._instance.range.end,n,r,t.granularity);this.mutate({endDelta:o})}else this.mutate({standardProps:{hasEnd:!1}})},e.prototype.setDates=function(e,t,n){void 0===n&&(n={});var r,o=this._calendar.dateEnv,i={allDay:n.allDay},a=o.createMarker(e);if(a&&(null==t||(r=o.createMarker(t)))&&this._instance){var c=this._instance.range;!0===n.allDay&&(c=Oe(c));var s=Ie(c.start,a,o,n.granularity);if(r){var l=Ie(c.end,r,o,n.granularity);ve(s,l)?this.mutate({datesDelta:s,standardProps:i}):this.mutate({startDelta:s,endDelta:l,standardProps:i})}else i.hasEnd=!1,this.mutate({datesDelta:s,standardProps:i})}},e.prototype.moveStart=function(e){var t=he(e);t&&this.mutate({startDelta:t})},e.prototype.moveEnd=function(e){var t=he(e);t&&this.mutate({endDelta:t})},e.prototype.moveDates=function(e){var t=he(e);t&&this.mutate({datesDelta:t})},e.prototype.setAllDay=function(e,t){void 0===t&&(t={});var n={allDay:e},r=t.maintainDuration;null==r&&(r=this._calendar.opt("allDayMaintainDuration")),this._def.allDay!==e&&(n.hasEnd=r),this.mutate({standardProps:n})},e.prototype.formatRange=function(e){var t=this._calendar.dateEnv,n=this._instance,r=bt(e,this._calendar.opt("defaultRangeSeparator"));return this._def.hasEnd?t.formatRange(n.range.start,n.range.end,r,{forcedStartTzo:n.forcedStartTzo,forcedEndTzo:n.forcedEndTzo}):t.format(n.range.start,r,{forcedTzo:n.forcedStartTzo})},e.prototype.mutate=function(e){var t=this._def,n=this._instance;if(n){this._calendar.dispatch({type:"MUTATE_EVENTS",instanceId:n.instanceId,mutation:e,fromApi:!0});var r=this._calendar.state.eventStore;this._def=r.defs[t.defId],this._instance=r.instances[n.instanceId]}},e.prototype.remove=function(){this._calendar.dispatch({type:"REMOVE_EVENT_DEF",defId:this._def.defId})},Object.defineProperty(e.prototype,"source",{get:function(){var e=this._def.sourceId;return e?new Et(this._calendar,this._calendar.state.eventSources[e]):null},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"start",{get:function(){return this._instance?this._calendar.dateEnv.toDate(this._instance.range.start):null},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"end",{get:function(){return this._instance&&this._def.hasEnd?this._calendar.dateEnv.toDate(this._instance.range.end):null},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"id",{get:function(){return this._def.publicId},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"groupId",{get:function(){return this._def.groupId},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"allDay",{get:function(){return this._def.allDay},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"title",{get:function(){return this._def.title},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"url",{get:function(){return this._def.url},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"display",{get:function(){return this._def.ui.display||"auto"},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"startEditable",{get:function(){return this._def.ui.startEditable},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"durationEditable",{get:function(){return this._def.ui.durationEditable},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"constraint",{get:function(){return this._def.ui.constraints[0]||null},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"overlap",{get:function(){return this._def.ui.overlap},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"allow",{get:function(){return this._def.ui.allows[0]||null},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"backgroundColor",{get:function(){return this._def.ui.backgroundColor},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"borderColor",{get:function(){return this._def.ui.borderColor},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"textColor",{get:function(){return this._def.ui.textColor},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"classNames",{get:function(){return this._def.ui.classNames},enumerable:!0,configurable:!0}),Object.defineProperty(e.prototype,"extendedProps",{get:function(){return this._def.extendedProps},enumerable:!0,configurable:!0}),e}();function wt(e,t,n,r){var o={},i={},a={},c=[],s=[],l=Ct(e.defs,t);for(var d in e.defs){"inverse-background"===(h=l[(k=e.defs[d]).defId]).display&&(k.groupId?(o[k.groupId]=[],a[k.groupId]||(a[k.groupId]=k)):i[d]=[])}for(var u in e.instances){var f=e.instances[u],h=l[(k=e.defs[f.defId]).defId],p=f.range,m=!k.allDay&&r?Te(p,r):p,v=tt(m,n);v&&("inverse-background"===h.display?k.groupId?o[k.groupId].push(v):i[f.defId].push(v):"none"!==h.display&&("background"===h.display?c:s).push({def:k,ui:h,instance:f,range:v,isStart:m.start&&m.start.valueOf()===v.start.valueOf(),isEnd:m.end&&m.end.valueOf()===v.end.valueOf()}))}for(var g in o)for(var b=0,y=$e(o[g],n);b<y.length;b++){var k,A=y[b];h=l[(k=a[g]).defId];c.push({def:k,ui:h,instance:null,range:A,isStart:!1,isEnd:!1})}for(var d in i)for(var _=0,E=$e(i[d],n);_<E.length;_++){A=E[_];c.push({def:e.defs[d],ui:l[d],instance:null,range:A,isStart:!1,isEnd:!1})}return{bg:c,fg:s}}function St(e,t){e.fcSeg=t}function Dt(e){return e.fcSeg||e.parentNode.fcSeg||null}function Ct(e,t){return He(e,(function(e){return Rt(e,t)}))}function Rt(e,t){var n=[];return t[""]&&n.push(t[""]),t[e.defId]&&n.push(t[e.defId]),n.push(e.ui),$t(n)}function Ot(e,t){var n=e.map(Tt);return n.sort((function(e,n){return function(e,t,n){var r,o;for(r=0;r<n.length;r++)if(o=Ee(e,t,n[r]))return o;return 0}(e,n,t)})),n.map((function(e){return e._seg}))}function Tt(e){var t=e.eventRange,n=t.def,r=t.instance?t.instance.range:t.range,o=r.start?r.start.valueOf():0,i=r.end?r.end.valueOf():0;return Object(d.a)(Object(d.a)(Object(d.a)({},n.extendedProps),n),{id:n.publicId,start:o,end:i,duration:i-o,allDay:Number(n.allDay),_seg:e})}function It(e,t){for(var n=t.pluginHooks,r=t.calendar,o=n.isDraggableTransformers,i=e.eventRange,a=i.def,c=i.ui,s=c.startEditable,l=0,d=o;l<d.length;l++){s=(0,d[l])(s,a,c,r)}return s}function Mt(e,t){return e.isStart&&e.eventRange.ui.durationEditable&&t.options.eventResizableFromStart}function jt(e,t){return e.isEnd&&e.eventRange.ui.durationEditable}function Nt(e,t,n,r,o,i,a){var c=n.dateEnv,s=n.options,l=s.displayEventTime,d=s.displayEventEnd,u=e.eventRange.def,f=e.eventRange.instance;if(null==l&&(l=!1!==r),null==d&&(d=!1!==o),l&&!u.allDay&&(e.isStart||e.isEnd)){var h=i||(e.isStart?f.range.start:e.start||e.eventRange.range.start),p=a||(e.isEnd?f.range.end:e.end||e.eventRange.range.end);return d&&u.hasEnd?c.formatRange(h,p,t,{forcedStartTzo:i?null:f.forcedStartTzo,forcedEndTzo:a?null:f.forcedEndTzo}):c.format(h,t,{forcedTzo:i?null:f.forcedStartTzo})}return""}function Pt(e,t,n){var r=e.eventRange.range;return{isPast:r.end<(n||t.start),isFuture:r.start>=(n||t.end),isToday:t&&it(t,r.start)}}function Bt(e,t,n,r,o){var i=n.standardProps||{};null==i.hasEnd&&t.durationEditable&&(n.startDelta||n.endDelta)&&(i.hasEnd=!0);var a=Object(d.a)(Object(d.a)(Object(d.a)({},e),i),{ui:Object(d.a)(Object(d.a)({},e.ui),i.ui)});n.extendedProps&&(a.extendedProps=Object(d.a)(Object(d.a)({},a.extendedProps),n.extendedProps));for(var c=0,s=r;c<s.length;c++){(0,s[c])(a,n,o)}return!a.hasEnd&&o.opt("forceEventDuration")&&(a.hasEnd=!0),a}function Ht(e,t,n,r,o){var i=o.dateEnv,a=r.standardProps&&!0===r.standardProps.allDay,c=r.standardProps&&!1===r.standardProps.hasEnd,s=Object(d.a)({},e);return a&&(s.range=Oe(s.range)),r.datesDelta&&n.startEditable&&(s.range={start:i.add(s.range.start,r.datesDelta),end:i.add(s.range.end,r.datesDelta)}),r.startDelta&&n.durationEditable&&(s.range={start:i.add(s.range.start,r.startDelta),end:s.range.end}),r.endDelta&&n.durationEditable&&(s.range={start:s.range.start,end:i.add(s.range.end,r.endDelta)}),c&&(s.range={start:s.range.start,end:o.getDefaultEventEnd(t.allDay,s.range.start)}),t.allDay&&(s.range={start:re(s.range.start),end:re(s.range.end)}),s.range.end<s.range.start&&(s.range.end=o.getDefaultEventEnd(t.allDay,s.range.start)),s}function zt(e,t,n,r,o){switch(t.type){case"RECEIVE_EVENTS":return function(e,t,n,r,o,i){if(t&&n===t.latestFetchId){var a=We(function(e,t,n){var r=n.opt("eventDataTransform"),o=t?t.eventDataTransform:null;return o&&(e=qe(e,o)),r&&(e=qe(e,r)),e}(o,t,i),t.sourceId,i);return r&&(a=Ge(a,r,i)),Ke(Ut(e,t.sourceId),a)}return e}(e,n[t.sourceId],t.fetchId,t.fetchRange,t.rawEvents,o);case"ADD_EVENTS":return function(e,t,n,r){n&&(t=Ge(t,n,r));return Ke(e,t)}(e,t.eventStore,r?r.activeRange:null,o);case"MERGE_EVENTS":return Ke(e,t.eventStore);case"PREV":case"NEXT":case"SET_DATE":case"SET_VIEW_TYPE":return r?Ge(e,r.activeRange,o):e;case"CHANGE_TIMEZONE":return function(e,t,n){var r=e.defs,o=He(e.instances,(function(e){var o=r[e.defId];return o.allDay||o.recurringDef?e:Object(d.a)(Object(d.a)({},e),{range:{start:n.createMarker(t.toDate(e.range.start,e.forcedStartTzo)),end:n.createMarker(t.toDate(e.range.end,e.forcedEndTzo))},forcedStartTzo:n.canComputeOffset?null:e.forcedStartTzo,forcedEndTzo:n.canComputeOffset?null:e.forcedEndTzo})}));return{defs:r,instances:o}}(e,t.oldDateEnv,o.dateEnv);case"MUTATE_EVENTS":return function(e,t,n,r,o){var i=Ye(e,t),a=r?{"":{display:"",startEditable:!0,durationEditable:!0,constraints:[],overlap:null,allows:[],backgroundColor:"",borderColor:"",textColor:"",classNames:[]}}:o.eventUiBases;return i=function(e,t,n,r){var o=Ct(e.defs,t),i={defs:{},instances:{}};for(var a in e.defs){var c=e.defs[a];i.defs[a]=Bt(c,o[a],n,r.pluginSystem.hooks.eventDefMutationAppliers,r)}for(var s in e.instances){var l=e.instances[s];c=i.defs[l.defId];i.instances[s]=Ht(l,c,o[l.defId],n,r)}return i}(i,a,n,o),Ke(e,i)}(e,t.instanceId,t.mutation,t.fromApi,o);case"REMOVE_EVENT_INSTANCES":return Ft(e,t.instances);case"REMOVE_EVENT_DEF":return Je(e,(function(e){return e.defId!==t.defId}));case"REMOVE_EVENT_SOURCE":return Ut(e,t.sourceId);case"REMOVE_ALL_EVENT_SOURCES":return Je(e,(function(e){return!e.sourceId}));case"REMOVE_ALL_EVENTS":return{defs:{},instances:{}};default:return e}}function Ut(e,t){return Je(e,(function(e){return e.sourceId!==t}))}function Ft(e,t){return{defs:e.defs,instances:Be(e.instances,(function(e){return!t[e.instanceId]}))}}function Lt(e,t){var n=t.component.view,r=Object(d.a)({businessHours:n?n.props.businessHours:{defs:{},instances:{}},dateSelection:"",eventStore:t.state.eventStore,eventUiBases:t.eventUiBases,eventSelection:"",eventDrag:null,eventResize:null},e);return(t.pluginSystem.hooks.isPropsValid||Qt)(r,t)}function Qt(e,t,n,r){return void 0===n&&(n={}),!(e.eventDrag&&!function(e,t,n,r){var o=e.eventDrag,i=o.mutatedEvents,a=i.defs,c=i.instances,s=Ct(a,o.isEvent?e.eventUiBases:{"":t.selectionConfig});r&&(s=He(s,r));var l=Ft(e.eventStore,o.affectedEvents.instances),u=l.defs,f=l.instances,h=Ct(u,e.eventUiBases);for(var p in c){var m=c[p],v=m.range,g=s[m.defId],b=a[m.defId];if(!Vt(g.constraints,v,l,e.businessHours,t))return!1;var y=t.opt("eventOverlap");for(var k in"function"!=typeof y&&(y=null),f){var A=f[k];if(rt(v,A.range)){if(!1===h[A.defId].overlap&&o.isEvent)return!1;if(!1===g.overlap)return!1;if(y&&!y(new xt(t,u[A.defId],A),new xt(t,b,m)))return!1}}for(var _=t.state.eventStore,E=0,x=g.allows;E<x.length;E++){var w=x[E],S=Object(d.a)(Object(d.a)({},n),{range:m.range,allDay:b.allDay}),D=_.defs[b.defId],C=_.instances[p],R=void 0;if(R=D?new xt(t,D,C):new xt(t,b),!w(t.buildDateSpanApi(S),R))return!1}}return!0}(e,t,n,r))&&!(e.dateSelection&&!function(e,t,n,r){var o=e.eventStore,i=o.defs,a=o.instances,c=e.dateSelection,s=c.range,l=t.selectionConfig;r&&(l=r(l));if(!Vt(l.constraints,s,o,e.businessHours,t))return!1;var u=t.opt("selectOverlap");"function"!=typeof u&&(u=null);for(var f in a){var h=a[f];if(rt(s,h.range)){if(!1===l.overlap)return!1;if(u&&!u(new xt(t,i[h.defId],h)))return!1}}for(var p=0,m=l.allows;p<m.length;p++){var v=m[p],g=Object(d.a)(Object(d.a)({},n),c);if(!v(t.buildDateSpanApi(g),null))return!1}return!0}(e,t,n,r))}function Vt(e,t,n,r,o){for(var i=0,a=e;i<a.length;i++){if(!Gt(Wt(a[i],t,n,r,o),t))return!1}return!0}function Wt(e,t,n,r,o){return"businessHours"===e?Zt(Ge(r,t,o)):"string"==typeof e?Zt(Je(n,(function(t){return t.groupId===e}))):"object"==typeof e&&e?Zt(Ge(e,t,o)):[]}function Zt(e){var t=e.instances,n=[];for(var r in t)n.push(t[r].range);return n}function Gt(e,t){for(var n=0,r=e;n<r.length;n++){if(ot(r[n],t))return!0}return!1}function Yt(e){return Array.isArray(e)?e:"string"==typeof e?e.split(/\s+/):[]}var qt={display:null,editable:Boolean,startEditable:Boolean,durationEditable:Boolean,constraint:null,overlap:null,allow:null,className:Yt,classNames:Yt,color:String,backgroundColor:String,borderColor:String,textColor:String};function Kt(e,t,n){var r=Re(e,qt,{},n),o=function(e,t){return Array.isArray(e)?We(e,"",t,!0):"object"==typeof e&&e?We([e],"",t,!0):null!=e?String(e):null}(r.constraint,t);return{display:r.display,startEditable:null!=r.startEditable?r.startEditable:r.editable,durationEditable:null!=r.durationEditable?r.durationEditable:r.editable,constraints:null!=o?[o]:[],overlap:r.overlap,allows:null!=r.allow?[r.allow]:[],backgroundColor:r.backgroundColor||r.color,borderColor:r.borderColor||r.color,textColor:r.textColor,classNames:r.classNames.concat(r.className)}}function Jt(e,t,n,r){var o={},i={};for(var a in qt){var c=e+xe(a);o[a]=t[c],i[c]=!0}if("event"===e&&(o.editable=t.editable),r)for(var a in t)i[a]||(r[a]=t[a]);return Kt(o,n)}var Xt={display:null,startEditable:null,durationEditable:null,constraints:[],overlap:null,allows:[],backgroundColor:"",borderColor:"",textColor:"",classNames:[]};function $t(e){return e.reduce(en,Xt)}function en(e,t){return{display:null!=t.display?t.display:e.display,startEditable:null!=t.startEditable?t.startEditable:e.startEditable,durationEditable:null!=t.durationEditable?t.durationEditable:e.durationEditable,constraints:e.constraints.concat(t.constraints),overlap:"boolean"==typeof t.overlap?t.overlap:e.overlap,allows:e.allows.concat(t.allows),backgroundColor:t.backgroundColor||e.backgroundColor,borderColor:t.borderColor||e.borderColor,textColor:t.textColor||e.textColor,classNames:e.classNames.concat(t.classNames)}}var tn={id:String,groupId:String,title:String,url:String,extendedProps:null},nn={start:null,date:null,end:null,allDay:null};function rn(e,t,n,r){var o=function(e,t){var n=null;if(e){var r=t.state.eventSources[e];n=r.defaultAllDay}null==n&&(n=t.opt("defaultAllDay"));return n}(t,n),i={},a=function(e,t,n,r,o){for(var i=0;i<r.length;i++){var a={},c=r[i].parse(e,a,n);if(c){var s=a.allDay;return delete a.allDay,null==s&&null==(s=t)&&null==(s=c.allDayGuess)&&(s=!1),Object(d.a)(o,a),{allDay:s,duration:c.duration,typeData:c.typeData,typeId:i}}}return null}(e,o,n.dateEnv,n.pluginSystem.hooks.recurringTypes,i);if(a)return(c=on(i,t,a.allDay,Boolean(a.duration),n)).recurringDef={typeId:a.typeId,typeData:a.typeData,duration:a.duration},{def:c,instance:null};var c,s={},l=function(e,t,n,r,o){var i,a,c=function(e,t){var n=Re(e,nn,{},t);return n.start=null!==n.start?n.start:n.date,delete n.date,n}(e,r),s=c.allDay,l=null,d=!1,u=null;if(i=n.dateEnv.createMarkerMeta(c.start))l=i.marker;else if(!o)return null;null!=c.end&&(a=n.dateEnv.createMarkerMeta(c.end));null==s&&(s=null!=t?t:(!i||i.isTimeUnspecified)&&(!a||a.isTimeUnspecified));s&&l&&(l=re(l));a&&(u=a.marker,s&&(u=re(u)),l&&u<=l&&(u=null));u?d=!0:o||(d=n.opt("forceEventDuration")||!1,u=n.dateEnv.add(l,s?n.defaultAllDayEventDuration:n.defaultTimedEventDuration));return{allDay:s,hasEnd:d,range:{start:l,end:u},forcedStartTzo:i?i.forcedTzo:null,forcedEndTzo:a?a.forcedTzo:null}}(e,o,n,s,r);return l?{def:c=on(s,t,l.allDay,l.hasEnd,n),instance:an(c.defId,l.range,l.forcedStartTzo,l.forcedEndTzo)}:null}function on(e,t,n,r,o){var i={},a=function(e,t,n){var r={},o=Re(e,tn,{},r),i=Kt(r,t,n);return o.publicId=o.id,delete o.id,o.ui=i,o}(e,o,i);a.defId=Ae(),a.sourceId=t,a.allDay=n,a.hasEnd=r;for(var c=0,s=o.pluginSystem.hooks.eventDefParsers;c<s.length;c++){var l={};(0,s[c])(a,i,l),i=l}return a.extendedProps=Object(d.a)(i,a.extendedProps||{}),Object.freeze(a.ui.classNames),Object.freeze(a.extendedProps),a}function an(e,t,n,r){return{instanceId:Ae(),defId:e,range:t,forcedStartTzo:null==n?null:n,forcedEndTzo:null==r?null:r}}var cn={startTime:"09:00",endTime:"17:00",daysOfWeek:[1,2,3,4,5],display:"inverse-background",classNames:"fc-non-business",groupId:"_businessHours"};function sn(e,t){return We(function(e){var t;t=!0===e?[{}]:Array.isArray(e)?e.filter((function(e){return e.daysOfWeek})):"object"==typeof e&&e?[e]:[];return t=t.map((function(e){return Object(d.a)(Object(d.a)({},cn),e)}))}(e),"",t)}var ln={defs:{},instances:{}};!function(){function e(){this.getKeysForEventDefs=at(this._getKeysForEventDefs),this.splitDateSelection=at(this._splitDateSpan),this.splitEventStore=at(this._splitEventStore),this.splitIndividualUi=at(this._splitIndividualUi),this.splitEventDrag=at(this._splitInteraction),this.splitEventResize=at(this._splitInteraction),this.eventUiBuilders={}}e.prototype.splitProps=function(e){var t=this,n=this.getKeyInfo(e),r=this.getKeysForEventDefs(e.eventStore),o=this.splitDateSelection(e.dateSelection),i=this.splitIndividualUi(e.eventUiBases,r),a=this.splitEventStore(e.eventStore,r),c=this.splitEventDrag(e.eventDrag),s=this.splitEventResize(e.eventResize),l={};for(var d in this.eventUiBuilders=He(n,(function(e,n){return t.eventUiBuilders[n]||at(dn)})),n){var u=n[d],f=a[d]||ln,h=this.eventUiBuilders[d];l[d]={businessHours:u.businessHours||e.businessHours,dateSelection:o[d]||null,eventStore:f,eventUiBases:h(e.eventUiBases[""],u.ui,i[d]),eventSelection:f.instances[e.eventSelection]?e.eventSelection:"",eventDrag:c[d]||null,eventResize:s[d]||null}}return l},e.prototype._splitDateSpan=function(e){var t={};if(e)for(var n=0,r=this.getKeysForDateSpan(e);n<r.length;n++){t[r[n]]=e}return t},e.prototype._getKeysForEventDefs=function(e){var t=this;return He(e.defs,(function(e){return t.getKeysForEventDef(e)}))},e.prototype._splitEventStore=function(e,t){var n=e.defs,r=e.instances,o={};for(var i in n)for(var a=0,c=t[i];a<c.length;a++){o[f=c[a]]||(o[f]={defs:{},instances:{}}),o[f].defs[i]=n[i]}for(var s in r)for(var l=r[s],d=0,u=t[l.defId];d<u.length;d++){var f;o[f=u[d]]&&(o[f].instances[s]=l)}return o},e.prototype._splitIndividualUi=function(e,t){var n={};for(var r in e)if(r)for(var o=0,i=t[r];o<i.length;o++){var a=i[o];n[a]||(n[a]={}),n[a][r]=e[r]}return n},e.prototype._splitInteraction=function(e){var t={};if(e){var n=this._splitEventStore(e.affectedEvents,this._getKeysForEventDefs(e.affectedEvents)),r=this._getKeysForEventDefs(e.mutatedEvents),o=this._splitEventStore(e.mutatedEvents,r),i=function(r){t[r]||(t[r]={affectedEvents:n[r]||ln,mutatedEvents:o[r]||ln,isEvent:e.isEvent})};for(var a in n)i(a);for(var a in o)i(a)}return t}}();function dn(e,t,n){var r=[];e&&r.push(e),t&&r.push(t);var o={"":$t(r)};return n&&Object(d.a)(o,n),o}function un(e,t,n,r){return{dow:e.getUTCDay(),isDisabled:Boolean(r&&!it(r.activeRange,e)),isOther:Boolean(r&&!it(r.currentRange,e)),isToday:Boolean(t&&it(t,e)),isPast:Boolean(n?e<n:!!t&&e<t.start),isFuture:Boolean(n?e>n:!!t&&e>=t.end)}}function fn(e,t){var n=["fc-day","fc-day-"+K[e.dow]];return e.isDisabled?n.push("fc-day-disabled"):(e.isToday&&(n.push("fc-day-today"),n.push(t.getClass("today"))),e.isPast&&n.push("fc-day-past"),e.isFuture&&n.push("fc-day-future"),e.isOther&&n.push("fc-day-other")),n}function hn(e,t){return void 0===t&&(t="day"),JSON.stringify({date:yt(e),type:t})}var pn;function mn(){return pn||(pn=function(){var e=document.createElement("div");e.style.overflow="scroll",document.body.appendChild(e);var t=vn(e);return document.body.removeChild(e),t}()),pn}function vn(e){return{x:e.offsetHeight-e.clientHeight,y:e.offsetWidth-e.clientWidth}}var gn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.on=function(e,t){return bn(this._handlers||(this._handlers={}),e,t),this},t.prototype.one=function(e,t){return bn(this._oneHandlers||(this._oneHandlers={}),e,t),this},t.prototype.off=function(e,t){return this._handlers&&yn(this._handlers,e,t),this._oneHandlers&&yn(this._oneHandlers,e,t),this},t.prototype.trigger=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];return this.triggerWith(e,this,t),this},t.prototype.triggerWith=function(e,t,n){return this._handlers&&De(this._handlers[e],t,n),this._oneHandlers&&(De(this._oneHandlers[e],t,n),delete this._oneHandlers[e]),this},t.prototype.hasHandlers=function(e){return this._handlers&&this._handlers[e]&&this._handlers[e].length||this._oneHandlers&&this._oneHandlers[e]&&this._oneHandlers[e].length},t}(function(){function e(){}return e.mixInto=function(e){this.mixIntoObj(e.prototype)},e.mixIntoObj=function(e){var t=this;Object.getOwnPropertyNames(this.prototype).forEach((function(n){e[n]||(e[n]=t.prototype[n])}))},e.mixOver=function(e){var t=this;Object.getOwnPropertyNames(this.prototype).forEach((function(n){e.prototype[n]=t.prototype[n]}))},e}());function bn(e,t,n){(e[t]||(e[t]=[])).push(n)}function yn(e,t,n){n?e[t]&&(e[t]=e[t].filter((function(e){return e!==n}))):delete e[t]}var kn=function(){function e(e,t,n,r){this.els=t;var o=this.originClientRect=e.getBoundingClientRect();n&&this.buildElHorizontals(o.left),r&&this.buildElVerticals(o.top)}return e.prototype.buildElHorizontals=function(e){for(var t=[],n=[],r=0,o=this.els;r<o.length;r++){var i=o[r].getBoundingClientRect();t.push(i.left-e),n.push(i.right-e)}this.lefts=t,this.rights=n},e.prototype.buildElVerticals=function(e){for(var t=[],n=[],r=0,o=this.els;r<o.length;r++){var i=o[r].getBoundingClientRect();t.push(i.top-e),n.push(i.bottom-e)}this.tops=t,this.bottoms=n},e.prototype.leftToIndex=function(e){var t,n=this.lefts,r=this.rights,o=n.length;for(t=0;t<o;t++)if(e>=n[t]&&e<r[t])return t},e.prototype.topToIndex=function(e){var t,n=this.tops,r=this.bottoms,o=n.length;for(t=0;t<o;t++)if(e>=n[t]&&e<r[t])return t},e.prototype.getWidth=function(e){return this.rights[e]-this.lefts[e]},e.prototype.getHeight=function(e){return this.bottoms[e]-this.tops[e]},e}(),An=function(){function e(){}return e.prototype.getMaxScrollTop=function(){return this.getScrollHeight()-this.getClientHeight()},e.prototype.getMaxScrollLeft=function(){return this.getScrollWidth()-this.getClientWidth()},e.prototype.canScrollVertically=function(){return this.getMaxScrollTop()>0},e.prototype.canScrollHorizontally=function(){return this.getMaxScrollLeft()>0},e.prototype.canScrollUp=function(){return this.getScrollTop()>0},e.prototype.canScrollDown=function(){return this.getScrollTop()<this.getMaxScrollTop()},e.prototype.canScrollLeft=function(){return this.getScrollLeft()>0},e.prototype.canScrollRight=function(){return this.getScrollLeft()<this.getMaxScrollLeft()},e}(),_n=(function(e){function t(t){var n=e.call(this)||this;return n.el=t,n}Object(d.c)(t,e),t.prototype.getScrollTop=function(){return this.el.scrollTop},t.prototype.getScrollLeft=function(){return this.el.scrollLeft},t.prototype.setScrollTop=function(e){this.el.scrollTop=e},t.prototype.setScrollLeft=function(e){this.el.scrollLeft=e},t.prototype.getScrollWidth=function(){return this.el.scrollWidth},t.prototype.getScrollHeight=function(){return this.el.scrollHeight},t.prototype.getClientHeight=function(){return this.el.clientHeight},t.prototype.getClientWidth=function(){return this.el.clientWidth}}(An),function(e){function t(){return null!==e&&e.apply(this,arguments)||this}Object(d.c)(t,e),t.prototype.getScrollTop=function(){return window.pageYOffset},t.prototype.getScrollLeft=function(){return window.pageXOffset},t.prototype.setScrollTop=function(e){window.scroll(window.pageXOffset,e)},t.prototype.setScrollLeft=function(e){window.scroll(e,window.pageYOffset)},t.prototype.getScrollWidth=function(){return document.documentElement.scrollWidth},t.prototype.getScrollHeight=function(){return document.documentElement.scrollHeight},t.prototype.getClientHeight=function(){return document.documentElement.clientHeight},t.prototype.getClientWidth=function(){return document.documentElement.clientWidth}}(An),function(){function e(e){this.iconOverrideOption&&this.setIconOverride(e[this.iconOverrideOption])}return e.prototype.setIconOverride=function(e){var t,n;if("object"==typeof e&&e){for(n in t=Object(d.a)({},this.iconClasses),e)t[n]=this.applyIconOverridePrefix(e[n]);this.iconClasses=t}else!1===e&&(this.iconClasses={})},e.prototype.applyIconOverridePrefix=function(e){var t=this.iconOverridePrefix;return t&&0!==e.indexOf(t)&&(e=t+e),e},e.prototype.getClass=function(e){return this.classes[e]||""},e.prototype.getIconClass=function(e,t){var n;return(n=t&&this.rtlIconClasses&&this.rtlIconClasses[e]||this.iconClasses[e])?this.baseIconClass+" "+n:""},e.prototype.getCustomButtonIconClass=function(e){var t;return this.iconOverrideCustomButtonOption&&(t=e[this.iconOverrideCustomButtonOption])?this.baseIconClass+" "+this.applyIconOverridePrefix(t):""},e}());function En(){var e=r.debounceRendering,t=[];for(r.debounceRendering=function(e){t.push(e)},P(v(xn,{}),document.createElement("div"));t.length;)t.shift()();r.debounceRendering=e}_n.prototype.classes={},_n.prototype.iconClasses={},_n.prototype.baseIconClass="",_n.prototype.iconOverridePrefix="";var xn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(){return v("div",{})},t.prototype.componentDidMount=function(){this.setState({})},t}(k);function wn(e,t,n,r,o){return He(e,(function(e){return function(e,t,n,r,o){var i=r.optionsManager,a=r.viewSpecs,c=i.computed.customButtons||{},s=i.overrides.buttonText||{},l=i.computed.buttonText||{};return(e?e.split(" "):[]).map((function(e,i){return e.split(",").map((function(e,i){if("title"===e)return{buttonName:e};var d,u=void 0,f=void 0,h=void 0,p=void 0;return(d=c[e])?(f=function(e){d.click&&d.click.call(e.target,e)},(h=t.getCustomButtonIconClass(d))||(h=t.getIconClass(e,n))||(p=d.text)):(u=a[e])?(o.push(e),f=function(){r.changeView(e)},(p=u.buttonTextOverride)||(h=t.getIconClass(e,n))||(p=u.buttonTextDefault)):r[e]&&(f=function(){r[e]()},(p=s[e])||(h=t.getIconClass(e,n))||(p=l[e])),{buttonName:e,buttonClick:f,buttonIcon:h,buttonText:p}}))}))}(e,t,n,r,o)}))}var Sn=function(){function e(e,t){var n=this;this.calendar=e,this.execFunc=t,this.handleScrollRequest=function(e){n.queuedRequest=Object(d.a)({},n.queuedRequest||{},e),n.drain()},e.on("scrollRequest",this.handleScrollRequest),this.fireInitialScroll()}return e.prototype.detach=function(){this.calendar.off("scrollRequest",this.handleScrollRequest)},e.prototype.update=function(e){e?this.fireInitialScroll():this.drain()},e.prototype.fireInitialScroll=function(){this.handleScrollRequest({time:he(this.calendar.viewOpt("scrollTime"))})},e.prototype.drain=function(){this.queuedRequest&&this.execFunc(this.queuedRequest)&&(this.queuedRequest=null)},e}(),Dn=function(e){var t={},n={__c:"__cC"+l++,__:e,Consumer:function(e,t){return e.children(t)},Provider:function(e){var r,o=this;return this.getChildContext||(r=[],this.getChildContext=function(){return t[n.__c]=o,t},this.shouldComponentUpdate=function(e){o.props.value!==e.value&&r.some((function(t){t.context=e.value,E(t)}))},this.sub=function(e){r.push(e);var t=e.componentWillUnmount;e.componentWillUnmount=function(){r.splice(r.indexOf(e),1),t&&t.call(e)}}),e.children}};return n.Consumer.contextType=n,n.Provider.__=n,n}({});function Cn(e,t,n,r,o,i){return Object(d.a)(Object(d.a)({calendar:e,pluginHooks:t,dateEnv:n,theme:r,view:o,options:i},function(e,t,n){var r="rtl"===e.direction;return Object(d.a)({isRtl:r,eventOrderSpecs:_e(e.eventOrder),nextDayThreshold:he(e.nextDayThreshold)},function(e,t,n,r){var o=[];return{headerToolbar:e.headerToolbar?wn(e.headerToolbar,t,n,r,o):null,footerToolbar:e.footerToolbar?wn(e.footerToolbar,t,n,r,o):null,viewsWithButtons:o}}(e,t,r,n))}(i,r,e)),{addResizeHandler:e.addResizeHandler,removeResizeHandler:e.removeResizeHandler,createScrollResponder:function(t){return new Sn(e,t)}})}var Rn=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.shouldComponentUpdate=function(e,t,n){return this.debug&&console.log(Le(e,this.props),Le(t,this.state)),!Qe(this.props,e,this.propEquality)||!Qe(this.state,t,this.stateEquality)||this.context!==n},t.addPropsEquality=On,t.addStateEquality=Tn,t.contextType=Dn,t}(k);function On(e){var t=Object.create(this.prototype.propEquality);Object(d.a)(t,e),this.prototype.propEquality=t}function Tn(e){var t=Object.create(this.prototype.stateEquality);Object(d.a)(t,e),this.prototype.stateEquality=t}function In(e,t){"function"==typeof e?e(t):e&&(e.current=t)}Rn.prototype.propEquality={},Rn.prototype.stateEquality={};var Mn=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.uid=Ae(),t}return Object(d.c)(t,e),t.prototype.prepareHits=function(){},t.prototype.queryHit=function(e,t,n,r){return null},t.prototype.isInteractionValid=function(e){var t=this.context.calendar,n=this.props.dateProfile,r=e.mutatedEvents.instances;if(n)for(var o in r)if(!ot(n.validRange,r[o].range))return!1;return function(e,t){return Lt({eventDrag:e},t)}(e,t)},t.prototype.isDateSelectionValid=function(e){var t=this.context.calendar,n=this.props.dateProfile;return!(n&&!ot(n.validRange,e.range))&&function(e,t){return Lt({dateSelection:e},t)}(e,t)},t.prototype.isValidSegDownEl=function(e){return!this.props.eventDrag&&!this.props.eventResize&&!Q(e,".fc-event-mirror")&&(this.isPopover()||!this.isInPopover(e))},t.prototype.isValidDateDownEl=function(e){return!(Q(e,".fc-event:not(.fc-bg-event)")||Q(e,".fc-daygrid-more-link")||Q(e,"a[data-navlink]")||this.isInPopover(e))},t.prototype.isPopover=function(){return!1},t.prototype.isInPopover=function(e){return Boolean(Q(e,".fc-popover"))},t}(Rn),jn={defaultRangeSeparator:" - ",titleRangeSeparator:" – ",defaultTimedEventDuration:"01:00:00",defaultAllDayEventDuration:{day:1},forceEventDuration:!1,nextDayThreshold:"00:00:00",dayHeaders:!0,initialView:"",aspectRatio:1.35,headerToolbar:{start:"title",center:"",end:"today prev,next"},weekends:!0,weekNumbers:!1,weekNumberCalculation:"local",editable:!1,scrollTime:"06:00:00",slotMinTime:"00:00:00",slotMaxTime:"24:00:00",showNonCurrentDates:!0,lazyFetching:!0,startParam:"start",endParam:"end",timeZoneParam:"timeZone",timeZone:"local",locales:[],locale:"",themeSystem:"standard",dragRevertDuration:500,dragScroll:!0,allDayMaintainDuration:!1,unselectAuto:!0,dropAccept:"*",eventOrder:"start,-duration,allDay,title",moreLinkClick:"popover",dayPopoverFormat:{month:"long",day:"numeric",year:"numeric"},handleWindowResize:!0,windowResizeDelay:100,longPressDelay:1e3,eventDragMinDistance:5,expandRows:!1},Nn=["headerToolbar","footerToolbar","buttonText","buttonIcons"];var Pn={code:"en",week:{dow:0,doy:4},direction:"ltr",buttonText:{prev:"prev",next:"next",prevYear:"prev year",nextYear:"next year",year:"year",today:"today",month:"month",week:"week",day:"day",list:"list"},weekText:"W",allDayText:"all-day",moreLinkText:"more",noEventsText:"No events to display"};function Bn(e){for(var t,n=e.length>0?e[0].code:"en",r=(t=window.FullCalendarLocales,Array.isArray(t)?t:Ue(t)).concat(e),o={en:Pn},i=0,a=r;i<a.length;i++){var c=a[i];o[c.code]=c}return{map:o,defaultCode:n}}function Hn(e,t){return"object"!=typeof e||Array.isArray(e)?function(e,t){var n=[].concat(e||[]),r=function(e,t){for(var n=0;n<e.length;n++)for(var r=e[n].toLocaleLowerCase().split("-"),o=r.length;o>0;o--){var i=r.slice(0,o).join("-");if(t[i])return t[i]}return null}(n,t)||Pn;return zn(e,n,r)}(e,t):zn(e.code,[e.code],e)}function zn(e,t,n){var r=Pe([Pn,n],["buttonText"]);delete r.code;var o=r.week;return delete r.week,{codeArg:e,codes:t,week:o,simpleNumberFormat:new Intl.NumberFormat(e),options:r}}var Un=function(){function e(e){this.overrides=Object(d.a)({},e),this.dynamicOverrides={},this.compute()}return e.prototype.mutate=function(e,t,n){if(Object.keys(e).length||t.length){var r=n?this.dynamicOverrides:this.overrides;Object(d.a)(r,e);for(var o=0,i=t;o<i.length;o++){delete r[i[o]]}this.compute()}},e.prototype.compute=function(){var e=Ce(this.dynamicOverrides.locales,this.overrides.locales,jn.locales),t=Ce(this.dynamicOverrides.locale,this.overrides.locale,jn.locale),n=Bn(e),r=Hn(t||n.defaultCode,n.map).options;this.localeDefaults=r,this.computed=Pe([jn,r,this.overrides,this.dynamicOverrides],Nn)},e}(),Fn={};var Ln,Qn=function(){function e(){}return e.prototype.getMarkerYear=function(e){return e.getUTCFullYear()},e.prototype.getMarkerMonth=function(e){return e.getUTCMonth()},e.prototype.getMarkerDay=function(e){return e.getUTCDate()},e.prototype.arrayToMarker=function(e){return le(e)},e.prototype.markerToArray=function(e){return se(e)},e}();Ln=Qn,Fn["gregory"]=Ln;var Vn=/^\s*(\d{4})(-(\d{2})(-(\d{2})([T ](\d{2}):(\d{2})(:(\d{2})(\.(\d+))?)?(Z|(([-+])(\d{2})(:?(\d{2}))?))?)?)?)?$/;var Wn=function(){function e(e){var t=this.timeZone=e.timeZone,n="local"!==t&&"UTC"!==t;e.namedTimeZoneImpl&&n&&(this.namedTimeZoneImpl=new e.namedTimeZoneImpl(t)),this.canComputeOffset=Boolean(!n||this.namedTimeZoneImpl),this.calendarSystem=function(e){return new Fn[e]}(e.calendarSystem),this.locale=e.locale,this.weekDow=e.locale.week.dow,this.weekDoy=e.locale.week.doy,"ISO"===e.weekNumberCalculation&&(this.weekDow=1,this.weekDoy=4),"number"==typeof e.firstDay&&(this.weekDow=e.firstDay),"function"==typeof e.weekNumberCalculation&&(this.weekNumberFunc=e.weekNumberCalculation),this.weekText=null!=e.weekText?e.weekText:e.locale.options.weekText,this.cmdFormatter=e.cmdFormatter}return e.prototype.createMarker=function(e){var t=this.createMarkerMeta(e);return null===t?null:t.marker},e.prototype.createNowMarker=function(){return this.canComputeOffset?this.timestampToMarker((new Date).valueOf()):le(ae(new Date))},e.prototype.createMarkerMeta=function(e){if("string"==typeof e)return this.parse(e);var t=null;return"number"==typeof e?t=this.timestampToMarker(e):e instanceof Date?(e=e.valueOf(),isNaN(e)||(t=this.timestampToMarker(e))):Array.isArray(e)&&(t=le(e)),null!==t&&de(t)?{marker:t,isTimeUnspecified:!1,forcedTzo:null}:null},e.prototype.parse=function(e){var t=function(e){var t=Vn.exec(e);if(t){var n=new Date(Date.UTC(Number(t[1]),t[3]?Number(t[3])-1:0,Number(t[5]||1),Number(t[7]||0),Number(t[8]||0),Number(t[10]||0),t[12]?1e3*Number("0."+t[12]):0));if(de(n)){var r=null;return t[13]&&(r=("-"===t[15]?-1:1)*(60*Number(t[16]||0)+Number(t[18]||0))),{marker:n,isTimeUnspecified:!t[6],timeZoneOffset:r}}}return null}(e);if(null===t)return null;var n=t.marker,r=null;return null!==t.timeZoneOffset&&(this.canComputeOffset?n=this.timestampToMarker(n.valueOf()-60*t.timeZoneOffset*1e3):r=t.timeZoneOffset),{marker:n,isTimeUnspecified:t.isTimeUnspecified,forcedTzo:r}},e.prototype.getYear=function(e){return this.calendarSystem.getMarkerYear(e)},e.prototype.getMonth=function(e){return this.calendarSystem.getMarkerMonth(e)},e.prototype.add=function(e,t){var n=this.calendarSystem.markerToArray(e);return n[0]+=t.years,n[1]+=t.months,n[2]+=t.days,n[6]+=t.milliseconds,this.calendarSystem.arrayToMarker(n)},e.prototype.subtract=function(e,t){var n=this.calendarSystem.markerToArray(e);return n[0]-=t.years,n[1]-=t.months,n[2]-=t.days,n[6]-=t.milliseconds,this.calendarSystem.arrayToMarker(n)},e.prototype.addYears=function(e,t){var n=this.calendarSystem.markerToArray(e);return n[0]+=t,this.calendarSystem.arrayToMarker(n)},e.prototype.addMonths=function(e,t){var n=this.calendarSystem.markerToArray(e);return n[1]+=t,this.calendarSystem.arrayToMarker(n)},e.prototype.diffWholeYears=function(e,t){var n=this.calendarSystem;return ue(e)===ue(t)&&n.getMarkerDay(e)===n.getMarkerDay(t)&&n.getMarkerMonth(e)===n.getMarkerMonth(t)?n.getMarkerYear(t)-n.getMarkerYear(e):null},e.prototype.diffWholeMonths=function(e,t){var n=this.calendarSystem;return ue(e)===ue(t)&&n.getMarkerDay(e)===n.getMarkerDay(t)?n.getMarkerMonth(t)-n.getMarkerMonth(e)+12*(n.getMarkerYear(t)-n.getMarkerYear(e)):null},e.prototype.greatestWholeUnit=function(e,t){var n=this.diffWholeYears(e,t);return null!==n?{unit:"year",value:n}:null!==(n=this.diffWholeMonths(e,t))?{unit:"month",value:n}:null!==(n=function(e,t){var n=ne(e,t);return null!==n&&n%7==0?n/7:null}(e,t))?{unit:"week",value:n}:null!==(n=ne(e,t))?{unit:"day",value:n}:Se(n=function(e,t){return(t.valueOf()-e.valueOf())/36e5}(e,t))?{unit:"hour",value:n}:Se(n=function(e,t){return(t.valueOf()-e.valueOf())/6e4}(e,t))?{unit:"minute",value:n}:Se(n=function(e,t){return(t.valueOf()-e.valueOf())/1e3}(e,t))?{unit:"second",value:n}:{unit:"millisecond",value:t.valueOf()-e.valueOf()}},e.prototype.countDurationsBetween=function(e,t,n){var r;return n.years&&null!==(r=this.diffWholeYears(e,t))?r/(ge(n)/365):n.months&&null!==(r=this.diffWholeMonths(e,t))?r/function(e){return ge(e)/30}(n):n.days&&null!==(r=ne(e,t))?r/ge(n):(t.valueOf()-e.valueOf())/be(n)},e.prototype.startOf=function(e,t){return"year"===t?this.startOfYear(e):"month"===t?this.startOfMonth(e):"week"===t?this.startOfWeek(e):"day"===t?re(e):"hour"===t?function(e){return le([e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate(),e.getUTCHours()])}(e):"minute"===t?function(e){return le([e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate(),e.getUTCHours(),e.getUTCMinutes()])}(e):"second"===t?function(e){return le([e.getUTCFullYear(),e.getUTCMonth(),e.getUTCDate(),e.getUTCHours(),e.getUTCMinutes(),e.getUTCSeconds()])}(e):void 0},e.prototype.startOfYear=function(e){return this.calendarSystem.arrayToMarker([this.calendarSystem.getMarkerYear(e)])},e.prototype.startOfMonth=function(e){return this.calendarSystem.arrayToMarker([this.calendarSystem.getMarkerYear(e),this.calendarSystem.getMarkerMonth(e)])},e.prototype.startOfWeek=function(e){return this.calendarSystem.arrayToMarker([this.calendarSystem.getMarkerYear(e),this.calendarSystem.getMarkerMonth(e),e.getUTCDate()-(e.getUTCDay()-this.weekDow+7)%7])},e.prototype.computeWeekNumber=function(e){return this.weekNumberFunc?this.weekNumberFunc(this.toDate(e)):function(e,t,n){var r=e.getUTCFullYear(),o=oe(e,r,t,n);if(o<1)return oe(e,r-1,t,n);var i=oe(e,r+1,t,n);return i>=1?Math.min(o,i):o}(e,this.weekDow,this.weekDoy)},e.prototype.format=function(e,t,n){return void 0===n&&(n={}),t.format({marker:e,timeZoneOffset:null!=n.forcedTzo?n.forcedTzo:this.offsetForMarker(e)},this)},e.prototype.formatRange=function(e,t,n,r){return void 0===r&&(r={}),r.isEndExclusive&&(t=$(t,-1)),n.formatRange({marker:e,timeZoneOffset:null!=r.forcedStartTzo?r.forcedStartTzo:this.offsetForMarker(e)},{marker:t,timeZoneOffset:null!=r.forcedEndTzo?r.forcedEndTzo:this.offsetForMarker(t)},this)},e.prototype.formatIso=function(e,t){void 0===t&&(t={});var n=null;return t.omitTimeZoneOffset||(n=null!=t.forcedTzo?t.forcedTzo:this.offsetForMarker(e)),function(e,t,n){void 0===n&&(n=!1);var r=e.toISOString();return r=r.replace(".000",""),n&&(r=r.replace("T00:00:00Z","")),r.length>10&&(null==t?r=r.replace("Z",""):0!==t&&(r=r.replace("Z",kt(t,!0)))),r}(e,n,t.omitTime)},e.prototype.timestampToMarker=function(e){return"local"===this.timeZone?le(ae(new Date(e))):"UTC"!==this.timeZone&&this.namedTimeZoneImpl?le(this.namedTimeZoneImpl.timestampToArray(e)):new Date(e)},e.prototype.offsetForMarker=function(e){return"local"===this.timeZone?-ce(se(e)).getTimezoneOffset():"UTC"===this.timeZone?0:this.namedTimeZoneImpl?this.namedTimeZoneImpl.offsetForArray(se(e)):null},e.prototype.toDate=function(e,t){return"local"===this.timeZone?ce(se(e)):"UTC"===this.timeZone?new Date(e.valueOf()):this.namedTimeZoneImpl?new Date(e.valueOf()-1e3*this.namedTimeZoneImpl.offsetForArray(se(e))*60):new Date(e.valueOf()-(t||0))},e}(),Zn={id:String,defaultAllDay:Boolean,eventDataTransform:Function,success:Function,failure:Function};function Gn(e,t){return!t.pluginSystem.hooks.eventSourceDefs[e.sourceDefId].ignoreRange}function Yn(e,t){for(var n=t.pluginSystem.hooks.eventSourceDefs,r=n.length-1;r>=0;r--){var o=n[r].parseMeta(e);if(o){var i=qn("object"==typeof e?e:{},o,r,t);return i._raw=e,i}}return null}function qn(e,t,n,r){var o={},i=Re(e,Zn,{},o),a={},c=Kt(o,r,a);return i.isFetching=!1,i.latestFetchId="",i.fetchRange=null,i.publicId=String(e.id||""),i.sourceId=Ae(),i.sourceDefId=n,i.meta=t,i.ui=c,i.extendedProps=a,i}function Kn(e,t,n,r){switch(t.type){case"ADD_EVENT_SOURCES":return function(e,t,n,r){for(var o={},i=0,a=t;i<a.length;i++){var c=a[i];o[c.sourceId]=c}n&&(o=Jn(o,n,r));return Object(d.a)(Object(d.a)({},e),o)}(e,t.sources,n?n.activeRange:null,r);case"REMOVE_EVENT_SOURCE":return o=e,i=t.sourceId,Be(o,(function(e){return e.sourceId!==i}));case"PREV":case"NEXT":case"SET_DATE":case"SET_VIEW_TYPE":return n?Jn(e,n.activeRange,r):e;case"FETCH_EVENT_SOURCES":case"CHANGE_TIMEZONE":return Xn(e,t.sourceIds?ze(t.sourceIds):function(e,t){return Be(e,(function(e){return Gn(e,t)}))}(e,r),n?n.activeRange:null,r);case"RECEIVE_EVENTS":case"RECEIVE_EVENT_ERROR":return function(e,t,n,r){var o,i=e[t];if(i&&n===i.latestFetchId)return Object(d.a)(Object(d.a)({},e),((o={})[t]=Object(d.a)(Object(d.a)({},i),{isFetching:!1,fetchRange:r}),o));return e}(e,t.sourceId,t.fetchId,t.fetchRange);case"REMOVE_ALL_EVENT_SOURCES":return{};default:return e}var o,i}function Jn(e,t,n){return Xn(e,Be(e,(function(e){return function(e,t,n){return Gn(e,n)?!n.opt("lazyFetching")||!e.fetchRange||e.isFetching||t.start<e.fetchRange.start||t.end>e.fetchRange.end:!e.latestFetchId}(e,t,n)})),t,n)}function Xn(e,t,n,r){var o={};for(var i in e){var a=e[i];t[i]?o[i]=$n(a,n,r):o[i]=a}return o}function $n(e,t,n){var r=n.pluginSystem.hooks.eventSourceDefs[e.sourceDefId],o=Ae();return r.fetch({eventSource:e,calendar:n,range:t},(function(r){var i,a=r.rawEvents;e.success&&(i=e.success(a,r.xhr));var c=n.publiclyTrigger("eventSourceSuccess",[a,r.xhr]);a=i||c||a,n.dispatch({type:"RECEIVE_EVENTS",sourceId:e.sourceId,fetchId:o,fetchRange:t,rawEvents:a})}),(function(r){console.warn(r.message,r),e.failure&&e.failure(r),n.publiclyTrigger("eventSourceFailure",[r]),n.dispatch({type:"RECEIVE_EVENT_ERROR",sourceId:e.sourceId,fetchId:o,fetchRange:t,error:r})})),Object(d.a)(Object(d.a)({},e),{isFetching:!0,latestFetchId:o})}var er=function(){function e(e,t){this.viewSpec=e,this.options=e.options,this.slotMinTime=t.slotMinTime,this.slotMaxTime=t.slotMaxTime,this.dateEnv=t.dateEnv,this.calendar=t,this.initHiddenDays()}return e.prototype.buildPrev=function(e,t){var n=this.dateEnv,r=n.subtract(n.startOf(t,e.currentRangeUnit),e.dateIncrement);return this.build(r,-1)},e.prototype.buildNext=function(e,t){var n=this.dateEnv,r=n.add(n.startOf(t,e.currentRangeUnit),e.dateIncrement);return this.build(r,1)},e.prototype.build=function(e,t,n){var r,o,i,a,c,s,l,d;return void 0===n&&(n=!1),r=this.buildValidRange(),r=this.trimHiddenDays(r),n&&(l=e,e=null!=(d=r).start&&l<d.start?d.start:null!=d.end&&l>=d.end?new Date(d.end.valueOf()-1):l),o=this.buildCurrentRangeInfo(e,t),i=/^(year|month|week|day)$/.test(o.unit),a=this.buildRenderRange(this.trimHiddenDays(o.range),o.unit,i),c=a=this.trimHiddenDays(a),this.options.showNonCurrentDates||(c=tt(c,o.range)),c=tt(c=this.adjustActiveRange(c),r),s=rt(o.range,r),{validRange:r,currentRange:o.range,currentRangeUnit:o.unit,isRangeAllDay:i,activeRange:c,renderRange:a,slotMinTime:this.slotMinTime,slotMaxTime:this.slotMaxTime,isValid:s,dateIncrement:this.buildDateIncrement(o.duration)}},e.prototype.buildValidRange=function(){return this.getRangeOption("validRange",this.calendar.getNow())||{start:null,end:null}},e.prototype.buildCurrentRangeInfo=function(e,t){var n,r=this.viewSpec,o=this.dateEnv,i=null,a=null,c=null;return r.duration?(i=r.duration,a=r.durationUnit,c=this.buildRangeFromDuration(e,t,i,a)):(n=this.options.dayCount)?(a="day",c=this.buildRangeFromDayCount(e,t,n)):(c=this.buildCustomVisibleRange(e))?a=o.greatestWholeUnit(c.start,c.end).unit:(a=ye(i=this.getFallbackDuration()).unit,c=this.buildRangeFromDuration(e,t,i,a)),{duration:i,unit:a,range:c}},e.prototype.getFallbackDuration=function(){return he({day:1})},e.prototype.adjustActiveRange=function(e){var t=this.dateEnv,n=this.slotMinTime,r=this.slotMaxTime,o=e.start,i=e.end;return this.viewSpec.options.usesMinMaxTime&&(ge(n)<0&&(o=re(o),o=t.add(o,n)),ge(r)>1&&(i=X(i=re(i),-1),i=t.add(i,r))),{start:o,end:i}},e.prototype.buildRangeFromDuration=function(e,t,n,r){var o,i,a,c,s,l=this.dateEnv,d=this.options.dateAlignment;function u(){a=l.startOf(e,d),c=l.add(a,n),s={start:a,end:c}}return d||((o=this.options.dateIncrement)?(i=he(o),d=be(i)<be(n)?ye(i,!me(o)).unit:r):d=r),ge(n)<=1&&this.isHiddenDay(a)&&(a=re(a=this.skipHiddenDays(a,t))),u(),this.trimHiddenDays(s)||(e=this.skipHiddenDays(e,t),u()),s},e.prototype.buildRangeFromDayCount=function(e,t,n){var r,o=this.dateEnv,i=this.options.dateAlignment,a=0,c=e;i&&(c=o.startOf(c,i)),c=re(c),r=c=this.skipHiddenDays(c,t);do{r=X(r,1),this.isHiddenDay(r)||a++}while(a<n);return{start:c,end:r}},e.prototype.buildCustomVisibleRange=function(e){var t=this.dateEnv,n=this.getRangeOption("visibleRange",t.toDate(e));return!n||null!=n.start&&null!=n.end?n:null},e.prototype.buildRenderRange=function(e,t,n){return e},e.prototype.buildDateIncrement=function(e){var t,n=this.options.dateIncrement;return n?he(n):(t=this.options.dateAlignment)?he(1,t):e||he({days:1})},e.prototype.getRangeOption=function(e){for(var t=[],n=1;n<arguments.length;n++)t[n-1]=arguments[n];var r=this.options[e];return"function"==typeof r&&(r=r.apply(null,t)),r&&(r=Xe(r,this.dateEnv)),r&&(r=Te(r)),r},e.prototype.initHiddenDays=function(){var e,t=this.options.hiddenDays||[],n=[],r=0;for(!1===this.options.weekends&&t.push(0,6),e=0;e<7;e++)(n[e]=-1!==t.indexOf(e))||r++;if(!r)throw new Error("invalid hiddenDays");this.isHiddenDayHash=n},e.prototype.trimHiddenDays=function(e){var t=e.start,n=e.end;return t&&(t=this.skipHiddenDays(t)),n&&(n=this.skipHiddenDays(n,-1,!0)),null==t||null==n||t<n?{start:t,end:n}:null},e.prototype.isHiddenDay=function(e){return e instanceof Date&&(e=e.getUTCDay()),this.isHiddenDayHash[e]},e.prototype.skipHiddenDays=function(e,t,n){for(void 0===t&&(t=1),void 0===n&&(n=!1);this.isHiddenDayHash[(e.getUTCDay()+(n?t:0)+7)%7];)e=X(e,t);return e},e}();function tr(e,t,n){for(var r=function(e,t){switch(t.type){case"SET_VIEW_TYPE":return t.viewType;default:return e}}(e.viewType,t),o=function(e,t,n,r,o){var i;switch(t.type){case"PREV":i=o.dateProfileGenerators[r].buildPrev(e,n);break;case"NEXT":i=o.dateProfileGenerators[r].buildNext(e,n);break;case"SET_DATE":e.activeRange&&it(e.currentRange,t.dateMarker)||(i=o.dateProfileGenerators[r].build(t.dateMarker,void 0,!0));break;case"SET_VIEW_TYPE":var a=o.dateProfileGenerators[r];if(!a)throw new Error(r?'The FullCalendar view "'+r+'" does not exist. Make sure your plugins are loaded correctly.':"No available FullCalendar view plugins.");i=a.build(t.dateMarker||n,void 0,!0)}return!i||!i.isValid||e&&(c=e,s=i,nt(c.validRange,s.validRange)&&nt(c.activeRange,s.activeRange)&&nt(c.renderRange,s.renderRange)&&ve(c.slotMinTime,s.slotMinTime)&&ve(c.slotMaxTime,s.slotMaxTime))?e:i;var c,s}(e.dateProfile,t,e.currentDate,r,n),i=Kn(e.eventSources,t,o,n),a=Object(d.a)(Object(d.a)({},e),{viewType:r,dateProfile:o,currentDate:nr(e.currentDate,t,o),eventSources:i,eventStore:zt(e.eventStore,t,i,o,n),dateSelection:rr(e.dateSelection,t),eventSelection:or(e.eventSelection,t),eventDrag:ir(e.eventDrag,t),eventResize:ar(e.eventResize,t),eventSourceLoadingLevel:cr(i),loadingLevel:cr(i)}),c=0,s=n.pluginSystem.hooks.reducers;c<s.length;c++){a=(0,s[c])(a,t,n)}return a}function nr(e,t,n){switch(t.type){case"PREV":case"NEXT":return it(n.currentRange,e)?e:n.currentRange.start;case"SET_DATE":case"SET_VIEW_TYPE":var r=t.dateMarker||e;return n.activeRange&&!it(n.activeRange,r)?n.currentRange.start:r;default:return e}}function rr(e,t,n){switch(t.type){case"SELECT_DATES":return t.selection;case"UNSELECT_DATES":return null;default:return e}}function or(e,t){switch(t.type){case"SELECT_EVENT":return t.eventInstanceId;case"UNSELECT_EVENT":return"";default:return e}}function ir(e,t,n,r){switch(t.type){case"SET_EVENT_DRAG":var o=t.state;return{affectedEvents:o.affectedEvents,mutatedEvents:o.mutatedEvents,isEvent:o.isEvent};case"UNSET_EVENT_DRAG":return null;default:return e}}function ar(e,t,n,r){switch(t.type){case"SET_EVENT_RESIZE":var o=t.state;return{affectedEvents:o.affectedEvents,mutatedEvents:o.mutatedEvents,isEvent:o.isEvent};case"UNSET_EVENT_RESIZE":return null;default:return e}}function cr(e){var t=0;for(var n in e)e[n].isFetching&&t++;return t}var sr={start:null,end:null,allDay:Boolean};function lr(e,t,n){var r=function(e,t){var n={},r=Re(e,sr,{},n),o=r.start?t.createMarkerMeta(r.start):null,i=r.end?t.createMarkerMeta(r.end):null,a=r.allDay;null==a&&(a=o&&o.isTimeUnspecified&&(!i||i.isTimeUnspecified));return n.range={start:o?o.marker:null,end:i?i.marker:null},n.allDay=a,n}(e,t),o=r.range;if(!o.start)return null;if(!o.end){if(null==n)return null;o.end=t.add(o.start,n)}return r}function dr(e,t,n){var r=on({editable:!1},"",e.allDay,!0,n);return{def:r,ui:Rt(r,t),instance:an(r.defId,e.range),range:e.range,isStart:!0,isEnd:!0}}function ur(e,t,n,r){if(t[e])return t[e];var o=function(e,t,n,r){var o=n[e],i=r[e],a=function(e){return o&&null!==o[e]?o[e]:i&&null!==i[e]?i[e]:null},c=a("component"),s=a("superType"),l=null;if(s){if(s===e)throw new Error("Can't have a custom view type that references itself");l=ur(s,t,n,r)}!c&&l&&(c=l.component);if(!c)return null;return{type:e,component:c,defaults:Object(d.a)(Object(d.a)({},l?l.defaults:{}),o?o.options:{}),overrides:Object(d.a)(Object(d.a)({},l?l.overrides:{}),i?i.options:{})}}(e,t,n,r);return o&&(t[e]=o),o}var fr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.rootElRef={},t.handleRootEl=function(e){In(t.rootElRef,e),t.props.elRef&&In(t.props.elRef,e)},t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=this;return v(pr,{name:e.name,hookProps:e.hookProps,options:e.options,elRef:this.handleRootEl},(function(t){return v(hr,{name:e.name,hookProps:e.hookProps,options:e.options,defaultContent:e.defaultContent,backupElRef:r.rootElRef},(function(r,o){return e.children(t,vr((e.options||n.options)[e.name?e.name+"ClassNames":"classNames"],e.hookProps),r,o)}))}))},t.contextType=Dn,t}(k),hr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.innerElRef={},t}return Object(d.c)(t,e),t.prototype.render=function(e){return e.children(this.innerElRef,this.renderInnerContent())},t.prototype.componentDidMount=function(){this.updateCustomContent()},t.prototype.componentDidUpdate=function(){this.updateCustomContent()},t.prototype.renderInnerContent=function(){var e=this.context.pluginHooks.contentTypeHandlers,t=this.props,n=this.customContentInfo,r=gr((this.props.options||this.context.options)[t.name?t.name+"Content":"content"],t.hookProps),o=null;if(void 0===r&&(r=gr(t.defaultContent,t.hookProps)),void 0!==r){if(n)n.contentVal=r[n.contentKey];else for(var i in e)if(void 0!==r[i]){n=this.customContentInfo={contentKey:i,contentVal:r[i],handler:e[i]()};break}o=n?[]:r}return o},t.prototype.updateCustomContent=function(){this.customContentInfo&&this.customContentInfo.handler(this.innerElRef.current||this.props.backupElRef.current,this.customContentInfo.contentVal)},t.contextType=Dn,t}(k),pr=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleRootEl=function(e){t.rootEl=e,t.props.elRef&&In(t.props.elRef,e)},t}return Object(d.c)(t,e),t.prototype.render=function(e){return e.children(this.handleRootEl)},t.prototype.componentDidMount=function(){this.triggerMountHandler("DidMount","didMount")},t.prototype.componentWillUnmount=function(){this.triggerMountHandler("WillUnmount","willUnmount")},t.prototype.triggerMountHandler=function(e,t){var n=this.props.name,r=(this.props.options||this.context.options)[n?n+e:t];r&&r(Object(d.a)(Object(d.a)({},this.props.hookProps),{el:this.rootEl}))},t.contextType=Dn,t}(k);function mr(e){var t,n,r,o;return function(i,a,c,s){var l=(c||a.options)[e?e+"ClassNames":"classNames"],d=s||i;return t===l&&n===a&&r&&Fe(r,d)||(o=vr(l,i),t=l,n=a,r=d),o}}function vr(e,t){return"function"==typeof e&&(e=e(t)),Array.isArray(e)?e:"string"==typeof e?e.split(" "):[]}function gr(e,t){return"function"==typeof e?e(t,v):e}var br=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buildClassNames=mr("view"),t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r={view:n.view},o=this.buildClassNames(r,n);return v(pr,{name:"view",hookProps:r,elRef:e.elRef},(function(t){return e.children(t,["fc-"+e.viewSpec.type+"-view","fc-view"].concat(o))}))},t}(Rn);function yr(e){return He(e,Ar)}var kr={type:String,component:null};function Ar(e){"function"==typeof e&&(e={component:e});var t={},n=Re(e,kr,{},t),r=n.component;return t.content&&(r=function(e){return function(t){return v(Dn.Consumer,null,(function(n){return v(br,{viewSpec:t.viewSpec},(function(r,o){var i=Object(d.a)(Object(d.a)({},t),{nextDayThreshold:n.nextDayThreshold});return v(fr,{name:"",options:e,hookProps:i,elRef:r},(function(e,t,n,r){return v("div",{className:o.concat(t).join(" "),ref:e},r)}))}))}))}}(t)),{superType:n.type,component:r,options:t}}function _r(e,t){var n=yr(e),r=yr(t.overrides.views);return He(function(e,t){var n,r={};for(n in e)ur(n,r,e,t);for(n in t)ur(n,r,e,t);return r}(n,r),(function(e){return function(e,t,n){var r=e.overrides.duration||e.defaults.duration||n.dynamicOverrides.duration||n.overrides.duration,o=null,i="",a="",c={};if(r&&(o=he(r))){var s=ye(o,!me(r));i=s.unit,1===s.value&&(a=i,c=t[i]?t[i].options:{})}var l=function(t){var n=t.buttonText||{},r=e.defaults.buttonTextKey;return null!=r&&null!=n[r]?n[r]:null!=n[e.type]?n[e.type]:null!=n[a]?n[a]:void 0};return{type:e.type,component:e.component,duration:o,durationUnit:i,singleUnit:a,options:Object(d.a)(Object(d.a)(Object(d.a)(Object(d.a)(Object(d.a)(Object(d.a)(Object(d.a)({},jn),e.defaults),n.localeDefaults),n.overrides),c),e.overrides),n.dynamicOverrides),buttonTextOverride:l(n.dynamicOverrides)||l(n.overrides)||e.overrides.buttonText,buttonTextDefault:l(n.localeDefaults)||e.defaults.buttonText||l(jn)||e.type}}(e,r,t)}))}function Er(e){return{id:Ae(),deps:e.deps||[],reducers:e.reducers||[],eventDefParsers:e.eventDefParsers||[],isDraggableTransformers:e.isDraggableTransformers||[],eventDragMutationMassagers:e.eventDragMutationMassagers||[],eventDefMutationAppliers:e.eventDefMutationAppliers||[],dateSelectionTransformers:e.dateSelectionTransformers||[],datePointTransforms:e.datePointTransforms||[],dateSpanTransforms:e.dateSpanTransforms||[],views:e.views||{},viewPropsTransformers:e.viewPropsTransformers||[],isPropsValid:e.isPropsValid||null,externalDefTransforms:e.externalDefTransforms||[],eventResizeJoinTransforms:e.eventResizeJoinTransforms||[],viewContainerAppends:e.viewContainerAppends||[],eventDropTransformers:e.eventDropTransformers||[],componentInteractions:e.componentInteractions||[],calendarInteractions:e.calendarInteractions||[],themeClasses:e.themeClasses||{},eventSourceDefs:e.eventSourceDefs||[],cmdFormatter:e.cmdFormatter,recurringTypes:e.recurringTypes||[],namedTimeZonedImpl:e.namedTimeZonedImpl,initialView:e.initialView||"",elementDraggingImpl:e.elementDraggingImpl,optionChangeHandlers:e.optionChangeHandlers||{},scrollGridImpl:e.scrollGridImpl||null,contentTypeHandlers:e.contentTypeHandlers||{}}}var xr=function(){function e(){this.hooks={reducers:[],eventDefParsers:[],isDraggableTransformers:[],eventDragMutationMassagers:[],eventDefMutationAppliers:[],dateSelectionTransformers:[],datePointTransforms:[],dateSpanTransforms:[],views:{},viewPropsTransformers:[],isPropsValid:null,externalDefTransforms:[],eventResizeJoinTransforms:[],viewContainerAppends:[],eventDropTransformers:[],componentInteractions:[],calendarInteractions:[],themeClasses:{},eventSourceDefs:[],cmdFormatter:null,recurringTypes:[],namedTimeZonedImpl:null,initialView:"",elementDraggingImpl:null,optionChangeHandlers:{},scrollGridImpl:null,contentTypeHandlers:{}},this.addedHash={}}return e.prototype.add=function(e){if(!this.addedHash[e.id]){this.addedHash[e.id]=!0;for(var t=0,n=e.deps;t<n.length;t++){var r=n[t];this.add(r)}this.hooks=(o=this.hooks,i=e,{reducers:o.reducers.concat(i.reducers),eventDefParsers:o.eventDefParsers.concat(i.eventDefParsers),isDraggableTransformers:o.isDraggableTransformers.concat(i.isDraggableTransformers),eventDragMutationMassagers:o.eventDragMutationMassagers.concat(i.eventDragMutationMassagers),eventDefMutationAppliers:o.eventDefMutationAppliers.concat(i.eventDefMutationAppliers),dateSelectionTransformers:o.dateSelectionTransformers.concat(i.dateSelectionTransformers),datePointTransforms:o.datePointTransforms.concat(i.datePointTransforms),dateSpanTransforms:o.dateSpanTransforms.concat(i.dateSpanTransforms),views:Object(d.a)(Object(d.a)({},o.views),i.views),viewPropsTransformers:o.viewPropsTransformers.concat(i.viewPropsTransformers),isPropsValid:i.isPropsValid||o.isPropsValid,externalDefTransforms:o.externalDefTransforms.concat(i.externalDefTransforms),eventResizeJoinTransforms:o.eventResizeJoinTransforms.concat(i.eventResizeJoinTransforms),viewContainerAppends:o.viewContainerAppends.concat(i.viewContainerAppends),eventDropTransformers:o.eventDropTransformers.concat(i.eventDropTransformers),calendarInteractions:o.calendarInteractions.concat(i.calendarInteractions),componentInteractions:o.componentInteractions.concat(i.componentInteractions),themeClasses:Object(d.a)(Object(d.a)({},o.themeClasses),i.themeClasses),eventSourceDefs:o.eventSourceDefs.concat(i.eventSourceDefs),cmdFormatter:i.cmdFormatter||o.cmdFormatter,recurringTypes:o.recurringTypes.concat(i.recurringTypes),namedTimeZonedImpl:i.namedTimeZonedImpl||o.namedTimeZonedImpl,initialView:o.initialView||i.initialView,elementDraggingImpl:o.elementDraggingImpl||i.elementDraggingImpl,optionChangeHandlers:Object(d.a)(Object(d.a)({},o.optionChangeHandlers),i.optionChangeHandlers),scrollGridImpl:i.scrollGridImpl||o.scrollGridImpl,contentTypeHandlers:Object(d.a)(Object(d.a)({},o.contentTypeHandlers),i.contentTypeHandlers)})}var o,i},e}();var wr,Sr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e){var t,n,r=e.model,o=!1,i=r.center;return r.left?(o=!0,t=r.left):t=r.start,r.right?(o=!0,n=r.right):n=r.end,v("div",{class:[e.extraClassName||"","fc-toolbar",o?"fc-toolbar-ltr":""].join(" ")},this.renderSection(t||[]),this.renderSection(i||[]),this.renderSection(n||[]))},t.prototype.renderSection=function(e){var t=this.props;return v(Dr,{widgetGroups:e,title:t.title,activeButton:t.activeButton,isTodayEnabled:t.isTodayEnabled,isPrevEnabled:t.isPrevEnabled,isNextEnabled:t.isNextEnabled})},t}(Rn),Dr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e){var t=this.context.theme;return v("div",{class:"fc-toolbar-chunk"},e.widgetGroups.map((function(n){for(var r=[],o=!0,i=0,a=n;i<a.length;i++){var c=a[i],s=c.buttonName,l=c.buttonClick,u=c.buttonText,f=c.buttonIcon;if("title"===s)o=!1,r.push(v("h2",{className:"fc-toolbar-title"},e.title));else{var h=f?{"aria-label":s}:{},p=["fc-"+s+"-button",t.getClass("button")];s===e.activeButton&&p.push(t.getClass("buttonActive"));var m=!e.isTodayEnabled&&"today"===s||!e.isPrevEnabled&&"prev"===s||!e.isNextEnabled&&"next"===s;r.push(v("button",Object(d.a)({disabled:m,class:p.join(" "),onClick:l},h),u||(f?v("span",{class:f}):"")))}}return r.length>1?v("div",{class:o&&t.getClass("buttonGroup")||""},r):r[0]})))},t}(Rn),Cr=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e){var t=["fc-view-harness",e.aspectRatio||e.liquid||e.height?"fc-view-harness-active":"fc-view-harness-passive"],n="",r="";return e.aspectRatio?r=1/e.aspectRatio*100+"%":n=e.height||"",v("div",{ref:e.elRef,onClick:e.onClick,class:t.join(" "),style:{height:n,paddingBottom:r}},e.children)},t}(Rn);function Rr(){return null==wr&&(wr=function(){var e=document.createElement("div");e.style.position="absolute",e.style.top="0",e.style.left="0",e.innerHTML='<table style="height:100px"><tr><td><div style="height:100%"></div></td></tr></table>',document.body.appendChild(e);var t=e.querySelector("div").offsetHeight>0;return document.body.removeChild(e),t}()),wr}var Or=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buildViewContext=at(Cn),t.parseBusinessHours=at((function(e){return sn(e,t.context.calendar)})),t.buildViewPropTransformers=at(Nr),t.buildToolbarProps=at(Tr),t.reportClassNames=at(Mr),t.reportHeight=at(jr),t.handleNavLinkClick=Y("a[data-navlink]",t._handleNavLinkClick.bind(t)),t.headerRef={},t.footerRef={},t.viewRef={},t.state={forPrint:!1},t.handleBeforePrint=function(){t.setState({forPrint:!0})},t.handleAfterPrint=function(){t.setState({forPrint:!1})},t}return Object(d.c)(t,e),Object.defineProperty(t.prototype,"view",{get:function(){return this.viewRef.current},enumerable:!0,configurable:!0}),t.prototype.render=function(e,t,n){var r,o=n.calendar,i=n.options,a=n.headerToolbar,c=n.footerToolbar,s=this.buildToolbarProps(e.viewSpec,e.dateProfile,e.dateProfileGenerator,e.currentDate,o.getNow(),e.title),l="",u=!1,f="";return Ir(i)?f="":null!=i.height?(l=i.height,u=!0):null!=i.contentHeight?f=i.contentHeight:r=Math.max(i.aspectRatio,.5),e.onClassNameChange&&this.reportClassNames(e.onClassNameChange,t.forPrint,i.direction,n.theme),e.onHeightChange&&this.reportHeight(e.onHeightChange,l),v(y,null,a&&v(Sr,Object(d.a)({ref:this.headerRef,extraClassName:"fc-header-toolbar",model:a},s)),v(Cr,{liquid:u,height:f,aspectRatio:r,onClick:this.handleNavLinkClick},this.renderView(e,this.context),this.buildAppendContent()),c&&v(Sr,Object(d.a)({ref:this.footerRef,extraClassName:"fc-footer-toolbar",model:c},s)))},t.prototype.componentDidMount=function(){window.addEventListener("beforeprint",this.handleBeforePrint),window.addEventListener("afterprint",this.handleAfterPrint),this.context.calendar.publiclyTrigger("datesDidUpdate")},t.prototype.componentDidUpdate=function(e){e.dateProfile!==this.props.dateProfile&&this.context.calendar.publiclyTrigger("datesDidUpdate")},t.prototype.componentWillUnmount=function(){window.removeEventListener("beforeprint",this.handleBeforePrint),window.removeEventListener("afterprint",this.handleAfterPrint),this.props.onClassNameChange&&this.props.onClassNameChange([]),this.props.onHeightChange&&this.props.onHeightChange("")},t.prototype._handleNavLinkClick=function(e,t){var n=this.context,r=n.dateEnv,o=n.calendar,i=t.getAttribute("data-navlink");i=i?JSON.parse(i):{};var a=r.createMarker(i.date),c=i.type,s=o.viewOpt("navLink"+xe(c)+"Click");"function"==typeof s?s(r.toDate(a),e):("string"==typeof s&&(c=s),o.zoomTo(a,c))},t.prototype.buildAppendContent=function(){var e=this.context,t=e.pluginHooks,n=e.calendar;return t.viewContainerAppends.map((function(e){return e(n)}))},t.prototype.renderView=function(e,t){for(var n=t.pluginHooks,r=t.options,o=e.viewSpec,i={viewSpec:o,dateProfileGenerator:e.dateProfileGenerator,dateProfile:e.dateProfile,businessHours:this.parseBusinessHours(o.options.businessHours),eventStore:e.eventStore,eventUiBases:e.eventUiBases,dateSelection:e.dateSelection,eventSelection:e.eventSelection,eventDrag:e.eventDrag,eventResize:e.eventResize,isHeightAuto:this.state.forPrint||Ir(r),forPrint:this.state.forPrint},a=0,c=this.buildViewPropTransformers(n.viewPropsTransformers);a<c.length;a++){var s=c[a];Object(d.a)(i,s.transform(i,o,e,r))}var l=this.buildViewContext(t.calendar,t.pluginHooks,t.dateEnv,t.theme,t.view,o.options),u=o.component;return v(Dn.Provider,{value:l},v(u,Object(d.a)({ref:this.viewRef},i)))},t}(Rn);function Tr(e,t,n,r,o,i){var a=n.build(o),c=n.buildPrev(t,r),s=n.buildNext(t,r);return{title:i,activeButton:e.type,isTodayEnabled:a.isValid&&!it(t.currentRange,o),isPrevEnabled:c.isValid,isNextEnabled:s.isValid}}function Ir(e){return"auto"===e.height||"auto"===e.contentHeight}function Mr(e,t,n,r){e(function(e,t,n){var r=["fc",e?"fc-media-print":"fc-media-screen","fc-direction-"+t,n.getClass("root")];Rr()||r.push("fc-liquid-hack");return r}(t,n,r))}function jr(e,t){e(t)}function Nr(e){return e.map((function(e){return new e}))}var Pr=function(){function e(e){this.component=e.component}return e.prototype.destroy=function(){},e}();var Br={},Hr=function(e){function t(t){var n=e.call(this,t)||this;return n.handleSegClick=function(e,t){var r=n.component,o=r.context,i=o.calendar,a=o.view,c=Dt(t);if(c&&r.isValidSegDownEl(e.target)){var s=Q(e.target,".fc-event-forced-url"),l=s?s.querySelector("a[href]").href:"";i.publiclyTrigger("eventClick",[{el:t,event:new xt(r.context.calendar,c.eventRange.def,c.eventRange.instance),jsEvent:e,view:a}]),l&&!e.defaultPrevented&&(window.location.href=l)}},n.destroy=q(t.el,"click",".fc-event",n.handleSegClick),n}return Object(d.c)(t,e),t}(Pr),zr=function(e){function t(t){var n=e.call(this,t)||this;n.handleEventElRemove=function(e){e===n.currentSegEl&&n.handleSegLeave(null,n.currentSegEl)},n.handleSegEnter=function(e,t){Dt(t)&&(t.classList.add("fc-event-resizable-mouse"),n.currentSegEl=t,n.triggerEvent("eventMouseEnter",e,t))},n.handleSegLeave=function(e,t){n.currentSegEl&&(t.classList.remove("fc-event-resizable-mouse"),n.currentSegEl=null,n.triggerEvent("eventMouseLeave",e,t))};var r,o,i,a,c,s=t.component;return n.removeHoverListeners=(r=t.el,o=".fc-event",i=n.handleSegEnter,a=n.handleSegLeave,q(r,"mouseover",o,(function(e,t){if(t!==c){c=t,i(e,t);var n=function(e){c=null,a(e,t),t.removeEventListener("mouseleave",n)};t.addEventListener("mouseleave",n)}}))),s.context.calendar.on("eventElRemove",n.handleEventElRemove),n}return Object(d.c)(t,e),t.prototype.destroy=function(){this.removeHoverListeners(),this.component.context.calendar.off("eventElRemove",this.handleEventElRemove)},t.prototype.triggerEvent=function(e,t,n){var r=this.component,o=r.context,i=o.calendar,a=o.view,c=Dt(n);t&&!r.isValidSegDownEl(t.target)||i.publiclyTrigger(e,[{el:n,event:new xt(i,c.eventRange.def,c.eventRange.instance),jsEvent:t,view:a}])},t}(Pr),Ur=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t}(_n);Ur.prototype.classes={root:"fc-theme-standard",buttonGroup:"fc-button-group",button:"fc-button fc-button-primary",buttonActive:"fc-button-active"},Ur.prototype.baseIconClass="fc-icon",Ur.prototype.iconClasses={close:"fc-icon-x",prev:"fc-icon-chevron-left",next:"fc-icon-chevron-right",prevYear:"fc-icon-chevrons-left",nextYear:"fc-icon-chevrons-right"},Ur.prototype.rtlIconClasses={prev:"fc-icon-chevron-right",next:"fc-icon-chevron-left",prevYear:"fc-icon-chevrons-right",nextYear:"fc-icon-chevrons-left"},Ur.prototype.iconOverrideOption="buttonIcons",Ur.prototype.iconOverrideCustomButtonOption="icon",Ur.prototype.iconOverridePrefix="fc-icon-";var Fr=function(){function e(e){this.drainedOption=e,this.isRunning=!1,this.isDirty=!1,this.pauseDepths={},this.timeoutId=0}return e.prototype.request=function(e){this.isDirty=!0,this.isPaused()||(this.clearTimeout(),null==e?this.tryDrain():this.timeoutId=setTimeout(this.tryDrain.bind(this),e))},e.prototype.pause=function(e){void 0===e&&(e="");var t=this.pauseDepths;t[e]=(t[e]||0)+1,this.clearTimeout()},e.prototype.resume=function(e,t){void 0===e&&(e="");var n=this.pauseDepths;if(e in n){if(t)delete n[e];else--n[e]<=0&&delete n[e];this.tryDrain()}},e.prototype.isPaused=function(){return Object.keys(this.pauseDepths).length},e.prototype.tryDrain=function(){if(!this.isRunning&&!this.isPaused()){for(this.isRunning=!0;this.isDirty;)this.isDirty=!1,this.drained();this.isRunning=!1}},e.prototype.clear=function(){this.clearTimeout(),this.isDirty=!1,this.pauseDepths={}},e.prototype.clearTimeout=function(){this.timeoutId&&(clearTimeout(this.timeoutId),this.timeoutId=0)},e.prototype.drained=function(){this.drainedOption&&this.drainedOption()},e}(),Lr=function(){function e(e,t){this.runTaskOption=e,this.drainedOption=t,this.queue=[],this.delayedRunner=new Fr(this.drain.bind(this))}return e.prototype.request=function(e,t){this.queue.push(e),this.delayedRunner.request(t)},e.prototype.pause=function(e){this.delayedRunner.pause(e)},e.prototype.resume=function(e,t){this.delayedRunner.resume(e,t)},e.prototype.drain=function(){for(var e=this.queue;e.length;){for(var t=[],n=void 0;n=e.shift();)this.runTask(n),t.push(n);this.drained(t)}},e.prototype.runTask=function(e){this.runTaskOption&&this.runTaskOption(e)},e.prototype.drained=function(e){this.drainedOption&&this.drainedOption(e)},e}();function Qr(e,t,n,r,o){var i=null;"GET"===(e=e.toUpperCase())?t=function(e,t){return e+(-1===e.indexOf("?")?"?":"&")+Vr(t)}(t,n):i=Vr(n);var a=new XMLHttpRequest;a.open(e,t,!0),"GET"!==e&&a.setRequestHeader("Content-Type","application/x-www-form-urlencoded"),a.onload=function(){if(a.status>=200&&a.status<400){var e=!1,t=void 0;try{t=JSON.parse(a.responseText),e=!0}catch(n){}e?r(t,a):o("Failure parsing JSON",a)}else o("Request failed",a)},a.onerror=function(){o("Request failed",a)},a.send(i)}function Vr(e){var t=[];for(var n in e)t.push(encodeURIComponent(n)+"="+encodeURIComponent(e[n]));return t.join("&")}function Wr(e,t){for(var n=Ue(t.state.eventSources),r=[],o=0,i=e;o<i.length;o++){for(var a=i[o],c=!1,s=0;s<n.length;s++)if(n[s]._raw===a){n.splice(s,1),c=!0;break}c||r.push(a)}for(var l=0,d=n;l<d.length;l++){var u=d[l];t.dispatch({type:"REMOVE_EVENT_SOURCE",sourceId:u.sourceId})}for(var f=0,h=r;f<h.length;f++){var p=h[f];t.addEventSource(p)}}var Zr=[Er({eventSourceDefs:[{ignoreRange:!0,parseMeta:function(e){return Array.isArray(e)?e:Array.isArray(e.events)?e.events:null},fetch:function(e,t){t({rawEvents:e.eventSource.meta})}}]}),Er({eventSourceDefs:[{parseMeta:function(e){return"function"==typeof e?e:"function"==typeof e.events?e.events:null},fetch:function(e,t,n){var r=e.calendar.dateEnv;!function(e,t,n){var r=!1,o=function(){r||(r=!0,t.apply(this,arguments))},i=function(){r||(r=!0,n&&n.apply(this,arguments))},a=e(o,i);a&&"function"==typeof a.then&&a.then(o,i)}(e.eventSource.meta.bind(null,{start:r.toDate(e.range.start),end:r.toDate(e.range.end),startStr:r.formatIso(e.range.start),endStr:r.formatIso(e.range.end),timeZone:r.timeZone}),(function(e){t({rawEvents:e})}),n)}}]}),Er({eventSourceDefs:[{parseMeta:function(e){if("string"==typeof e)e={url:e};else if(!e||"object"!=typeof e||!e.url)return null;return{url:e.url,method:(e.method||"GET").toUpperCase(),extraParams:e.extraParams,startParam:e.startParam,endParam:e.endParam,timeZoneParam:e.timeZoneParam}},fetch:function(e,t,n){var r=e.eventSource.meta,o=function(e,t,n){var r,o,i,a,c=n.dateEnv,s={};null==(r=e.startParam)&&(r=n.opt("startParam"));null==(o=e.endParam)&&(o=n.opt("endParam"));null==(i=e.timeZoneParam)&&(i=n.opt("timeZoneParam"));a="function"==typeof e.extraParams?e.extraParams():e.extraParams||{};Object(d.a)(s,a),s[r]=c.formatIso(t.start),s[o]=c.formatIso(t.end),"local"!==c.timeZone&&(s[i]=c.timeZone);return s}(r,e.range,e.calendar);Qr(r.method,r.url,o,(function(e,n){t({rawEvents:e,xhr:n})}),(function(e,t){n({message:e,xhr:t})}))}}]}),Er({recurringTypes:[{parse:function(e,t,n){var r,o,i=n.createMarker.bind(n),a=Re(e,{daysOfWeek:null,startTime:he,endTime:he,startRecur:i,endRecur:i},{},t),c=!1;for(var s in a)if(null!=a[s]){c=!0;break}if(c){var l=null;return"duration"in t&&(l=he(t.duration),delete t.duration),!l&&a.startTime&&a.endTime&&(r=a.endTime,o=a.startTime,l={years:r.years-o.years,months:r.months-o.months,days:r.days-o.days,milliseconds:r.milliseconds-o.milliseconds}),{allDayGuess:Boolean(!a.startTime&&!a.endTime),duration:l,typeData:a}}return null},expand:function(e,t,n){var r=tt(t,{start:e.startRecur,end:e.endRecur});return r?function(e,t,n,r){var o=e?ze(e):null,i=re(n.start),a=n.end,c=[];for(;i<a;){var s=void 0;o&&!o[i.getUTCDay()]||(s=t?r.add(i,t):i,c.push(s)),i=X(i,1)}return c}(e.daysOfWeek,e.startTime,r,n):[]}}]}),Er({optionChangeHandlers:{events:function(e,t){Wr([e],t)},eventSources:Wr,plugins:function(e,t){t.addPluginDefs(e)}}}),Er({contentTypeHandlers:{html:function(){return z},domNodes:function(){return U}}})],Gr=function(){function e(e,t){var n=this;this.organizeRawLocales=at(Bn),this.buildDateEnv=at(Yr),this.computeTitle=at(eo),this.buildTheme=at(qr),this.buildContext=at(Cn),this.buildEventUiSingleBase=at(Jr),this.buildSelectionConfig=at(Kr),this.buildEventUiBySource=at(Xr,Fe),this.buildEventUiBases=at($r),this.resizeHandlers=[],this.interactionsStore={},this.isRendering=!1,this.isRendered=!1,this.currentClassNames=[],this.componentRef={},this.handleClassNames=function(e){for(var t=n.el.classList,r=0,o=n.currentClassNames;r<o.length;r++){var i=o[r];t.remove(i)}for(var a=0,c=e;a<c.length;a++){i=c[a];t.add(i)}n.currentClassNames=e},this.handleHeightChange=function(e){G(n.el,"height",e)},this.resizeRunner=new Fr((function(){n.triggerResizeHandlers(!0),n.publiclyTrigger("windowResize",[n.context.view])})),this.handleWindowResize=function(e){var t=n.context.options;t.handleWindowResize&&e.target===window&&n.resizeRunner.request(t.windowResizeDelay)},this.addResizeHandler=function(e){n.resizeHandlers.push(e)},this.removeResizeHandler=function(e){!function(e,t){for(var n=0,r=0;r<e.length;)e[r]===t?(e.splice(r,1),n++):r++}(n.resizeHandlers,e)},this.el=e;var r=this.optionsManager=new Un(t||{});this.pluginSystem=new xr;var o=this.renderRunner=new Fr(this.updateComponent.bind(this)),i=this.actionRunner=new Lr(this.runAction.bind(this),(function(){n.updateDerivedState(),o.request(r.computed.rerenderDelay)}));i.pause(),this.addPluginDefs(Zr.concat(r.computed.plugins||[])),this.onOptionsChange(),this.publiclyTrigger("_init"),this.hydrate(),i.resume(),this.calendarInteractions=this.pluginSystem.hooks.calendarInteractions.map((function(e){return new e(n)}))}return Object.defineProperty(e.prototype,"component",{get:function(){return this.componentRef.current},enumerable:!0,configurable:!0}),e.prototype.addPluginDefs=function(e){for(var t=0,n=e;t<n.length;t++){var r=n[t];this.pluginSystem.add(r)}},e.prototype.render=function(){this.isRendering?this.setOption("renderId",Ae()):(this.isRendering=!0,this.renderableEventStore={defs:{},instances:{}},this.renderRunner.request(),window.addEventListener("resize",this.handleWindowResize))},e.prototype.destroy=function(){this.isRendering&&(this.isRendering=!1,this.renderRunner.request(),this.resizeRunner.clear(),window.removeEventListener("resize",this.handleWindowResize))},e.prototype.hydrate=function(){this.state=this.buildInitialState();var e=this.opt("eventSources")||[],t=this.opt("events"),n=[];t&&e.unshift(t);for(var r=0,o=e;r<o.length;r++){var i=Yn(o[r],this);i&&n.push(i)}this.dispatch({type:"INIT"}),this.dispatch({type:"ADD_EVENT_SOURCES",sources:n}),this.dispatch({type:"SET_VIEW_TYPE",viewType:this.opt("initialView")||this.pluginSystem.hooks.initialView})},e.prototype.buildInitialState=function(){return{viewType:null,loadingLevel:0,eventSourceLoadingLevel:0,currentDate:this.getInitialDate(),dateProfile:null,eventSources:{},eventStore:{defs:{},instances:{}},dateSelection:null,eventSelection:"",eventDrag:null,eventResize:null}},e.prototype.dispatch=function(e){switch(this.actionRunner.request(e),e.type){case"SET_EVENT_DRAG":case"SET_EVENT_RESIZE":this.renderRunner.tryDrain()}},e.prototype.runAction=function(e){var t=this.state,n=this.state=tr(this.state,e,this);!t.loadingLevel&&n.loadingLevel?this.publiclyTrigger("loading",[!0]):t.loadingLevel&&!n.loadingLevel&&this.publiclyTrigger("loading",[!1])},e.prototype.batchRendering=function(e){this.renderRunner.pause("batchRendering"),e(),this.renderRunner.resume("batchRendering")},e.prototype.pauseRendering=function(){this.renderRunner.pause("pauseRendering")},e.prototype.resumeRendering=function(){this.renderRunner.resume("pauseRendering",!0)},e.prototype.updateComponent=function(){this.isRendering?(this.renderComponent(),this.isRendered=!0):this.isRendered&&(this.destroyComponent(),this.isRendered=!1)},e.prototype.renderComponent=function(){var e=this.context,t=this.state,n=t.viewType,r=this.viewSpecs[n],o=e.view,i=this.renderableEventStore=t.eventSourceLoadingLevel&&!this.opt("progressiveEventRendering")?this.renderableEventStore:t.eventStore,a=this.buildEventUiSingleBase(r.options),c=this.buildEventUiBySource(t.eventSources),s=this.eventUiBases=this.buildEventUiBases(i.defs,a,c);P(v(Dn.Provider,{value:e},v(Or,Object(d.a)({ref:this.componentRef},t,{viewSpec:r,dateProfileGenerator:this.dateProfileGenerators[n],dateProfile:t.dateProfile,eventStore:i,eventUiBases:s,dateSelection:t.dateSelection,eventSelection:t.eventSelection,eventDrag:t.eventDrag,eventResize:t.eventResize,title:o.title,onClassNameChange:this.handleClassNames,onHeightChange:this.handleHeightChange}))),this.el),En()},e.prototype.destroyComponent=function(){P(null,this.el);for(var e=0,t=this.calendarInteractions;e<t.length;e++){t[e].destroy()}this.publiclyTrigger("_destroyed")},e.prototype.setOption=function(e,t){var n;this.mutateOptions(((n={})[e]=t,n),[],!0)},e.prototype.getOption=function(e){return this.optionsManager.computed[e]},e.prototype.opt=function(e){return this.optionsManager.computed[e]},e.prototype.viewOpt=function(e){return this.viewSpecs[this.state.viewType].options[e]},e.prototype.mutateOptions=function(e,t,n){var r=this;void 0===t&&(t=[]);var o=this.pluginSystem.hooks.optionChangeHandlers,i={},a={},c=this.dateEnv,s=!1,l=Boolean(t.length);for(var d in e)o[d]?a[d]=e[d]:i[d]=e[d];for(var u in i)/^(initialDate|initialView)$/.test(u)||(l=!0,"timeZone"===u&&(s=!0));this.optionsManager.mutate(i,t,n),l&&this.onOptionsChange(),this.batchRendering((function(){for(var e in l&&(s&&r.dispatch({type:"CHANGE_TIMEZONE",oldDateEnv:c}),r.dispatch({type:"SET_VIEW_TYPE",viewType:r.state.viewType})),a)o[e](a[e],r)}))},e.prototype.onOptionsChange=function(){var e=this,t=this.pluginSystem.hooks,n=this.optionsManager.computed,r=this.organizeRawLocales(n.locales),o=this.buildDateEnv(n,t,r);this.availableRawLocales=r.map,this.dateEnv=o,this.viewSpecs=_r(t.views,this.optionsManager),this.slotMinTime=he(n.slotMinTime),this.slotMaxTime=he(n.slotMaxTime),this.dateProfileGenerators=He(this.viewSpecs,(function(t){return new(t.options.dateProfileGeneratorClass||er)(t,e)})),this.defaultAllDayEventDuration=he(n.defaultAllDayEventDuration),this.defaultTimedEventDuration=he(n.defaultTimedEventDuration)},e.prototype.updateDerivedState=function(){var e=this.pluginSystem.hooks,t=this.optionsManager.computed,n=this.dateEnv,r=this.state,o=r.viewType,i=r.dateProfile,a=this.viewSpecs[o];if(!a)throw new Error('View type "'+o+'" is not valid');var c=this.buildTheme(t,e),s=this.computeTitle(i,n,a.options),l=this.buildViewApi(o,s,i,n),d=this.buildContext(this,e,n,c,l,t);this.context=d,this.selectionConfig=this.buildSelectionConfig(t)},e.prototype.buildViewApi=function(e,t,n,r){var o=this.view;return o&&o.type===e||(o=this.view={type:e}),o.title=t,o.activeStart=r.toDate(n.activeRange.start),o.activeEnd=r.toDate(n.activeRange.end),o.currentStart=r.toDate(n.currentRange.start),o.currentEnd=r.toDate(n.currentRange.end),o},e.prototype.getAvailableLocaleCodes=function(){return Object.keys(this.availableRawLocales)},e.prototype.hasPublicHandlers=function(e){return this.hasHandlers(e)||this.opt(e)},e.prototype.publiclyTrigger=function(e,t){var n=this.opt(e);if(this.triggerWith(e,this,t),n)return n.apply(this,t)},e.prototype.isValidViewType=function(e){return Boolean(this.viewSpecs[e])},e.prototype.changeView=function(e,t){var n=null;t&&(t.start&&t.end?(this.optionsManager.mutate({visibleRange:t},[]),this.onOptionsChange()):n=this.dateEnv.createMarker(t)),this.unselect(),this.dispatch({type:"SET_VIEW_TYPE",viewType:e,dateMarker:n})},e.prototype.zoomTo=function(e,t){var n;t=t||"day",n=this.viewSpecs[t]||this.getUnitViewSpec(t),this.unselect(),n?this.dispatch({type:"SET_VIEW_TYPE",viewType:n.type,dateMarker:e}):this.dispatch({type:"SET_DATE",dateMarker:e})},e.prototype.getUnitViewSpec=function(e){var t,n,r=[].concat(this.context.viewsWithButtons);for(var o in this.viewSpecs)r.push(o);for(t=0;t<r.length;t++)if((n=this.viewSpecs[r[t]])&&n.singleUnit===e)return n},e.prototype.getInitialDate=function(){var e=this.opt("initialDate");return null!=e?this.dateEnv.createMarker(e):this.getNow()},e.prototype.prev=function(){this.unselect(),this.dispatch({type:"PREV"})},e.prototype.next=function(){this.unselect(),this.dispatch({type:"NEXT"})},e.prototype.prevYear=function(){this.unselect(),this.dispatch({type:"SET_DATE",dateMarker:this.dateEnv.addYears(this.state.currentDate,-1)})},e.prototype.nextYear=function(){this.unselect(),this.dispatch({type:"SET_DATE",dateMarker:this.dateEnv.addYears(this.state.currentDate,1)})},e.prototype.today=function(){this.unselect(),this.dispatch({type:"SET_DATE",dateMarker:this.getNow()})},e.prototype.gotoDate=function(e){this.unselect(),this.dispatch({type:"SET_DATE",dateMarker:this.dateEnv.createMarker(e)})},e.prototype.incrementDate=function(e){var t=he(e);t&&(this.unselect(),this.dispatch({type:"SET_DATE",dateMarker:this.dateEnv.add(this.state.currentDate,t)}))},e.prototype.getDate=function(){return this.dateEnv.toDate(this.state.currentDate)},e.prototype.formatDate=function(e,t){var n=this.dateEnv;return n.format(n.createMarker(e),bt(t))},e.prototype.formatRange=function(e,t,n){var r=this.dateEnv;return r.formatRange(r.createMarker(e),r.createMarker(t),bt(n,this.opt("defaultRangeSeparator")),n)},e.prototype.formatIso=function(e,t){var n=this.dateEnv;return n.formatIso(n.createMarker(e),{omitTime:t})},e.prototype.updateSize=function(){this.triggerResizeHandlers(!0),En()},e.prototype.triggerResizeHandlers=function(e){for(var t=0,n=this.resizeHandlers;t<n.length;t++){(0,n[t])(e)}},e.prototype.registerInteractiveComponent=function(e,t){var n=function(e,t){return{component:e,el:t.el,useEventCenter:null==t.useEventCenter||t.useEventCenter}}(e,t),r=[Hr,zr].concat(this.pluginSystem.hooks.componentInteractions).map((function(e){return new e(n)}));this.interactionsStore[e.uid]=r,Br[e.uid]=n},e.prototype.unregisterInteractiveComponent=function(e){for(var t=0,n=this.interactionsStore[e.uid];t<n.length;t++){n[t].destroy()}delete this.interactionsStore[e.uid],delete Br[e.uid]},e.prototype.select=function(e,t){var n=lr(null==t?null!=e.start?e:{start:e,end:null}:{start:e,end:t},this.dateEnv,he({days:1}));n&&(this.dispatch({type:"SELECT_DATES",selection:n}),this.triggerDateSelect(n))},e.prototype.unselect=function(e){this.state.dateSelection&&(this.dispatch({type:"UNSELECT_DATES"}),this.triggerDateUnselect(e))},e.prototype.triggerDateSelect=function(e,t){var n=Object(d.a)(Object(d.a)({},this.buildDateSpanApi(e)),{jsEvent:t?t.origEvent:null,view:this.view});this.publiclyTrigger("select",[n])},e.prototype.triggerDateUnselect=function(e){this.publiclyTrigger("unselect",[{jsEvent:e?e.origEvent:null,view:this.view}])},e.prototype.triggerDateClick=function(e,t,n,r){var o=Object(d.a)(Object(d.a)({},this.buildDatePointApi(e)),{dayEl:t,jsEvent:r,view:n});this.publiclyTrigger("dateClick",[o])},e.prototype.buildDatePointApi=function(e){for(var t,n,r={},o=0,i=this.pluginSystem.hooks.datePointTransforms;o<i.length;o++){var a=i[o];Object(d.a)(r,a(e,this))}return Object(d.a)(r,(t=e,{date:(n=this.dateEnv).toDate(t.range.start),dateStr:n.formatIso(t.range.start,{omitTime:t.allDay}),allDay:t.allDay})),r},e.prototype.buildDateSpanApi=function(e){for(var t,n,r={},o=0,i=this.pluginSystem.hooks.dateSpanTransforms;o<i.length;o++){var a=i[o];Object(d.a)(r,a(e,this))}return Object(d.a)(r,(t=e,{start:(n=this.dateEnv).toDate(t.range.start),end:n.toDate(t.range.end),startStr:n.formatIso(t.range.start,{omitTime:t.allDay}),endStr:n.formatIso(t.range.end,{omitTime:t.allDay}),allDay:t.allDay})),r},e.prototype.getNow=function(){var e=this.opt("now");return"function"==typeof e&&(e=e()),null==e?this.dateEnv.createNowMarker():this.dateEnv.createMarker(e)},e.prototype.getDefaultEventEnd=function(e,t){var n=t;return e?(n=re(n),n=this.dateEnv.add(n,this.defaultAllDayEventDuration)):n=this.dateEnv.add(n,this.defaultTimedEventDuration),n},e.prototype.addEvent=function(e,t){if(e instanceof xt){var n=e._def,r=e._instance;return this.state.eventStore.defs[n.defId]||this.dispatch({type:"ADD_EVENTS",eventStore:Ze({def:n,instance:r})}),e}var o;if(t instanceof Et)o=t.internalEventSource.sourceId;else if(null!=t){var i=this.getEventSourceById(t);if(!i)return console.warn('Could not find an event source with ID "'+t+'"'),null;o=i.internalEventSource.sourceId}var a=rn(e,o,this);return a?(this.dispatch({type:"ADD_EVENTS",eventStore:Ze(a)}),new xt(this,a.def,a.def.recurringDef?null:a.instance)):null},e.prototype.getEventById=function(e){var t=this.state.eventStore,n=t.defs,r=t.instances;for(var o in e=String(e),n){var i=n[o];if(i.publicId===e){if(i.recurringDef)return new xt(this,i,null);for(var a in r){var c=r[a];if(c.defId===i.defId)return new xt(this,i,c)}}}return null},e.prototype.getEvents=function(){var e=this.state.eventStore,t=e.defs,n=e.instances,r=[];for(var o in n){var i=n[o],a=t[i.defId];r.push(new xt(this,a,i))}return r},e.prototype.removeAllEvents=function(){this.dispatch({type:"REMOVE_ALL_EVENTS"})},e.prototype.getEventSources=function(){var e=this.state.eventSources,t=[];for(var n in e)t.push(new Et(this,e[n]));return t},e.prototype.getEventSourceById=function(e){var t=this.state.eventSources;for(var n in e=String(e),t)if(t[n].publicId===e)return new Et(this,t[n]);return null},e.prototype.addEventSource=function(e){if(e instanceof Et)return this.state.eventSources[e.internalEventSource.sourceId]||this.dispatch({type:"ADD_EVENT_SOURCES",sources:[e.internalEventSource]}),e;var t=Yn(e,this);return t?(this.dispatch({type:"ADD_EVENT_SOURCES",sources:[t]}),new Et(this,t)):null},e.prototype.removeAllEventSources=function(){this.dispatch({type:"REMOVE_ALL_EVENT_SOURCES"})},e.prototype.refetchEvents=function(){this.dispatch({type:"FETCH_EVENT_SOURCES"})},e.prototype.scrollToTime=function(e){var t=he(e);t&&this.trigger("scrollRequest",{time:t})},e}();function Yr(e,t,n){var r=Hn(e.locale||n.defaultCode,n.map);return new Wn({calendarSystem:"gregory",timeZone:e.timeZone,namedTimeZoneImpl:t.namedTimeZonedImpl,locale:r,weekNumberCalculation:e.weekNumberCalculation,firstDay:e.firstDay,weekText:e.weekText,cmdFormatter:t.cmdFormatter})}function qr(e,t){return new(t.themeClasses[e.themeSystem]||Ur)(e)}function Kr(e){return Jt("select",e,this)}function Jr(e){return e.editable&&(e=Object(d.a)(Object(d.a)({},e),{eventEditable:!0})),Jt("event",e,this)}function Xr(e){return He(e,(function(e){return e.ui}))}function $r(e,t,n){var r={"":t};for(var o in e){var i=e[o];i.sourceId&&n[i.sourceId]&&(r[o]=n[i.sourceId])}return r}function eo(e,t,n){var r;return r=/^(year|month)$/.test(e.currentRangeUnit)?e.currentRange:e.activeRange,t.formatRange(r.start,r.end,bt(n.titleFormat||function(e){var t=e.currentRangeUnit;if("year"===t)return{year:"numeric"};if("month"===t)return{year:"numeric",month:"long"};var n=ne(e.currentRange.start,e.currentRange.end);return null!==n&&n>1?{year:"numeric",month:"short",day:"numeric"}:{year:"numeric",month:"long",day:"numeric"}}(e),n.titleRangeSeparator),{isEndExclusive:e.isRangeAllDay})}gn.mixInto(Gr);!function(){function e(e){this.emitter=new gn}e.prototype.destroy=function(){},e.prototype.setMirrorIsVisible=function(e){},e.prototype.setMirrorNeedsRevert=function(e){},e.prototype.setAutoScrollEnabled=function(e){}}();Boolean;var to="fc-col-header-cell",no=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=n.dateEnv,o=n.options,i=e.date,a=un(i,e.todayRange,null,e.dateProfile),c=[to].concat(fn(a,n.theme)),s=r.format(i,e.dayHeaderFormat),l=o.navLinks&&!a.isDisabled&&e.colCnt>1?hn(i):null,u=Object(d.a)(Object(d.a)(Object(d.a)({date:r.toDate(i),view:n.view},e.extraHookProps),{text:s}),a);return v(fr,{name:"dayHeader",hookProps:u,defaultContent:oo},(function(t,n,r,o){return v("th",Object(d.a)({ref:t,className:c.concat(n).join(" "),"data-date":a.isDisabled?void 0:yt(i),colSpan:e.colSpan},e.extraDataAttrs),!a.isDisabled&&v("a",{"data-navlink":l,class:["fc-col-header-cell-cushion",e.isSticky?"fc-sticky":""].join(" "),ref:r},o))}))},t}(Rn),ro=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=e.dow,o=n.dateEnv,i=X(new Date(2592e5),r),a={dow:r,isDisabled:!1,isFuture:!1,isPast:!1,isToday:!1,isOther:!1},c=[to].concat(fn(a,n.theme),e.extraClassNames||[]),s=o.format(i,e.dayHeaderFormat),l=Object(d.a)(Object(d.a)(Object(d.a)(Object(d.a)({date:i},a),{view:n.view}),e.extraHookProps),{text:s});return v(fr,{name:"dayHeader",hookProps:l,defaultContent:oo},(function(t,n,r,o){return v("th",Object(d.a)({ref:t,className:c.concat(n).join(" "),colSpan:e.colSpan},e.extraDataAttrs),v("a",{class:["fc-col-header-cell-cushion",e.isSticky?"fc-sticky":""].join(" "),ref:r},o))}))},t}(Rn);function oo(e){return e.text}var io=function(e){function t(t,n){var r=e.call(this,t,n)||this;return r.initialNowDate=n.calendar.getNow(),r.initialNowQueriedMs=(new Date).valueOf(),r.state=r.computeTiming().currentState,r}return Object(d.c)(t,e),t.prototype.render=function(e,t){return e.content(t.nowDate,t.todayRange)},t.prototype.componentDidMount=function(){this.setTimeout()},t.prototype.componentDidUpdate=function(e){e.unit!==this.props.unit&&(this.clearTimeout(),this.setTimeout())},t.prototype.componentWillUnmount=function(){this.clearTimeout()},t.prototype.computeTiming=function(){var e=this.props,t=this.context,n=$(this.initialNowDate,(new Date).valueOf()-this.initialNowQueriedMs),r=t.dateEnv.startOf(n,e.unit),o=t.dateEnv.add(r,he(1,e.unit)),i=o.valueOf()-n.valueOf();return{currentState:{nowDate:r,todayRange:ao(r)},nextState:{nowDate:o,todayRange:ao(o)},waitMs:i}},t.prototype.setTimeout=function(){var e=this,t=this.computeTiming(),n=t.nextState,r=t.waitMs;this.timeoutId=setTimeout((function(){e.setState(n,(function(){e.setTimeout()}))}),r)},t.prototype.clearTimeout=function(){this.timeoutId&&clearTimeout(this.timeoutId)},t.contextType=Dn,t}(k);function ao(e){var t=re(e);return{start:t,end:X(t,1)}}var co=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.createDayHeaderFormatter=at(so),t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=e.dates,o=e.datesRepDistinctDays,i=this.createDayHeaderFormatter(n.options.dayHeaderFormat,o,r.length);return v(io,{unit:"day",content:function(t,n){return v("tr",null,e.renderIntro&&e.renderIntro(),r.map((function(t){return o?v(no,{key:t.toISOString(),date:t,todayRange:n,dateProfile:e.dateProfile,colCnt:r.length,dayHeaderFormat:i}):v(ro,{key:t.getUTCDay(),dow:t.getUTCDay(),dayHeaderFormat:i})})))}})},t}(Rn);function so(e,t,n){return bt(e||function(e,t){return!e||t>10?{weekday:"short"}:t>1?{weekday:"short",month:"numeric",day:"numeric",omitCommas:!0}:{weekday:"long"}}(t,n))}var lo=function(){function e(e,t){for(var n=e.start,r=e.end,o=[],i=[],a=-1;n<r;)t.isHiddenDay(n)?o.push(a+.5):(a++,o.push(a),i.push(n)),n=X(n,1);this.dates=i,this.indices=o,this.cnt=i.length}return e.prototype.sliceRange=function(e){var t=this.getDateDayIndex(e.start),n=this.getDateDayIndex(X(e.end,-1)),r=Math.max(0,t),o=Math.min(this.cnt-1,n);return(r=Math.ceil(r))<=(o=Math.floor(o))?{firstIndex:r,lastIndex:o,isStart:t===r,isEnd:n===o}:null},e.prototype.getDateDayIndex=function(e){var t=this.indices,n=Math.floor(te(this.dates[0],e));return n<0?t[0]-1:n>=t.length?t[t.length-1]+1:t[n]},e}(),uo=function(){function e(e,t){var n,r,o,i=e.dates;if(t){for(r=i[0].getUTCDay(),n=1;n<i.length&&i[n].getUTCDay()!==r;n++);o=Math.ceil(i.length/n)}else o=1,n=i.length;this.rowCnt=o,this.colCnt=n,this.daySeries=e,this.cells=this.buildCells(),this.headerDates=this.buildHeaderDates()}return e.prototype.buildCells=function(){for(var e=[],t=0;t<this.rowCnt;t++){for(var n=[],r=0;r<this.colCnt;r++)n.push(this.buildCell(t,r));e.push(n)}return e},e.prototype.buildCell=function(e,t){var n=this.daySeries.dates[e*this.colCnt+t];return{key:n.toISOString(),date:n}},e.prototype.buildHeaderDates=function(){for(var e=[],t=0;t<this.colCnt;t++)e.push(this.cells[0][t].date);return e},e.prototype.sliceRange=function(e){var t=this.colCnt,n=this.daySeries.sliceRange(e),r=[];if(n)for(var o=n.firstIndex,i=n.lastIndex,a=o;a<=i;){var c=Math.floor(a/t),s=Math.min((c+1)*t,i+1);r.push({row:c,firstCol:a%t,lastCol:(s-1)%t,isStart:n.isStart&&a===o,isEnd:n.isEnd&&s-1===i}),a=s}return r},e}(),fo=function(){function e(){this.sliceBusinessHours=at(this._sliceBusinessHours),this.sliceDateSelection=at(this._sliceDateSpan),this.sliceEventStore=at(this._sliceEventStore),this.sliceEventDrag=at(this._sliceInteraction),this.sliceEventResize=at(this._sliceInteraction),this.forceDayIfListItem=!1}return e.prototype.sliceProps=function(e,t,n,r){for(var o=[],i=4;i<arguments.length;i++)o[i-4]=arguments[i];var a=e.eventUiBases,c=this.sliceEventStore.apply(this,Object(d.d)([e.eventStore,a,t,n],o));return{dateSelectionSegs:this.sliceDateSelection.apply(this,Object(d.d)([e.dateSelection,a,r],o)),businessHourSegs:this.sliceBusinessHours.apply(this,Object(d.d)([e.businessHours,t,n,r],o)),fgEventSegs:c.fg,bgEventSegs:c.bg,eventDrag:this.sliceEventDrag.apply(this,Object(d.d)([e.eventDrag,a,t,n],o)),eventResize:this.sliceEventResize.apply(this,Object(d.d)([e.eventResize,a,t,n],o)),eventSelection:e.eventSelection}},e.prototype.sliceNowDate=function(e,t){for(var n=[],r=2;r<arguments.length;r++)n[r-2]=arguments[r];return this._sliceDateSpan.apply(this,Object(d.d)([{range:{start:e,end:$(e,1)},allDay:!1},{},t],n))},e.prototype._sliceBusinessHours=function(e,t,n,r){for(var o=[],i=4;i<arguments.length;i++)o[i-4]=arguments[i];return e?this._sliceEventStore.apply(this,Object(d.d)([Ge(e,ho(t,Boolean(n)),r),{},t,n],o)).bg:[]},e.prototype._sliceEventStore=function(e,t,n,r){for(var o=[],i=4;i<arguments.length;i++)o[i-4]=arguments[i];if(e){var a=wt(e,t,ho(n,Boolean(r)),r);return{bg:this.sliceEventRanges(a.bg,o),fg:this.sliceEventRanges(a.fg,o)}}return{bg:[],fg:[]}},e.prototype._sliceInteraction=function(e,t,n,r){for(var o=[],i=4;i<arguments.length;i++)o[i-4]=arguments[i];if(!e)return null;var a=wt(e.mutatedEvents,t,ho(n,Boolean(r)),r);return{segs:this.sliceEventRanges(a.fg,o),affectedInstances:e.affectedEvents.instances,isEvent:e.isEvent}},e.prototype._sliceDateSpan=function(e,t,n){for(var r=[],o=3;o<arguments.length;o++)r[o-3]=arguments[o];if(!e)return[];for(var i=dr(e,t,n),a=this.sliceRange.apply(this,Object(d.d)([e.range],r)),c=0,s=a;c<s.length;c++){var l=s[c];l.eventRange=i}return a},e.prototype.sliceEventRanges=function(e,t){for(var n=[],r=0,o=e;r<o.length;r++){var i=o[r];n.push.apply(n,this.sliceEventRange(i,t))}return n},e.prototype.sliceEventRange=function(e,t){var n=e.range;this.forceDayIfListItem&&"list-item"===e.ui.display&&(n={start:n.start,end:X(n.start,1)});for(var r=this.sliceRange.apply(this,Object(d.d)([n],t)),o=0,i=r;o<i.length;o++){var a=i[o];a.eventRange=e,a.isStart=e.isStart&&a.isStart,a.isEnd=e.isEnd&&a.isEnd}return r},e}();function ho(e,t){var n=e.activeRange;return t?n:{start:$(n.start,e.slotMinTime.milliseconds),end:$(n.end,e.slotMaxTime.milliseconds-864e5)}}var po=/^(visible|hidden)$/,mo=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleEl=function(e){t.el=e,In(t.props.elRef,e)},t}return Object(d.c)(t,e),t.prototype.render=function(e){var t=["fc-scroller"],n=e.liquid,r=e.liquidIsAbsolute,o=n&&r;return n&&(r?t.push("fc-scroller-liquid-absolute"):t.push("fc-scroller-liquid")),v("div",{ref:this.handleEl,class:t.join(" "),style:{overflowX:e.overflowX,overflowY:e.overflowY,left:o&&-(e.overcomeLeft||0)||"",right:o&&-(e.overcomeRight||0)||"",bottom:o&&-(e.overcomeBottom||0)||"",marginLeft:!o&&-(e.overcomeLeft||0)||"",marginRight:!o&&-(e.overcomeRight||0)||"",marginBottom:!o&&-(e.overcomeBottom||0)||"",maxHeight:e.maxHeight||""}},e.children)},t.prototype.needsXScrolling=function(){if(po.test(this.props.overflowX))return!1;for(var e=this.el,t=this.el.getBoundingClientRect().width-this.getYScrollbarWidth(),n=e.children,r=0;r<n.length;r++){if(n[r].getBoundingClientRect().width>t)return!0}return!1},t.prototype.needsYScrolling=function(){if(po.test(this.props.overflowY))return!1;for(var e=this.el,t=this.el.getBoundingClientRect().height-this.getXScrollbarWidth(),n=e.children,r=0;r<n.length;r++){if(n[r].getBoundingClientRect().height>t)return!0}return!1},t.prototype.getXScrollbarWidth=function(){return po.test(this.props.overflowX)?0:this.el.offsetHeight-this.el.clientHeight},t.prototype.getYScrollbarWidth=function(){return po.test(this.props.overflowY)?0:this.el.offsetWidth-this.el.clientWidth},t}(Rn),vo=function(){function e(e){var t=this;this.masterCallback=e,this.currentMap={},this.depths={},this.callbackMap={},this.handleValue=function(e,n){var r=t,o=r.depths,i=r.currentMap,a=!1,c=!1;null!==e?(a=n in i,i[n]=e,o[n]=(o[n]||0)+1,c=!0):0==--o[n]&&(delete i[n],delete t.callbackMap[n],a=!0),t.masterCallback&&(a&&t.masterCallback(null,String(n)),c&&t.masterCallback(e,String(n)))}}return e.prototype.createRef=function(e){var t=this,n=this.callbackMap[e];return n||(n=this.callbackMap[e]=function(n){t.handleValue(n,String(e))}),n},e.prototype.collect=function(e,t,n){return function(e,t,n,r){void 0===t&&(t=0),void 0===r&&(r=1);var o=[];null==n&&(n=Object.keys(e).length);for(var i=t;i<n;i+=r){var a=e[i];void 0!==a&&o.push(a)}return o}(this.currentMap,e,t,n)},e.prototype.getAll=function(){return Ue(this.currentMap)},e}();function go(e){for(var t=0,n=0,r=function(e,t){for(var n=e instanceof HTMLElement?[e]:e,r=[],o=0;o<n.length;o++)for(var i=n[o].querySelectorAll(t),a=0;a<i.length;a++)r.push(i[a]);return r}(e,".fc-scrollgrid-shrink");n<r.length;n++){var o=r[n];t=Math.max(t,Me(o))}return Math.ceil(t)}function bo(e,t){return e.liquid&&t.liquid}function yo(e,t){return B(e,t,Fe)}function ko(e,t){for(var n=[],r=0,o=e;r<o.length;r++)for(var i=o[r],a=i.span||1,c=0;c<a;c++)n.push(v("col",{style:{width:"shrink"===i.width?Ao(t):i.width||"",minWidth:i.minWidth||""}}));return v("colgroup",null,n)}function Ao(e){return null==e?4:e}function _o(e,t){var n=["fc-scrollgrid-section","fc-scrollgrid-section-"+e.type,e.className];return t&&e.liquid&&null==e.maxHeight&&n.push("fc-scrollgrid-section-liquid"),e.isSticky&&n.push("fc-scrollgrid-section-sticky"),n}function Eo(e){return v("div",{class:"fc-scrollgrid-sticky-shim",style:{width:e.clientWidth,minWidth:e.tableMinWidth}})}function xo(e){var t=e.stickyHeaderDates;return null!=t&&"auto"!==t||(t="auto"===e.height||"auto"===e.viewHeight),t}function wo(e){var t=e.stickyFooterScrollbar;return null!=t&&"auto"!==t||(t="auto"===e.height||"auto"===e.viewHeight),t}var So=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.processCols=at((function(e){return e}),yo),t.renderMicroColGroup=at(ko),t.scrollerRefs=new vo,t.scrollerElRefs=new vo(t._handleScrollerEl.bind(t)),t.state={shrinkWidth:null,forceYScrollbars:!1,scrollerClientWidths:{},scrollerClientHeights:{}},t.handleSizing=function(){t.props.forPrint||t.setState(Object(d.a)({shrinkWidth:t.computeShrinkWidth()},t.computeScrollerDims()))},t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=this,o=e.sections||[],i=this.processCols(e.cols),a=e.forPrint?v("colgroup",null):this.renderMicroColGroup(i,t.shrinkWidth);return v("table",{class:function(e,t){var n=["fc-scrollgrid",t.theme.getClass("table")];return e&&n.push("fc-scrollgrid-liquid"),n}(e.liquid,n).join(" "),style:{height:e.height}},v("tbody",null,o.map((function(e,t){return r.renderSection(e,t,a)}))))},t.prototype.renderSection=function(e,t,n){return"outerContent"in e?e.outerContent:v("tr",{key:e.key,class:_o(e,this.props.liquid).join(" ")},this.renderChunkTd(e,t,n,e.chunk))},t.prototype.renderChunkTd=function(e,t,n,r){if("outerContent"in r)return r.outerContent;var o=this.props,i=this.state,a=i.forceYScrollbars,c=i.scrollerClientWidths,s=i.scrollerClientHeights,l=function(e,t){return null!=t.maxHeight||bo(e,t)}(o,e),d=bo(o,e),u=o.liquid?a?"scroll":l?"auto":"hidden":"visible",f=function(e,t,n){var r=e.expandRows;return"function"==typeof t.content?t.content(n):v("table",{className:[t.tableClassName,e.syncRowHeights?"fc-scrollgrid-sync-table":""].join(" "),style:{minWidth:n.tableMinWidth,width:n.clientWidth,height:r?n.clientHeight:""}},[n.tableColGroupNode,v("tbody",{},"function"==typeof t.rowContent?t.rowContent(n):t.rowContent)])}(e,r,{tableColGroupNode:n,tableMinWidth:"",clientWidth:void 0!==c[t]?c[t]:null,clientHeight:void 0!==s[t]?s[t]:null,expandRows:e.expandRows,syncRowHeights:!1,rowSyncHeights:[],reportRowHeightChange:function(){}});return v("td",{ref:r.elRef},v("div",{class:"fc-scroller-harness"+(d?" fc-scroller-harness-liquid":"")},v(mo,{ref:this.scrollerRefs.createRef(t),elRef:this.scrollerElRefs.createRef(t),overflowY:u,overflowX:o.liquid?"hidden":"visible",maxHeight:e.maxHeight,liquid:d,liquidIsAbsolute:!0},f)))},t.prototype._handleScrollerEl=function(e,t){var n=parseInt(t,10);In(this.props.sections[n].chunk.scrollerElRef,e)},t.prototype.componentDidMount=function(){this.handleSizing(),this.context.addResizeHandler(this.handleSizing)},t.prototype.componentDidUpdate=function(){this.handleSizing()},t.prototype.componentWillUnmount=function(){this.context.removeResizeHandler(this.handleSizing)},t.prototype.computeShrinkWidth=function(){return function(e){for(var t=0,n=e;t<n.length;t++){if("shrink"===n[t].width)return!0}return!1}(this.props.cols)?go(this.scrollerElRefs.getAll()):0},t.prototype.computeScrollerDims=function(){for(var e=mn(),t=this.props.sections.length,n=this.scrollerRefs,r=this.scrollerElRefs,o=!1,i={},a={},c=0;c<t;c++){var s=n.currentMap[c];if(s&&s.needsYScrolling()){o=!0;break}}for(c=0;c<t;c++){var l=r.currentMap[c];if(l){var d=l.parentNode;i[c]=Math.floor(d.getBoundingClientRect().width-(o?e.y:0)),a[c]=Math.floor(d.getBoundingClientRect().height)}}return{forceYScrollbars:o,scrollerClientWidths:i,scrollerClientHeights:a}},t}(Rn);So.addStateEquality({scrollerClientWidths:Fe,scrollerClientHeights:Fe});var Do=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.elRef={},t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=e.seg,o=r.eventRange,i=o.ui,a={event:new xt(n.calendar,o.def,o.instance),view:n.view,timeText:e.timeText,textColor:i.textColor,backgroundColor:i.backgroundColor,borderColor:i.borderColor,isDraggable:!e.disableDragging&&It(r,n),isStartResizable:!e.disableResizing&&Mt(r,n),isEndResizable:!e.disableResizing&&jt(r),isMirror:Boolean(e.isDragging||e.isResizing||e.isDateSelecting),isStart:Boolean(r.isStart),isEnd:Boolean(r.isEnd),isPast:Boolean(e.isPast),isFuture:Boolean(e.isFuture),isToday:Boolean(e.isToday),isSelected:Boolean(e.isSelected),isDragging:Boolean(e.isDragging),isResizing:Boolean(e.isResizing)},c=function(e){return{"background-color":e.backgroundColor,"border-color":e.borderColor,color:e.textColor}}(i),s=function(e){var t=["fc-event"];return e.isMirror&&t.push("fc-event-mirror"),e.isDraggable&&t.push("fc-event-draggable"),(e.isStartResizable||e.isEndResizable)&&t.push("fc-event-resizable"),e.isDragging&&t.push("fc-event-dragging"),e.isResizing&&t.push("fc-event-resizing"),e.isSelected&&t.push("fc-event-selected"),e.isStart&&t.push("fc-event-start"),e.isEnd&&t.push("fc-event-end"),e.isPast&&t.push("fc-event-past"),e.isToday&&t.push("fc-event-today"),e.isFuture&&t.push("fc-event-future"),t}(a).concat(i.classNames);return v(fr,{name:"event",hookProps:a,defaultContent:e.defaultContent,elRef:this.elRef},(function(t,n,r,o){return e.children(t,s.concat(n),c,r,o,a)}))},t.prototype.componentDidMount=function(){St(this.elRef.current,this.props.seg)},t.prototype.componentDidUpdate=function(e){var t=this.props.seg;t!==e.seg&&St(this.elRef.current,t)},t}(Rn),Co=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r=n.options,o=bt(r.eventTimeFormat||e.defaultTimeFormat,r.defaultRangeSeparator),i=Nt(e.seg,o,n,e.defaultDisplayEventTime,e.defaultDisplayEventEnd);return v(Do,{seg:e.seg,timeText:i,disableDragging:e.disableDragging,disableResizing:e.disableResizing,defaultContent:e.defaultContent||Ro,isDragging:e.isDragging,isResizing:e.isResizing,isDateSelecting:e.isDateSelecting,isSelected:e.isSelected,isPast:e.isPast,isFuture:e.isFuture,isToday:e.isToday},(function(t,n,r,o,i,a){return v("a",Object(d.a)({className:e.extraClassNames.concat(n).join(" "),style:r,ref:t},(c=e.seg,(s=c.eventRange.def.url)?{href:s}:{})),v("div",{class:"fc-event-main",ref:o},i),a.isStartResizable&&v("div",{class:"fc-event-resizer fc-event-resizer-start"}),a.isEndResizable&&v("div",{class:"fc-event-resizer fc-event-resizer-end"}));var c,s}))},t}(Rn);function Ro(e){return[e.timeText&&v("div",{class:"fc-event-time"},e.timeText),v("div",{class:"fc-event-title"},e.event.title||v(y,null," "))]}var Oo=bt({day:"numeric"}),To=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buildClassNames=mr("dayCell"),t}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r={date:e.date,dateProfile:e.dateProfile,todayRange:e.todayRange,showDayNumber:e.showDayNumber},o=Object(d.a)(Object(d.a)({},Mo(r,n)),e.extraHookProps),i=fn(o,n.theme).concat(o.isDisabled?[]:this.buildClassNames(o,n,null,r)),a=o.isDisabled?{}:{"data-date":yt(e.date)};return v(pr,{name:"dayCell",hookProps:o,elRef:e.elRef},(function(t){return e.children(t,i,a,o.isDisabled)}))},t}(Rn),Io=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(d.c)(t,e),t.prototype.render=function(e,t,n){var r={date:e.date,dateProfile:e.dateProfile,todayRange:e.todayRange,showDayNumber:e.showDayNumber},o=Object(d.a)(Object(d.a)({},Mo(r,n)),e.extraHookProps);return v(hr,{name:"dayCell",hookProps:o,defaultContent:e.defaultContent},e.children)},t}(Rn);function Mo(e,t){var n=t.dateEnv,r=e.date,o=un(r,e.todayRange,null,e.dateProfile);return Object(d.a)(Object(d.a)({date:n.toDate(r),view:t.view},o),{dayNumberText:e.showDayNumber?n.format(r,Oo):""})}function jo(e){return v("div",{class:"fc-"+e})}var No=function(e){return v(Do,{defaultContent:Po,seg:e.seg,timeText:"",disableDragging:!0,disableResizing:!0,isDragging:!1,isResizing:!1,isDateSelecting:!1,isSelected:!1,isPast:e.isPast,isFuture:e.isFuture,isToday:e.isToday},(function(e,t,n,r,o){return v("div",{ref:e,className:["fc-bg-event"].concat(t).join(" "),style:n},o)}))};function Po(e){return e.event.title&&v("div",{class:"fc-event-title"},e.event.title)}var Bo=function(e){return v(Dn.Consumer,null,(function(t){var n=e.date,r=bt(t.options.weekNumberFormat||e.defaultFormat),o=t.dateEnv.computeWeekNumber(n),i=t.dateEnv.format(n,r);return v(fr,{name:"weekNumber",hookProps:{num:o,text:i,date:n},defaultContent:Ho},e.children)}))};function Ho(e){return e.text}},577:function(e,t,n){"use strict";var r=n(571),o=n(1),i=(n(518),function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.headerElRef=Object(r.E)(),t}return Object(o.c)(t,e),t.prototype.renderSimpleLayout=function(e,t){var n=this.props,o=this.context,i=[],a=Object(r.J)(o.options);return e&&i.push({type:"header",isSticky:a,chunk:{elRef:this.headerElRef,tableClassName:"fc-col-header",rowContent:e}}),i.push({type:"body",liquid:!0,chunk:{content:t}}),Object(r.K)(r.v,{viewSpec:n.viewSpec},(function(e,t){return Object(r.K)("div",{ref:e,class:["fc-daygrid"].concat(t).join(" ")},Object(r.K)(r.s,{liquid:!n.isHeightAuto,forPrint:n.forPrint,cols:[],sections:i}))}))},t.prototype.renderHScrollLayout=function(e,t,n,o){var i=this.context.pluginHooks.scrollGridImpl;if(!i)throw new Error("No ScrollGrid implementation");var a=this.props,c=this.context,s=Object(r.J)(c.options),l=Object(r.I)(c.options),d=[];return e&&d.push({type:"header",isSticky:s,chunks:[{elRef:this.headerElRef,tableClassName:"fc-col-header",rowContent:e}]}),d.push({type:"body",liquid:!0,chunks:[{content:t}]}),l&&d.push({type:"footer",isSticky:!0,chunks:[{content:r.Q}]}),Object(r.K)(r.v,{viewSpec:a.viewSpec},(function(e,t){return Object(r.K)("div",{ref:e,class:["fc-daygrid"].concat(t).join(" ")},Object(r.K)(i,{liquid:!a.isHeightAuto,forPrint:a.forPrint,colGroups:[{cols:[{span:n,minWidth:o}]}],sections:d}))}))},t}(r.d));function a(e,t){for(var n=[],r=0;r<t;r++)n[r]=[];for(var o=0,i=e;o<i.length;o++){var a=i[o];n[a.row].push(a)}return n}function c(e,t){for(var n=[],r=0;r<t;r++)n[r]=[];for(var o=0,i=e;o<i.length;o++){var a=i[o];n[a.firstCol].push(a)}return n}function s(e,t){var n=[];if(e){for(a=0;a<t;a++)n[a]={affectedInstances:e.affectedInstances,isEvent:e.isEvent,segs:[]};for(var r=0,o=e.segs;r<o.length;r++){var i=o[r];n[i.row].segs.push(i)}}else for(var a=0;a<t;a++)n[a]=null;return n}var l={week:"narrow"},d=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handleMoreLink=function(e){var n=t.props;if(n.onMoreClick){var r=h(n.allFgSegs,n.date),o=r.filter((function(e){return n.segIsHidden[e.eventRange.instance.instanceId]}));n.onMoreClick({date:n.date,allSegs:r,hiddenSegs:o,moreCnt:n.moreCnt,dayEl:t.base,ev:e})}},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var i=this,a=n.options,c=e.date;return Object(r.K)(r.g,{date:c,todayRange:e.todayRange,dateProfile:e.dateProfile,showDayNumber:e.showDayNumber,extraHookProps:e.extraHookProps,elRef:e.elRef},(function(t,s,d,u){return Object(r.K)("td",Object(o.a)({ref:t,class:["fc-daygrid-day"].concat(s,e.extraClassNames||[]).join(" ")},d,e.extraDataAttrs),Object(r.K)("div",{class:"fc-daygrid-day-frame fc-scrollgrid-sync-inner",ref:e.innerElRef},e.showWeekNumber&&Object(r.K)(r.w,{date:c,defaultFormat:l},(function(e,t,n,o){return Object(r.K)("a",{ref:e,class:["fc-daygrid-week-number"].concat(t).join(" "),"data-navlink":a.navLinks?Object(r.A)(c,"week"):null},o)})),!u&&Object(r.K)(p,{date:c,showDayNumber:e.showDayNumber,dateProfile:e.dateProfile,todayRange:e.todayRange,extraHookProps:e.extraHookProps}),Object(r.K)("div",{class:"fc-daygrid-day-events",ref:e.fgContentElRef,style:{paddingBottom:e.fgPaddingBottom}},e.fgContent,Boolean(e.moreCnt)&&Object(r.K)("div",{class:"fc-daygrid-day-bottom",style:{marginTop:e.moreMarginTop}},Object(r.K)(r.r,{name:"moreLink",hookProps:{num:e.moreCnt,text:e.buildMoreLinkText(e.moreCnt),view:n.view},defaultContent:f},(function(e,t,n,o){return Object(r.K)("a",{onClick:i.handleMoreLink,ref:e,className:["fc-daygrid-more-link"].concat(t).join(" ")},o)})))),Object(r.K)("div",{class:"fc-daygrid-day-bg"},e.bgContent)))}))},t}(r.d);function u(e){return e.dayNumberText}function f(e){return e.text}function h(e,t){for(var n=t,i={start:n,end:Object(r.x)(n,1)},a=[],c=0,s=e;c<s.length;c++){var l=s[c],d=l.eventRange,u=d.range,f=Object(r.L)(u,i);f&&a.push(Object(o.a)(Object(o.a)({},l),{eventRange:{def:d.def,ui:Object(o.a)(Object(o.a)({},d.ui),{durationEditable:!1}),instance:d.instance,range:f},isStart:l.isStart&&f.start.valueOf()===u.start.valueOf(),isEnd:l.isEnd&&f.end.valueOf()===u.end.valueOf()}))}return a}var p=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(o.c)(t,e),t.prototype.render=function(e){var t=this;return Object(r.K)(r.f,{date:e.date,todayRange:e.todayRange,dateProfile:e.dateProfile,showDayNumber:e.showDayNumber,extraHookProps:e.extraHookProps,defaultContent:u},(function(n,o){return o&&Object(r.K)("div",{class:"fc-daygrid-day-top",ref:n},Object(r.K)("a",{className:"fc-daygrid-day-number","data-navlink":t.context.options.navLinks?Object(r.A)(e.date):null},o))}))},t}(r.a),m={hour:"numeric",minute:"2-digit",omitZeroMinute:!0,meridiem:"narrow"};function v(e){var t=e.ui.display;return"list-item"===t||(!t||"auto"===t)&&!e.def.allDay&&Object(r.F)(e.instance.range.start,e.instance.range.end)<=1}var g=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var i=n.options,a=Object(r.C)(i.eventTimeFormat||m,i.defaultRangeSeparator),c=Object(r.B)(e.seg,a,n,!0,e.defaultDisplayEventEnd);return Object(r.K)(r.m,{seg:e.seg,timeText:c,defaultContent:b,isDragging:e.isDragging,isResizing:!1,isDateSelecting:!1,isSelected:e.isSelected,isPast:e.isPast,isFuture:e.isFuture,isToday:e.isToday},(function(t,n,i,a,c,s){return Object(r.K)("a",Object(o.a)({className:["fc-daygrid-event","fc-daygrid-dot-event"].concat(n).join(" "),ref:t,style:{color:s.textColor}},(l=e.seg,(d=l.eventRange.def.url)?{href:d}:{})),c);var l,d}))},t}(r.a);function b(e){return[Object(r.K)("div",{className:"fc-daygrid-event-dot",style:{backgroundColor:e.backgroundColor||e.borderColor}}),e.timeText&&Object(r.K)("div",{class:"fc-event-time"},e.timeText),Object(r.K)("div",{class:"fc-event-title"},e.event.title||Object(r.K)(r.n,null," "))]}var y=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(o.c)(t,e),t.prototype.render=function(e){return Object(r.K)(r.u,Object(o.a)({},e,{extraClassNames:["fc-daygrid-event","fc-daygrid-block-event","fc-h-event"],defaultTimeFormat:m,defaultDisplayEventEnd:e.defaultDisplayEventEnd,disableResizing:!e.seg.eventRange.def.allDay}))},t}(r.a);function k(e,t,n,o,i,a,c){for(var s,l=[],d=[],u={},f={},h={},p={},m={},v=[],g=0;g<a;g++)l.push([]),d.push(0),v.push([]);for(var b=0,y=e=Object(r.S)(e,c);b<y.length;b++){M(T=y[b],o[N=T.eventRange.instance.instanceId]||0)}for(var k=0,w=l;k<w.length;k++){w[k].sort(E)}!0===t||!0===n?function(e,t,n,r){x(e,t,n,!0,(function(e){return e.bottom<=r}))}(d,u,l,i):"number"==typeof t?function(e,t,n,r){x(e,t,n,!1,(function(e,t){return t<r}))}(d,u,l,t):"number"==typeof n&&function(e,t,n,r){x(e,t,n,!0,(function(e,t){return t<r}))}(d,u,l,n);for(var S=0;S<a;S++){for(var D=0,C=0,R=0,O=l[S];R<O.length;R++){var T,I=O[R];u[(T=I.seg).eventRange.instance.instanceId]||(f[T.eventRange.instance.instanceId]=I.top,T.firstCol===T.lastCol&&T.isStart&&T.isEnd?(h[T.eventRange.instance.instanceId]=I.top-D+C,C=0):C+=I.bottom-I.top,D=I.bottom)}C&&(d[S]?p[S]=C:m[S]=C)}function M(e,t){if(!j(e,t,0))for(var n=e.firstCol;n<=e.lastCol;n++)for(var r=0,o=l[n];r<o.length;r++){if(j(e,t,o[r].bottom))return}}function j(e,t,n){if(function(e,t,n){for(var r=e.firstCol;r<=e.lastCol;r++)for(var o=0,i=l[r];o<i.length;o++){var a=i[o];if(n<a.bottom&&n+t>a.top)return!1}return!0}(e,t,n)){for(var r=e.firstCol;r<=e.lastCol;r++)l[r].push({seg:e,top:n,bottom:n+t});return!0}return!1}for(var N in s=l.map(A),v=l.map(_),o)o[N]||(u[N]=!0);return{finalSegsByCol:v,segsByFirstCol:s,segIsHidden:u,segTops:f,segMarginTops:h,moreCnts:d,moreTops:p,paddingBottoms:m}}function A(e,t){for(var n=[],r=0,o=e;r<o.length;r++){var i=o[r];i.seg.firstCol===t&&n.push(i.seg)}return n}function _(e,t){for(var n=[],r=0,o=e;r<o.length;r++){var i=o[r];n.push(i.seg)}return n}function E(e,t){return e.top-t.top}function x(e,t,n,r,o){for(var i=e.length,a={},c=[],s=0;s<i;s++)c.push([]);for(s=0;s<i;s++)for(var l=0,d=0,u=n[s];d<u.length;d++){var f=u[d];o(f,l)?h(f):p(f),f.top!==f.bottom&&l++}function h(e){var t=e.seg,n=t.eventRange.instance.instanceId;if(!a[n]){a[n]=!0;for(var r=t.firstCol;r<=t.lastCol;r++)c[r].push(e)}}function p(n){var o=n.seg,i=o.eventRange.instance.instanceId;if(!t[i]){t[i]=!0;for(var a=o.firstCol;a<=o.lastCol;a++){var s=++e[a];if(r&&1===s){var l=c[a].pop();l&&p(l)}}}}}var w=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.cellElRefs=new r.q,t.cellInnerElRefs=new r.q,t.cellContentElRefs=new r.q,t.segHarnessRefs=new r.q,t.state={cellInnerPositions:null,cellContentPositions:null,maxContentHeight:null,segHeights:{}},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var o=this,i=e.cells.length,a=c(e.businessHourSegs,i),s=c(e.bgEventSegs,i),l=c(this.getHighlightSegs(),i),u=c(this.getMirrorSegs(),i),f=k(e.fgEventSegs,e.dayMaxEvents,e.dayMaxEventRows,t.segHeights,t.maxContentHeight,i,n.eventOrderSpecs),h=f.paddingBottoms,p=f.finalSegsByCol,m=f.segsByFirstCol,v=f.segIsHidden,g=f.segTops,b=f.segMarginTops,y=f.moreCnts,A=f.moreTops,_=e.eventDrag&&e.eventDrag.affectedInstances||e.eventResize&&e.eventResize.affectedInstances||{};return Object(r.K)("tr",null,e.renderIntro&&e.renderIntro(),e.cells.map((function(t,n){var i=o.renderFgSegs(m[n],v,g,b,_,e.todayRange),c=o.renderFgSegs(u[n],{},g,{},{},e.todayRange,Boolean(e.eventDrag),Boolean(e.eventResize),!1),f=e.showWeekNumbers&&0===n;return Object(r.K)(d,{key:t.key,elRef:o.cellElRefs.createRef(t.key),innerElRef:o.cellInnerElRefs.createRef(t.key),date:t.date,showDayNumber:e.showDayNumbers||f,showWeekNumber:f,dateProfile:e.dateProfile,todayRange:e.todayRange,extraHookProps:t.extraHookProps,extraDataAttrs:t.extraDataAttrs,extraClassNames:t.extraClassNames,moreCnt:y[n],moreMarginTop:A[n],buildMoreLinkText:e.buildMoreLinkText,onMoreClick:e.onMoreClick,hasEvents:Boolean(i.length),allFgSegs:p[n],segIsHidden:v,fgPaddingBottom:h[n],fgContentElRef:o.cellContentElRefs.createRef(t.key),fgContent:[Object(r.K)(r.n,null,i),Object(r.K)(r.n,null,c)],bgContent:[Object(r.K)(r.n,null,o.renderFillSegs(l[n],"highlight")),Object(r.K)(r.n,null,o.renderFillSegs(a[n],"non-business")),Object(r.K)(r.n,null,o.renderFillSegs(s[n],"bg-event"))]})})))},t.prototype.componentDidMount=function(){this.updateSizing(!0)},t.prototype.componentDidUpdate=function(e,t){var n=this.props;this.updateSizing(!Object(r.M)(e,n))},t.prototype.getHighlightSegs=function(){var e=this.props;return e.eventDrag&&e.eventDrag.segs.length?e.eventDrag.segs:e.eventResize&&e.eventResize.segs.length?e.eventResize.segs:e.dateSelectionSegs},t.prototype.getMirrorSegs=function(){var e=this.props;return e.eventResize&&e.eventResize.segs.length?e.eventResize.segs:[]},t.prototype.renderFgSegs=function(e,t,n,i,a,c,s,l,d){var u=this.context,f=this.props.eventSelection,h=this.state,p=h.cellInnerPositions,m=h.cellContentPositions,b=1===this.props.cells.length,k=[];if(p&&m)for(var A=0,_=e;A<_.length;A++){var E=_[A],x=E.eventRange,w=x.instance.instanceId,S=s||l||d,D=a[w],C=t[w]||D,R=t[w]||S||E.firstCol!==E.lastCol||!E.isStart||!E.isEnd,O=void 0,T=void 0,I=void 0,M=void 0;R?(T=n[w],u.isRtl?(M=E.isStart?0:m.rights[E.firstCol]-p.rights[E.firstCol],I=(E.isEnd?m.lefts[E.lastCol]:p.lefts[E.lastCol])-m.lefts[E.firstCol]):(I=E.isStart?0:p.lefts[E.firstCol]-m.lefts[E.firstCol],M=m.rights[E.firstCol]-(E.isEnd?m.rights[E.lastCol]:p.rights[E.lastCol]))):O=i[w],k.push(Object(r.K)("div",{class:"fc-daygrid-event-harness"+(R?" fc-daygrid-event-harness-abs":""),key:w,ref:S?null:this.segHarnessRefs.createRef(w),style:{visibility:C?"hidden":"",marginTop:O||"",top:T||"",left:I||"",right:M||""}},v(x)?Object(r.K)(g,Object(o.a)({seg:E,isDragging:s,isSelected:w===f,defaultDisplayEventEnd:b},Object(r.H)(E,c))):Object(r.K)(y,Object(o.a)({seg:E,isDragging:s,isResizing:l,isDateSelecting:d,isSelected:w===f,defaultDisplayEventEnd:b},Object(r.H)(E,c)))))}return k},t.prototype.renderFillSegs=function(e,t){var n=this.context.isRtl,i=this.props.todayRange,a=this.state.cellInnerPositions,c=[];if(a)for(var s=0,l=e;s<l.length;s++){var d=l[s],u=n?{right:0,left:a.lefts[d.lastCol]-a.lefts[d.firstCol]}:{left:0,right:a.rights[d.firstCol]-a.rights[d.lastCol]},f=d.eventRange,h=f.instance?f.instance.instanceId:f.def.defId;c.push(Object(r.K)("div",{class:"fc-daygrid-bg-harness",style:u},"bg-event"===t?Object(r.K)(r.b,Object(o.a)({key:h,seg:d},Object(r.H)(d,i))):Object(r.P)(t)))}return c},t.prototype.updateSizing=function(e){var t=this.props,n=this.cellInnerElRefs,o=this.cellContentElRefs;if(null!==t.clientWidth){if(e){var i=t.cells.map((function(e){return n.currentMap[e.key]})),a=t.cells.map((function(e){return o.currentMap[e.key]}));if(a.length){var c=this.base;this.setState({cellInnerPositions:new r.p(c,i,!0,!1),cellContentPositions:new r.p(c,a,!0,!1)})}}var s=!0===t.dayMaxEvents||!0===t.dayMaxEventRows;this.setState({segHeights:this.computeSegHeights(),maxContentHeight:s?this.computeMaxContentHeight():null})}},t.prototype.computeSegHeights=function(){return Object(r.N)(this.segHarnessRefs.currentMap,(function(e,t){return e.getBoundingClientRect().height}))},t.prototype.computeMaxContentHeight=function(){var e=this.props.cells[0].key,t=this.cellElRefs.currentMap[e],n=this.cellContentElRefs.currentMap[e];return t.getBoundingClientRect().bottom-n.getBoundingClientRect().top},t.prototype.getCellEls=function(){var e=this.cellElRefs.currentMap;return this.props.cells.map((function(t){return e[t.key]}))},t}(r.d);w.addStateEquality({segHeights:r.M});var S=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.repositioner=new r.k(t.updateSize.bind(t)),t.handleRootEl=function(e){t.rootEl=e,t.props.elRef&&Object(r.R)(t.props.elRef,e)},t.handleDocumentMousedown=function(e){var n=t.props.onClose,r=t.base;n&&!r.contains(e.target)&&n()},t.handleDocumentScroll=function(){t.repositioner.request(10)},t.handleCloseClick=function(){var e=t.props.onClose;e&&e()},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var i=n.theme,a=["fc-popover",n.theme.getClass("popover")].concat(e.extraClassNames||[]);return Object(r.K)("div",Object(o.a)({class:a.join(" ")},e.extraAttrs,{ref:this.handleRootEl}),Object(r.K)("div",{class:"fc-popover-header "+i.getClass("popoverHeader")},Object(r.K)("span",{class:"fc-popover-title"},e.title),Object(r.K)("span",{class:"fc-popover-close "+i.getIconClass("close"),onClick:this.handleCloseClick})),Object(r.K)("div",{class:"fc-popover-body "+i.getClass("popoverContent")},e.children))},t.prototype.componentDidMount=function(){document.addEventListener("mousedown",this.handleDocumentMousedown),document.addEventListener("scroll",this.handleDocumentScroll),this.updateSize()},t.prototype.componentWillUnmount=function(){document.removeEventListener("mousedown",this.handleDocumentMousedown),document.removeEventListener("scroll",this.handleDocumentScroll)},t.prototype.updateSize=function(){var e=this.props,t=e.alignmentEl,n=e.topAlignmentEl,o=this.rootEl;if(o){var i,a=o.getBoundingClientRect(),c=t.getBoundingClientRect(),s=n?n.getBoundingClientRect().top:c.top;s=Math.min(s,window.innerHeight-a.height-10),s=Math.max(s,10),i=this.context.isRtl?c.right-a.width:c.left,i=Math.min(i,window.innerWidth-a.width-10),i=Math.max(i,10),Object(r.z)(o,{top:s,left:i})}},t}(r.a),D=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.handlePopoverEl=function(e){t.popoverEl=e,e?t.context.calendar.registerInteractiveComponent(t,{el:e,useEventCenter:!1}):t.context.calendar.unregisterInteractiveComponent(t)},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var i=n.options,a=n.dateEnv,c=e.date,s=e.hiddenInstances,l=e.todayRange,d=a.format(c,Object(r.C)(i.dayPopoverFormat));return Object(r.K)(r.g,{date:c,todayRange:l,elRef:this.handlePopoverEl},(function(t,n,i){return Object(r.K)(S,{elRef:t,title:d,extraClassNames:["fc-more-popover"].concat(n),extraAttrs:i,onClose:e.onCloseClick,alignmentEl:e.alignmentEl,topAlignmentEl:e.topAlignmentEl},Object(r.K)(r.f,{date:c,todayRange:l},(function(e,t){return t&&Object(r.K)("div",{class:"fc-more-popover-misc",ref:e},t)})),e.segs.map((function(t){var n=t.eventRange,i=n.instance.instanceId;return Object(r.K)("div",{className:"fc-daygrid-event-harness",key:i,style:{visibility:s[i]?"hidden":""}},v(n)?Object(r.K)(g,Object(o.a)({seg:t,isDragging:!1,isSelected:i===e.selectedInstanceId,defaultDisplayEventEnd:!1},Object(r.H)(t,l))):Object(r.K)(y,Object(o.a)({seg:t,isDragging:!1,isResizing:!1,isDateSelecting:!1,isSelected:i===e.selectedInstanceId,defaultDisplayEventEnd:!1},Object(r.H)(t,l))))})))}))},t.prototype.queryHit=function(e,t,n,o){var i=this.props.date;if(e<n&&t<o)return{component:this,dateSpan:{allDay:!0,range:{start:i,end:Object(r.x)(i,1)}},dayEl:this.popoverEl,rect:{left:0,top:0,right:n,bottom:o},layer:1}},t.prototype.isPopover=function(){return!0},t}(r.d),C=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.splitBusinessHourSegs=Object(r.O)(a),t.splitBgEventSegs=Object(r.O)(a),t.splitFgEventSegs=Object(r.O)(a),t.splitDateSelectionSegs=Object(r.O)(a),t.splitEventDrag=Object(r.O)(s),t.splitEventResize=Object(r.O)(s),t.buildBuildMoreLinkText=Object(r.O)(R),t.rowRefs=new r.q,t.handleRootEl=function(e){t.rootEl=e,Object(r.R)(t.props.elRef,e)},t.handleMoreLinkClick=function(e){var n=t.context,i=n.calendar,a=n.view,c=n.options,s=n.dateEnv,l=c.moreLinkClick;function d(e){var t=e.eventRange,n=t.def,o=t.instance,a=t.range;return{event:new r.l(i,n,o),start:s.toDate(a.start),end:s.toDate(a.end),isStart:e.isStart,isEnd:e.isEnd}}"function"==typeof l&&(l=i.publiclyTrigger("moreLinkClick",[{date:s.toDate(e.date),allDay:!0,allSegs:e.allSegs.map(d),hiddenSegs:e.hiddenSegs.map(d),jsEvent:e.ev,view:a}])),"popover"===l?t.setState({morePopoverState:Object(o.a)(Object(o.a)({},e),{currentFgEventSegs:t.props.fgEventSegs})}):"string"==typeof l&&i.zoomTo(e.date,l)},t.handleMorePopoverClose=function(){t.setState({morePopoverState:null})},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var o=this,i=e.dayMaxEventRows,a=e.dayMaxEvents,c=e.expandRows,s=t.morePopoverState,l=e.cells.length,d=this.splitBusinessHourSegs(e.businessHourSegs,l),u=this.splitBgEventSegs(e.bgEventSegs,l),f=this.splitFgEventSegs(e.fgEventSegs,l),h=this.splitDateSelectionSegs(e.dateSelectionSegs,l),p=this.splitEventDrag(e.eventDrag,l),m=this.splitEventResize(e.eventResize,l),v=this.buildBuildMoreLinkText(n.options.moreLinkText),g=!0===a||!0===i;g&&!c&&(g=!1,i=null,a=null);var b=["fc-daygrid-body",g?"fc-daygrid-body-balanced":"fc-daygrid-body-unbalanced",c?"":"fc-daygrid-body-natural"];return Object(r.K)("div",{class:b.join(" "),ref:this.handleRootEl,style:{width:e.clientWidth,minWidth:e.tableMinWidth}},Object(r.K)(r.o,{unit:"day",content:function(n,g){return[Object(r.K)("table",{className:"fc-scrollgrid-sync-table",style:{width:e.clientWidth,minWidth:e.tableMinWidth,height:c?e.clientHeight:""}},e.colGroupNode,Object(r.K)("tbody",null,e.cells.map((function(t,n){return Object(r.K)(w,{ref:o.rowRefs.createRef(n),key:t.length?t[0].date.toISOString():n,showDayNumbers:l>1,showWeekNumbers:e.showWeekNumbers,todayRange:g,dateProfile:e.dateProfile,cells:t,renderIntro:e.renderRowIntro,businessHourSegs:d[n],eventSelection:e.eventSelection,bgEventSegs:u[n],fgEventSegs:f[n],dateSelectionSegs:h[n],eventDrag:p[n],eventResize:m[n],dayMaxEvents:a,dayMaxEventRows:i,clientWidth:e.clientWidth,buildMoreLinkText:v,onMoreClick:o.handleMoreLinkClick})})))),s&&s.currentFgEventSegs===e.fgEventSegs&&Object(r.K)(D,{date:t.morePopoverState.date,segs:t.morePopoverState.allSegs,alignmentEl:t.morePopoverState.dayEl,topAlignmentEl:1===l?e.headerAlignElRef.current:null,onCloseClick:o.handleMorePopoverClose,selectedInstanceId:e.eventSelection,hiddenInstances:(e.eventDrag?e.eventDrag.affectedInstances:null)||(e.eventResize?e.eventResize.affectedInstances:null)||{},todayRange:g})]}}))},t.prototype.prepareHits=function(){this.rowPositions=new r.p(this.rootEl,this.rowRefs.collect().map((function(e){return e.getCellEls()[0]})),!1,!0),this.colPositions=new r.p(this.rootEl,this.rowRefs.currentMap[0].getCellEls(),!0,!1)},t.prototype.positionToHit=function(e,t){var n=this.colPositions,r=this.rowPositions,o=n.leftToIndex(e),i=r.topToIndex(t);if(null!=i&&null!=o)return{row:i,col:o,dateSpan:{range:this.getCellRange(i,o),allDay:!0},dayEl:this.getCellEl(i,o),relativeRect:{left:n.lefts[o],right:n.rights[o],top:r.tops[i],bottom:r.bottoms[i]}}},t.prototype.getCellEl=function(e,t){return this.rowRefs.currentMap[e].getCellEls()[t]},t.prototype.getCellRange=function(e,t){var n=this.props.cells[e][t].date;return{start:n,end:Object(r.x)(n,1)}},t}(r.d);function R(e){return"function"==typeof e?e:function(t){return"+"+t+" "+e}}var O=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.slicer=new T,t.tableRef=Object(r.E)(),t.handleRootEl=function(e){var n=t.context.calendar;e?n.registerInteractiveComponent(t,{el:e}):n.unregisterInteractiveComponent(t)},t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var i=e.dateProfile,a=e.dayTableModel;return Object(r.K)(C,Object(o.a)({ref:this.tableRef,elRef:this.handleRootEl},this.slicer.sliceProps(e,i,e.nextDayThreshold,n.calendar,a),{cells:a.cells,dateProfile:i,colGroupNode:e.colGroupNode,tableMinWidth:e.tableMinWidth,renderRowIntro:e.renderRowIntro,dayMaxEvents:e.dayMaxEvents,dayMaxEventRows:e.dayMaxEventRows,showWeekNumbers:e.showWeekNumbers,expandRows:e.expandRows,headerAlignElRef:e.headerAlignElRef,clientWidth:e.clientWidth,clientHeight:e.clientHeight}))},t.prototype.prepareHits=function(){this.tableRef.current.prepareHits()},t.prototype.queryHit=function(e,t){var n=this.tableRef.current.positionToHit(e,t);if(n)return{component:this,dateSpan:n.dateSpan,dayEl:n.dayEl,rect:{left:n.relativeRect.left,right:n.relativeRect.right,top:n.relativeRect.top,bottom:n.relativeRect.bottom},layer:0}},t}(r.d),T=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.forceDayIfListItem=!0,t}return Object(o.c)(t,e),t.prototype.sliceRange=function(e,t){return t.sliceRange(e)},t}(r.t),I=function(e){function t(){var t=null!==e&&e.apply(this,arguments)||this;return t.buildDayTableModel=Object(r.O)(M),t.headerRef=Object(r.E)(),t.tableRef=Object(r.E)(),t}return Object(o.c)(t,e),t.prototype.render=function(e,t,n){var o=this,i=n.options,a=e.dateProfile,c=this.buildDayTableModel(a,e.dateProfileGenerator),s=i.dayHeaders&&Object(r.K)(r.h,{ref:this.headerRef,dateProfile:a,dates:c.headerDates,datesRepDistinctDays:1===c.rowCnt}),l=function(t){return Object(r.K)(O,{ref:o.tableRef,dateProfile:a,dayTableModel:c,businessHours:e.businessHours,dateSelection:e.dateSelection,eventStore:e.eventStore,eventUiBases:e.eventUiBases,eventSelection:e.eventSelection,eventDrag:e.eventDrag,eventResize:e.eventResize,nextDayThreshold:n.nextDayThreshold,colGroupNode:t.tableColGroupNode,tableMinWidth:t.tableMinWidth,dayMaxEvents:i.dayMaxEvents,dayMaxEventRows:i.dayMaxEventRows,showWeekNumbers:i.weekNumbers,expandRows:!e.isHeightAuto,headerAlignElRef:o.headerElRef,clientWidth:t.clientWidth,clientHeight:t.clientHeight})};return i.dayMinWidth?this.renderHScrollLayout(s,l,c.colCnt,i.dayMinWidth):this.renderSimpleLayout(s,l)},t}(i);function M(e,t){var n=new r.i(e.renderRange,t);return new r.j(n,/year|month|week/.test(e.currentRangeUnit))}var j=function(e){function t(){return null!==e&&e.apply(this,arguments)||this}return Object(o.c)(t,e),t.prototype.buildRenderRange=function(t,n,o){var i,a=this.dateEnv,c=e.prototype.buildRenderRange.call(this,t,n,o),s=c.start,l=c.end;if(/^(year|month)$/.test(n)&&(s=a.startOfWeek(s),(i=a.startOfWeek(l)).valueOf()!==l.valueOf()&&(l=Object(r.y)(i,1))),this.options.monthMode&&this.options.fixedWeekCount){var d=Math.ceil(Object(r.G)(s,l));l=Object(r.y)(l,6-d)}return{start:s,end:l}},t}(r.e),N=Object(r.D)({initialView:"dayGridMonth",views:{dayGrid:{component:I,dateProfileGeneratorClass:j},dayGridDay:{type:"dayGrid",duration:{days:1}},dayGridWeek:{type:"dayGrid",duration:{weeks:1}},dayGridMonth:{type:"dayGrid",duration:{months:1},monthMode:!0,fixedWeekCount:!0}}});t.a=N},83:function(e,t,n){"use strict";n.d(t,"a",(function(){return o}));n(5);var r=n(6);class o{constructor(e){o[" "](e),this.type=e&&e.type||"default",this.key=e&&e.key,e&&"value"in e&&(this.value=e.value)}get value(){var e=this.type,t=this.key;if(e&&t)return o.types[e]&&o.types[e][t]}set value(e){var t=this.type,n=this.key;t&&n&&(t=o.types[t]=o.types[t]||{},null==e?delete t[n]:t[n]=e)}get list(){if(this.type){var e=o.types[this.type];return e?Object.keys(e).map((function(e){return i[this.type][e]}),this):[]}}byKey(e){return this.key=e,this.value}}o[" "]=function(){},o.types={};var i=o.types;Object(r.a)({is:"iron-meta",properties:{type:{type:String,value:"default"},key:{type:String},value:{type:String,notify:!0},self:{type:Boolean,observer:"_selfChanged"},__meta:{type:Boolean,computed:"__computeMeta(type, key, value)"}},hostAttributes:{hidden:!0},__computeMeta:function(e,t,n){var r=new o({type:e,key:t});return void 0!==n&&n!==r.value?r.value=n:this.value!==r.value&&(this.value=r.value),r},get list(){return this.__meta&&this.__meta.list},_selfChanged:function(e){e&&(this.value=this)},byKey:function(e){return new o({type:this.type,key:e}).value}})}}]);
//# sourceMappingURL=chunk.14613ef780b1623041e2.js.map